@@ -21,6 +21,7 @@
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
+#include "skgbankgui_export.h"
 #include "skgobjectmodelbase.h"
 #include "skgobjectbase.h"
 
@@ -34,7 +35,7 @@ class SKGDocumentBank;
 /**
  * The Table model managing SKGObjectBase
  */
-class KDE_EXPORT SKGObjectModel : public SKGObjectModelBase
+class SKGBANKGUI_EXPORT SKGObjectModel : public SKGObjectModelBase
 {
         Q_OBJECT
 public:
@@ -141,13 +142,40 @@ private:
         QString cacheUnit;
         bool operationTable;
         bool recurrentoperationTable;
-        bool refundTable;
+        bool trackerTable;
         bool accountTable;
         bool unitTable;
         bool unitvalueTable;
+        bool suboperationTable;
+        bool categoryTable;
+        bool ruleTable;
 
-        QFont fontFutureOperations;
-        QColor fontFutureOperationsColor;
+        QVariant fontFutureOperations;
+        QVariant fontFutureOperationsColor;
+        QVariant fontNotValidatedOperations;
+        QVariant fontNotValidatedOperationsColor;
+        QVariant fontSubOperations;
+        QVariant fontSubOperationsColor;
+        QVariant fontRedColor;
+
+        QVariant icon_skrooge_transfer;
+        QVariant icon_skrooge_split;
+        QVariant icon_skrooge_much_more;
+        QVariant icon_skrooge_much_less;
+        QVariant icon_skrooge_more;
+        QVariant icon_skrooge_less;
+        QVariant icon_closed;
+        QVariant icon_imported;
+        QVariant icon_imported_checked;
+        QVariant icon_recurrent;
+        QVariant icon_recurrent_master;
+        QVariant icon_favorite;
+        QVariant icon_category;
+        QVariant icon_category_plus;
+        QVariant icon_category_moins;
+        QVariant icon_search;
+        QVariant icon_update;
+        QVariant icon_alarm;
 };
 
 #endif
