@@ -25,6 +25,8 @@
 #include "skgunitobject.h"
 #include "skgdocumentbank.h"
 
+#include <klocale.h>
+
 SKGAccountObject::SKGAccountObject(const SKGDocument* iDocument, int iID): SKGNamedObject(iDocument, "v_account", iID) {}
 
 SKGAccountObject::~SKGAccountObject() {}
@@ -112,7 +114,7 @@ QString SKGAccountObject::getAgencyAddress() const
 SKGError SKGAccountObject::addOperation(SKGOperationObject& oOperation)
 {
         SKGError err;
-        if (getID() == 0) err=SKGError(ERR_FAIL, tr("%1 failed because linked object is not yet saved in the database.").arg("SKGAccountObject::addOperation"));
+	if (getID() == 0) err=SKGError(ERR_FAIL, i18n("%1 failed because linked object is not yet saved in the database.",QString("SKGAccountObject::addOperation")));
         else {
                 oOperation = SKGOperationObject(getDocument());
                 err = oOperation.setParentAccount(*this);
@@ -157,14 +159,14 @@ double SKGAccountObject::getAmount(const QDate& iDate) const
 SKGError SKGAccountObject::setType(SKGAccountObject::AccountType iType)
 {
         SKGError err;
-        if (err.isSucceeded()) err=setAttribute("t_type", (iType==CURRENT ? "C" : (iType==CREDITCARD ? "D" : (iType==ACTIF ? "A" : (iType==INVESTMENT ? "I" : "O")))));
+        if (err.isSucceeded()) err=setAttribute("t_type", (iType==CURRENT ? "C" : (iType==CREDITCARD ? "D" : (iType==ASSETS ? "A" : (iType==INVESTMENT ? "I" : "O")))));
         return err;
 }
 
 SKGAccountObject::AccountType SKGAccountObject::getType() const
 {
         QString typeString=getAttribute("t_type");
-        return (typeString=="C" ? CURRENT : (typeString=="D" ? CREDITCARD : (typeString=="A" ? ACTIF : (typeString=="I" ? INVESTMENT : OTHER))));
+        return (typeString=="C" ? CURRENT : (typeString=="D" ? CREDITCARD : (typeString=="A" ? ASSETS : (typeString=="I" ? INVESTMENT : OTHER))));
 }
 
 SKGError SKGAccountObject::setClosed(bool iClosed)
