@@ -29,11 +29,13 @@
 #include "skgdocumentbank.h"
 #include "skgoperationobject.h"
 #include "skgrecurrentoperationobject.h"
-#include "skgrefundtrackerobject.h"
+#include "skgtrackerobject.h"
 #include "skgsuboperationobject.h"
 
 #include "skgnodeobject.h"
 
+#include "skgruleobject.h"
+
 #include "skgtransactionmng.h"
 
 #include "skgdefinebank.h"
