@@ -27,6 +27,8 @@
 #include "skgservices.h"
 #include "skgdocument.h"
 
+#include <klocale.h>
+
 SKGOperationObject::SKGOperationObject(const SKGDocument* iDocument, int iID): SKGObjectBase(iDocument, "v_operation", iID)
 {
 }
@@ -55,7 +57,7 @@ const SKGOperationObject& SKGOperationObject::operator= (const SKGObjectBase& iO
         return *this;
 }
 
-SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, const QDate& iDate)
+SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, const QDate& iDate, bool iTemplateMode)
 {
         SKGError err;
         //Create the duplicated operation
@@ -64,6 +66,7 @@ SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, const QDa
         if (err.isSucceeded()) err=oOperation.setDate(iDate);
         if (err.isSucceeded()) err=oOperation.setStatus(SKGOperationObject::NONE);
         if (err.isSucceeded()) err=oOperation.setImported(false);
+        if (err.isSucceeded()) err=oOperation.setTemplate(iTemplateMode);
         if (err.isSucceeded()) err=oOperation.setImportID("");
         if (err.isSucceeded()) err=oOperation.bookmark(false);
         if (err.isSucceeded()) err=oOperation.setNumber(0);
@@ -97,6 +100,7 @@ SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, const QDa
                                 if (err.isSucceeded()) err=newgroupop.setDate(iDate);
                                 if (err.isSucceeded()) err=newgroupop.setStatus(SKGOperationObject::NONE);
                                 if (err.isSucceeded()) err=newgroupop.setImported(false);
+                                if (err.isSucceeded()) err=newgroupop.setTemplate(iTemplateMode);
                                 if (err.isSucceeded()) err=newgroupop.setImportID("");
                                 if (err.isSucceeded()) err=newgroupop.bookmark(false);
                                 if (err.isSucceeded()) err=newgroupop.setNumber(0);
@@ -139,11 +143,11 @@ SKGError SKGOperationObject::setParentAccount(const SKGAccountObject& iAccount)
         QString currentAccount=getAttribute("rd_account_id");
         QString newAccount=SKGServices::intToString(iAccount.getID());
         if (newAccount=="0") {
-                err=SKGError(ERR_FAIL, tr("%1 failed because linked object is not yet saved in the database.").arg("SKGOperationObject::setParentAccount"));
+                err=SKGError(ERR_FAIL, i18n("%1 failed because linked object is not yet saved in the database.",QString("SKGOperationObject::setParentAccount")));
         } else {
                 if (newAccount!=currentAccount) {
                         if (iAccount.isClosed()) {
-                                err=SKGError(ERR_FAIL, tr("Impossible to add an operation in a closed account"));
+                                err=SKGError(ERR_FAIL, i18n("Impossible to add an operation in a closed account"));
                         } else {
                                 err=setAttribute("rd_account_id", newAccount);
                         }
@@ -195,14 +199,14 @@ int SKGOperationObject::getNumber() const
 SKGOperationObject::OperationStatus SKGOperationObject::getStatus() const
 {
         QString t_status=getAttribute("t_status");
-        if (t_status=="C") return SKGOperationObject::CHECKED;
+        if (t_status=="Y") return SKGOperationObject::CHECKED;
         else if (t_status=="P") return SKGOperationObject::POINTED;
         return SKGOperationObject::NONE;
 }
 
 SKGError SKGOperationObject::setStatus(SKGOperationObject::OperationStatus iStatus)
 {
-        return setAttribute("t_status", (iStatus==SKGOperationObject::CHECKED ? "C" : (iStatus==SKGOperationObject::POINTED ? "P" : "N")));
+        return setAttribute("t_status", (iStatus==SKGOperationObject::CHECKED ? "Y" : (iStatus==SKGOperationObject::POINTED ? "P" : "N")));
 }
 
 SKGError SKGOperationObject::setDate(const QDate& iDate)
@@ -266,7 +270,7 @@ SKGError SKGOperationObject::setGroupOperation(const SKGOperationObject& iOperat
                         err=SKGServices::executeSelectSqliteOrder(getDocument(), "SELECT max(i_group_id) from operation", result);
                         if (err.isSucceeded()) {
                                 //Compute new group id
-                                QString newIdGroup="1";
+                                QString newIdGroup('1');
                                 if (result.count()==2) {
                                         newIdGroup=SKGServices::intToString(SKGServices::stringToInt(result.at(1).at(0))+1);
                                 }
@@ -325,6 +329,17 @@ QString SKGOperationObject::getImportID() const
         return getAttribute("t_import_id");
 }
 
+SKGError SKGOperationObject::setTemplate(bool iTemplate)
+{
+        return setAttribute("t_template", iTemplate ? "Y" :"N");
+
+}
+
+bool SKGOperationObject::isTemplate() const
+{
+        return (getAttribute("t_template")!="N" ? true : false);
+}
+
 int SKGOperationObject::getNbSubOperations() const
 {
         return SKGServices::stringToInt(getAttribute("i_NBSUBCATEGORY"));
@@ -333,7 +348,7 @@ int SKGOperationObject::getNbSubOperations() const
 SKGError SKGOperationObject::addSubOperation(SKGSubOperationObject& oSubOperation)
 {
         SKGError err;
-        if (getID() == 0) err=SKGError(ERR_FAIL, tr("%1 failed because linked object is not yet saved in the database.").arg("SKGOperationObject::addSubOperation"));
+        if (getID() == 0) err=SKGError(ERR_FAIL, i18n("%1 failed because linked object is not yet saved in the database.",QString("SKGOperationObject::addSubOperation")));
         else {
                 oSubOperation = SKGSubOperationObject(getDocument());
                 err = oSubOperation.setParentOperation(*this);
@@ -344,7 +359,7 @@ SKGError SKGOperationObject::addSubOperation(SKGSubOperationObject& oSubOperatio
 SKGError SKGOperationObject::getSubOperations(SKGListSKGObjectBase& oSubOperations) const
 {
         SKGError err;
-        if (getID() == 0) err=SKGError(ERR_FAIL, tr("%1 failed because linked object is not yet saved in the database.").arg("SKGOperationObject::getSubOperations"));
+        if (getID() == 0) err=SKGError(ERR_FAIL, i18n("%1 failed because linked object is not yet saved in the database.",QString("SKGOperationObject::getSubOperations")));
         else {
 
                 err=SKGObjectBase::getObjects(getDocument(), "v_suboperation",
@@ -358,6 +373,20 @@ double SKGOperationObject::getCurrentAmount() const
         return SKGServices::stringToDouble(getAttribute("f_CURRENTAMOUNT"));
 }
 
+double SKGOperationObject::getBalance() const
+{
+        double output=0.0;
+        SKGStringListList result;
+        SKGError err=SKGServices::executeSelectSqliteOrder(getDocument(), "SELECT TOTAL(f_CURRENTAMOUNT) FROM v_operation WHERE t_template='N' AND "
+                        "rd_account_id="+getAttribute("rd_account_id")+" AND (d_date<'"+getAttribute("d_date")+"' OR "
+                        "(d_date='"+getAttribute("d_date")+"' AND id<="+SKGServices::intToString(getID())+"))", result);
+        if (err.isSucceeded()) {
+                output=SKGServices::stringToDouble(result.at(1).at(0));
+        }
+
+        return output;
+}
+
 double SKGOperationObject::getAmount(const QDate& iDate) const
 {
         //Get quantity
@@ -381,7 +410,7 @@ double SKGOperationObject::getAmount(const QDate& iDate) const
 SKGError SKGOperationObject::addRecurrentOperation(SKGRecurrentOperationObject& oRecurrentOperation)
 {
         SKGError err;
-        if (getID() == 0) err=SKGError(ERR_FAIL, tr("%1 failed because linked object is not yet saved in the database.").arg("SKGOperationObject::addRecurrentOperation"));
+        if (getID() == 0) err=SKGError(ERR_FAIL, i18n("%1 failed because linked object is not yet saved in the database.",QString("SKGOperationObject::addRecurrentOperation")));
         else {
                 oRecurrentOperation = SKGRecurrentOperationObject(getDocument());
                 err = oRecurrentOperation.setParentOperation(*this);
@@ -393,7 +422,7 @@ SKGError SKGOperationObject::addRecurrentOperation(SKGRecurrentOperationObject&
 SKGError SKGOperationObject::getRecurrentOperations(SKGListSKGObjectBase& oRecurrentOperation) const
 {
         SKGError err;
-        if (getID() == 0) err=SKGError(ERR_FAIL, tr("%1 failed because linked object is not yet saved in the database.").arg("SKGOperationObject::getRecurrentOperation"));
+        if (getID() == 0) err=SKGError(ERR_FAIL, i18n("%1 failed because linked object is not yet saved in the database.",QString("SKGOperationObject::getRecurrentOperation")));
         else {
                 err=SKGObjectBase::getObjects(getDocument(), "v_recurrentoperation",
                                               "rd_operation_id="+ SKGServices::intToString(getID()), oRecurrentOperation);
