@@ -22,9 +22,11 @@
 #include "skgsuboperationobject.h"
 #include "skgoperationobject.h"
 #include "skgcategoryobject.h"
-#include "skgrefundtrackerobject.h"
+#include "skgtrackerobject.h"
 #include "skgservices.h"
 
+#include <klocale.h>
+
 SKGSubOperationObject::SKGSubOperationObject(const SKGDocument* iDocument, int iID): SKGObjectBase(iDocument, "v_suboperation", iID)
 {
 }
@@ -97,19 +99,25 @@ double SKGSubOperationObject::getQuantity() const
 }
 
 
-SKGError SKGSubOperationObject::setRefundTracker(const SKGRefundTrackerObject& iTracker)
+SKGError SKGSubOperationObject::setTracker(const SKGTrackerObject& iTracker)
 {
-        return setAttribute("r_refund_id", SKGServices::intToString(iTracker.getID()));
+        SKGError err;
+        if (iTracker.isClosed()) {
+                err=SKGError(ERR_FAIL, i18n("Impossible to add an operation in a closed tracker"));
+        } else {
+                err=setAttribute("r_refund_id", SKGServices::intToString(iTracker.getID()));
+        }
+        return err;
 }
 
-SKGError SKGSubOperationObject::getRefundTracker(SKGRefundTrackerObject& oTracker) const
+SKGError SKGSubOperationObject::getTracker(SKGTrackerObject& oTracker) const
 {
         SKGError err = getObject(getDocument(), "v_refund", "id=" + getAttribute("r_refund_id"), oTracker);
         return err;
 
 }
 
-SKGError SKGSubOperationObject::removeRefundTracker()
+SKGError SKGSubOperationObject::removeTracker()
 {
         return setAttribute("r_refund_id", "0");
 }
