@@ -23,15 +23,15 @@
  */
 
 #include "skgobjectbase.h"
-
+#include "skgbankmodeler_export.h"
 class SKGOperationObject;
 class SKGCategoryObject;
-class SKGRefundTrackerObject;
+class SKGTrackerObject;
 
 /**
  * This class manages suboperation object
  */
-class KDE_EXPORT SKGSubOperationObject : public SKGObjectBase
+class SKGBANKMODELER_EXPORT SKGSubOperationObject : public SKGObjectBase
 {
         Q_OBJECT;
 
@@ -112,27 +112,27 @@ public:
         virtual SKGError getCategory(SKGCategoryObject& oCategory) const;
 
         /**
-         * Set the refund tracker
-         * @param iTracker the refund tracker
+         * Set the tracker
+         * @param iTracker the tracker
          * @return an object managing the error
          *   @see SKGError
          */
-        virtual SKGError setRefundTracker(const SKGRefundTrackerObject& iTracker);
+        virtual SKGError setTracker(const SKGTrackerObject& iTracker);
 
         /**
-         * Get the refund tracker
-         * @param oTracker the refund tracker
+         * Get the tracker
+         * @param oTracker the tracker
          * @return an object managing the error
          *   @see SKGError
          */
-        virtual SKGError getRefundTracker(SKGRefundTrackerObject& oTracker) const;
+        virtual SKGError getTracker(SKGTrackerObject& oTracker) const;
 
         /**
-         * Remove the refund tracker
+         * Remove the tracker
          * @return an object managing the error
          *   @see SKGError
          */
-        virtual SKGError removeRefundTracker();
+        virtual SKGError removeTracker();
 
         /**
          * Set the quantity of the suboperation
