@@ -24,6 +24,8 @@
 #include "skgdocumentbank.h"
 #include "skgtraces.h"
 
+#include <klocale.h>
+
 #include <QRegExp>
 #include <math.h>
 
@@ -87,19 +89,19 @@ QStringList SKGUnitObject::getListofKnownCurrencies()
 {
         QStringList output;
         output
-        << tr("Euro (EUR)")
-        << tr("United States Dollar (USD)")
-        << tr("French Franc (FRF)")
-        << tr("Belgium Franc (BEF)")
-        << tr("Deutsche mark (DEM)")
-        << tr("Espana Peseta (ESP)")
-        << tr("Italian Lira (ITL)")
-        << tr("Pound sterling (GBP)")
-        << tr("Canadian dollar (CAD)")
-        << tr("CAC 40")
-        << tr("Dow Jones (DJIA)")
-        << tr("NASDAQ")
-        << tr("SBF 120")
+        << i18n("Euro (EUR)")
+        << i18n("United States Dollar (USD)")
+        << i18n("French Franc (FRF)")
+        << i18n("Belgium Franc (BEF)")
+        << i18n("Deutsche Mark (DEM)")
+        << i18n("Espana Peseta (ESP)")
+        << i18n("Italian Lira (ITL)")
+        << i18n("Pound Sterling (GBP)")
+        << i18n("Canadian Dollar (CAD)")
+        << i18n("CAC 40")
+        << i18n("Dow Jones (DJIA)")
+        << i18n("NASDAQ")
+        << i18n("SBF 120")
         ;
         return output;
 }
@@ -132,85 +134,85 @@ SKGError SKGUnitObject::createCurrencyUnit(const SKGDocumentBank* iDocument, con
                 QString seco=((SKGDocumentBank*) iDocument)->getSecondaryUnit();
 
                 //Principal units
-                if (iUnitName==tr("Euro (EUR)") || iUnitName=="EUR" || iUnitName==QString::fromUtf8("€")) {
+                if (iUnitName==i18n("Euro (EUR)") || iUnitName=="EUR" || iUnitName==QString::fromUtf8("€")) {
                         //Euro
-                        name=tr("Euro (EUR)");
+                        name=i18n("Euro (EUR)");
                         symbol=QString::fromUtf8("€");
-                        country=tr("Europe");
+                        country=i18n("Europe");
                         date=QDate(2002,1,1);
                         value=1;
                         type=(prim.isEmpty() || prim==symbol ? SKGUnitObject::PRIMARY : SKGUnitObject::CURRENCY);
-                } else if (iUnitName==tr("United States Dollar (USD)") || iUnitName=="USD" || iUnitName==QString::fromUtf8("$")) {
+                } else if (iUnitName==i18n("United States Dollar (USD)") || iUnitName=="USD" || iUnitName==QString::fromUtf8("$")) {
                         //US Dollar
-                        name=tr("United States dollar (USD)");
+                        name=i18n("United States dollar (USD)");
                         symbol=QString::fromUtf8("$");
-                        country=tr("United States");
+                        country=i18n("United States");
                         date=QDate(1959,1,1);
                         value=1;
                         type=(prim.isEmpty() || prim==symbol ? SKGUnitObject::PRIMARY : SKGUnitObject::CURRENCY);
-                } else if (iUnitName==tr("Canadian dollar (CAD)") || iUnitName=="CAD" || iUnitName==QString::fromUtf8("C$")) {
+                } else if (iUnitName==i18n("Canadian Dollar (CAD)") || iUnitName=="CAD" || iUnitName==QString::fromUtf8("C$")) {
                         //US Dollar
-                        name=tr("Canadian dollar (CAD)");
+                        name=i18n("Canadian dollar (CAD)");
                         symbol=QString::fromUtf8("C$");
-                        country=tr("Canada");
+                        country=i18n("Canada");
                         date=QDate(1858,1,1);
                         value=1;
                         type=(prim.isEmpty() || prim==symbol ? SKGUnitObject::PRIMARY : SKGUnitObject::CURRENCY);
-                } else if (iUnitName==tr("Pound sterling (GBP)") || iUnitName=="GBP" || iUnitName==QString::fromUtf8("£")) {
+                } else if (iUnitName==i18n("Pound Sterling (GBP)") || iUnitName=="GBP" || iUnitName==QString::fromUtf8("£")) {
                         //Lyre
-                        name=tr("Pound sterling (GBP)");
+                        name=i18n("Pound sterling (GBP)");
                         symbol=QString::fromUtf8("£");
-                        country=tr("United Kingdom");
+                        country=i18n("United Kingdom");
                         date=QDate(1990,9,8);
                         value=1;
                         type=(prim.isEmpty() || prim==symbol  ? SKGUnitObject::PRIMARY : SKGUnitObject::CURRENCY);
                 }
                 //Europeen units
-                else if (iUnitName==tr("French Franc (FRF)") || iUnitName=="FRF" || iUnitName=="F") {
+                else if (iUnitName==i18n("French Franc (FRF)") || iUnitName=="FRF" || iUnitName=="F") {
                         //Franc
-                        name=tr("French Franc (FRF)");
-                        symbol="F";
-                        country=tr("France");
+                        name=i18n("French Franc (FRF)");
+                        symbol='F';
+                        country=i18n("France");
                         date=QDate(1963,1,1);
                         value=1.0/6.55957;
                         type=(seco.isEmpty() || seco==symbol  ? SKGUnitObject::SECONDARY : SKGUnitObject::CURRENCY);
 
                         err=SKGUnitObject::createCurrencyUnit(iDocument, "EUR", parentUnit);
-                } else if (iUnitName==tr("Deutsche mark (DEM)") || iUnitName=="DEM" || iUnitName=="DM") {
+                } else if (iUnitName==i18n("Deutsche Mark (DEM)") || iUnitName=="DEM" || iUnitName=="DM") {
                         //Deutch mark
-                        name=tr("Deutsche mark (DEM)");
+                        name=i18n("Deutsche mark (DEM)");
                         symbol="DM";
-                        country=tr("Germany");
+                        country=i18n("Germany");
                         date=QDate(1948,1,1);
                         value=1.0/1.955083;
                         type=(seco.isEmpty() || seco==symbol  ? SKGUnitObject::SECONDARY : SKGUnitObject::CURRENCY);
 
                         err=SKGUnitObject::createCurrencyUnit(iDocument, "EUR", parentUnit);
-                } else if (iUnitName==tr("Espana Peseta (ESP)") || iUnitName=="ESP" || iUnitName=="P") {
+                } else if (iUnitName==i18n("Espana Peseta (ESP)") || iUnitName=="ESP" || iUnitName=="P") {
                         //Pesetas
-                        name=tr("Espana Peseta (ESP)");
-                        symbol="P";
-                        country=tr("Spain");
+                        name=i18n("Espana Peseta (ESP)");
+                        symbol='P';
+                        country=i18n("Spain");
                         date=QDate(1868,1,1);
                         value=1.0/166.386;
                         type=(seco.isEmpty() || seco==symbol  ? SKGUnitObject::SECONDARY : SKGUnitObject::CURRENCY);
 
                         err=SKGUnitObject::createCurrencyUnit(iDocument, "EUR", parentUnit);
-                } else if (iUnitName==tr("Italian Lira (ITL)") || iUnitName=="ITL" || iUnitName==QString::fromUtf8("£")) {
+                } else if (iUnitName==i18n("Italian Lira (ITL)") || iUnitName=="ITL" || iUnitName==QString::fromUtf8("£")) {
                         //Lyre
-                        name=tr("Italian Lira (ITL)");
+                        name=i18n("Italian Lira (ITL)");
                         symbol=QString::fromUtf8("£");
-                        country=tr("Italia");
+                        country=i18n("Italy");
                         date=QDate(1970,1,1);
                         value=1.0/1936.27;
                         type=(seco.isEmpty() || seco==symbol  ? SKGUnitObject::SECONDARY : SKGUnitObject::CURRENCY);
 
                         err=SKGUnitObject::createCurrencyUnit(iDocument, "EUR", parentUnit);
-                } else if (iUnitName==tr("Belgium Franc (BEF)") || iUnitName=="BEF" || iUnitName=="FB") {
+                } else if (iUnitName==i18n("Belgium Franc (BEF)") || iUnitName=="BEF" || iUnitName=="FB") {
                         //Lyre
-                        name=tr("Belgium Franc (BEF)");
+                        name=i18n("Belgium Franc (BEF)");
                         symbol="FB";
-                        country=tr("Belgium");
+                        country=i18n("Belgium");
                         date=QDate(1970,1,1);
                         value=1.0/40.3399;
                         type=(seco.isEmpty() || seco==symbol  ? SKGUnitObject::SECONDARY : SKGUnitObject::CURRENCY);
@@ -218,43 +220,43 @@ SKGError SKGUnitObject::createCurrencyUnit(const SKGDocumentBank* iDocument, con
                         err=SKGUnitObject::createCurrencyUnit(iDocument, "EUR", parentUnit);
                 }
                 //Indexes
-                else if (iUnitName==tr("CAC 40")) {
+                else if (iUnitName==i18n("CAC 40")) {
                         //US Dollar
                         name=iUnitName;
                         symbol=iUnitName;
-                        country=tr("France");
+                        country=i18n("France");
                         date=QDate(1987,1,1);
                         value=-1;
                         internet="^FCHI";
                         type=SKGUnitObject::INDEX;
-                } else if (iUnitName==tr("NASDAQ")) {
+                } else if (iUnitName==i18n("NASDAQ")) {
                         //NASDAQ
                         name=iUnitName;
                         symbol=iUnitName;
-                        country=tr("United States");
+                        country=i18n("United States");
                         date=QDate(1971,2,5);
                         value=-1;
                         internet="^IXIC";
                         type=SKGUnitObject::INDEX;
-                } else if (iUnitName==tr("Dow Jones (DJIA)") || iUnitName=="DJIA") {
+                } else if (iUnitName==i18n("Dow Jones (DJIA)") || iUnitName=="DJIA") {
                         //Dow Jones
                         name=iUnitName;
                         symbol="DJIA";
-                        country=tr("United States");
+                        country=i18n("United States");
                         date=QDate(1884,1,1);
                         value=-1;
                         internet="^DJI";
                         type=SKGUnitObject::INDEX;
-                } else if (iUnitName==tr("SBF 120")) {
+                } else if (iUnitName==i18n("SBF 120")) {
                         //SBF 120
                         name=iUnitName;
                         symbol=iUnitName;
-                        country=tr("France");
+                        country=i18n("France");
                         date=QDate(1990,12,31);
                         value=-1;
                         internet="^SBF120";
                         type=SKGUnitObject::INDEX;
-                } else err=SKGError(ERR_INVALIDARG, tr("Unknown unit [%1]").arg(iUnitName));
+                } else err=SKGError(ERR_INVALIDARG, i18n("Unknown unit [%1]",iUnitName));
 
                 //Point on primary unit
                 if (value==1 && err.isSucceeded() && (type==SKGUnitObject::CURRENCY || type==SKGUnitObject::SECONDARY)) {
@@ -381,7 +383,7 @@ SKGError SKGUnitObject::removeUnit()
 SKGError SKGUnitObject::addUnitValue(SKGUnitValueObject& oUnitValue)
 {
         SKGError err;
-        if (getID() == 0) err=SKGError(ERR_FAIL, tr("%1 failed because linked object is not yet saved in the database.").arg("SKGUnitObject::addUnitValue"));
+        if (getID() == 0) err=SKGError(ERR_FAIL, i18n("%1 failed because linked object is not yet saved in the database.",QString("SKGUnitObject::addUnitValue")));
         else {
                 oUnitValue = SKGUnitValueObject((SKGDocumentBank*) getDocument());
                 err = oUnitValue.setAttribute("rd_unit_id", SKGServices::intToString(getID()));
@@ -480,7 +482,7 @@ SKGError SKGUnitObject::split(double iRatio) const
                                                     " WHERE rd_unit_id="+SKGServices::intToString(getID()));
                 if (err.isSucceeded()) err=SKGServices::executeSqliteOrder(getDocument(), "UPDATE suboperation SET f_value=f_value*"+SKGServices::doubleToString(iRatio)+
                                                    " WHERE rd_operation_id IN (SELECT id FROM operation WHERE rc_unit_id="+SKGServices::intToString(getID())+')');
-        } else err=SKGError(ERR_INVALIDARG, tr("Invalid ratio. Ratio must be greater than 0."));
+        } else err=SKGError(ERR_INVALIDARG, i18n("Invalid ratio. Ratio must be greater than 0."));
         return err;
 }
 
