@@ -24,7 +24,7 @@
 
 #include "skgnamedobject.h"
 #include "skgerror.h"
-
+#include "skgbankmodeler_export.h"
 #include <QDate>
 
 class SKGUnitValueObject;
@@ -33,7 +33,7 @@ class SKGDocumentBank;
 /**
  * This class is a unit
  */
-class KDE_EXPORT SKGUnitObject : public SKGNamedObject
+class SKGBANKMODELER_EXPORT SKGUnitObject : public SKGNamedObject
 {
         Q_OBJECT;
         Q_ENUMS(UnitType);
