@@ -544,6 +544,74 @@ int main(int argc, char** argv)
                         SKGTEST("QIF:getValue", SKGServices::doubleToString(account.getCurrentAmount()), "1000000");
                 }
         }
+
+        {
+                //Test import bug 199818
+                SKGDocumentBank document1;
+                SKGTESTERROR("document1.initialize()", document1.initialize(), true);
+                SKGError err;
+                {
+                        //Scrope of the transaction
+                        SKGBEGINTRANSACTION(document1, "IMPORT", err);
+
+                        SKGImportExportManager imp1(&document1, SKGImportExportManager::QIF, getTestPath("IN")+"/skgtestimportqif/199818.qif");
+                        SKGTESTERROR("QIF.importFile", imp1.importFile(), true);
+                }
+
+                {
+                        SKGAccountObject account(&document1);
+                        SKGTESTERROR("QIF.setName", account.setName("199818"), true);
+                        SKGTESTERROR("QIF.load", account.load(), true);
+                        SKGTEST("QIF:getValue", SKGServices::doubleToString(account.getCurrentAmount()), "-345.64");
+                }
+        }
+
+        {
+                //Test import bug 201316
+                SKGDocumentBank document1;
+                SKGTESTERROR("document1.initialize()", document1.initialize(), true);
+                SKGError err;
+                {
+                        //Scrope of the transaction
+                        SKGBEGINTRANSACTION(document1, "IMPORT", err);
+
+                        SKGImportExportManager imp1(&document1, SKGImportExportManager::QIF, getTestPath("IN")+"/skgtestimportqif/201316.qif");
+                        SKGTESTERROR("QIF.importFile", imp1.importFile(), true);
+                }
+
+                {
+                        SKGStringListList listTmp;
+                        SKGTESTERROR("QIF.executeSelectSqliteOrder", SKGServices::executeSelectSqliteOrder (&document1,
+                                        "SELECT TOTAL(f_CURRENTAMOUNT),t_status FROM v_operation_display GROUP BY t_status ORDER BY t_status", listTmp ), true);
+                        SKGTEST("QIF:listTmp.count", listTmp.count(), 4);
+                        if (listTmp.count()==4) {
+                                SKGTEST("QIF:listTmp.at(1).at(0)", listTmp.at(1).at(0), "-10.0");
+                                SKGTEST("QIF:listTmp.at(2).at(0)", listTmp.at(2).at(0), "-100.0");
+                                SKGTEST("QIF:listTmp.at(3).at(0)", listTmp.at(3).at(0), "-1000.0");
+                        }
+                }
+        }
+
+        {
+                //Test import bug 201451
+                SKGDocumentBank document1;
+                SKGTESTERROR("document1.initialize()", document1.initialize(), true);
+                SKGError err;
+                {
+                        //Scrope of the transaction
+                        SKGBEGINTRANSACTION(document1, "IMPORT", err);
+
+                        SKGImportExportManager imp1(&document1, SKGImportExportManager::QIF, getTestPath("IN")+"/skgtestimportqif/201451.qif");
+                        SKGTESTERROR("QIF.importFile", imp1.importFile(), true);
+                }
+
+                {
+                        SKGAccountObject account(&document1);
+                        SKGTESTERROR("QIF.setName", account.setName("201451"), true);
+                        SKGTESTERROR("QIF.load", account.load(), true);
+                        SKGTEST("QIF:getValue", SKGServices::doubleToString(account.getCurrentAmount()), "-123.45");
+                }
+        }
         //End test
         SKGENDTEST();
 }
