@@ -65,6 +65,9 @@ int main(int argc, char** argv)
                 SKGTESTERROR("UNITVALUE:setDate", unitvalue1.setDate(SKGServices::stringToTime("1970-07-16").date()), true);
                 SKGTESTERROR("UNITVALUE:save", unitvalue1.save(), true);
 
+                SKGUnitValueObject unitvalue1bis=SKGUnitValueObject(unitvalue1);
+                SKGUnitValueObject unitvalue1ter=SKGUnitValueObject((SKGObjectBase) unitvalue1);
+
                 SKGUnitObject unit_get;
                 SKGTESTERROR("UNITVALUE:getUnit", unitvalue1.getUnit(unit_get), true);
                 SKGTEST("UNIT:comparison", (unit_get==unit1),true);
