@@ -30,6 +30,7 @@ SKGCalculatorEdit::SKGCalculatorEdit(QWidget *parent)
                 : KLineEdit(parent), lastValue(0), lastOperator(0)
 {
         setMode(CALCULATOR);
+        font_color = palette().color(QPalette::Text);
 }
 
 SKGCalculatorEdit::~SKGCalculatorEdit()
@@ -126,7 +127,10 @@ void SKGCalculatorEdit::keyPressEvent(int key)
                 }
         } else {
                 if (key==Qt::Key_Return) {
+                        QPalette field_palette = palette();
+
                         QString t=text();
+                        t.replace(',','.'); // Replace comma by a point in case of typo
                         QScriptEngine myEngine;
                         QScriptValue result = myEngine.evaluate(t);
                         if (result.isNumber()) {
@@ -134,8 +138,19 @@ void SKGCalculatorEdit::keyPressEvent(int key)
                                 if (t.length()>0 && t[0]=='+' && result.toNumber()>0) res='+';
                                 res+=result.toString();
                                 setText(res);
+                                field_palette.setColor(QPalette::Text,font_color);
                         }
+                        // The result is not a number,
+                        // * display the original string so thatso that user can correct it.
+                        // * set the widget's base color to red for better visualization
+                        else {
+                                setText(t);
+                                field_palette.setColor(QPalette::Text,Qt::red);
+
+                        }
+                        setPalette(field_palette);
                 }
+
         }
 }
 
