@@ -37,7 +37,7 @@
 #include <qmath.h>
 
 SKGGraphicsView::SKGGraphicsView ( QWidget *parent )
-                : QWidget ( parent )
+                : QWidget ( parent ), toolBarVisible(false)
 {
         ui.setupUi ( this );
 
@@ -160,13 +160,14 @@ void SKGGraphicsView::showMenu ( const QPoint& pos )
 
 void SKGGraphicsView::setToolBarVisible ( bool iVisibility )
 {
-        ui.toolBar->setVisible ( iVisibility );
-        if ( actShowToolBar ) actShowToolBar->setChecked ( iVisibility );
+        toolBarVisible=iVisibility;
+        ui.toolBar->setVisible ( toolBarVisible );
+        if ( actShowToolBar ) actShowToolBar->setChecked ( toolBarVisible );
 }
 
 bool SKGGraphicsView::isToolBarVisible() const
 {
-        return ui.toolBar->isVisible();
+        return toolBarVisible;
 }
 
 void SKGGraphicsView::onSwitchToolBarVisibility()
@@ -176,7 +177,7 @@ void SKGGraphicsView::onSwitchToolBarVisibility()
 
 void SKGGraphicsView::onSwitchAntialiasing()
 {
-        if ( actAntialiasing ) ui.kGraphicsView->setRenderHint ( QPainter::Antialiasing, actAntialiasing->isChecked() );
+        if ( actAntialiasing ) ui.kGraphicsView->setRenderHint (QPainter::Antialiasing, actAntialiasing->isChecked() );
 }
 
 void SKGGraphicsView::onZoom()
@@ -218,12 +219,13 @@ void SKGGraphicsView::onPrint()
 {
         _SKGTRACEIN ( 10, "SKGGraphicsView::onPrint" );
         QPrinter printer;
-        QPrintDialog dialog ( &printer, this );
-        if ( dialog.exec() == QDialog::Accepted ) {
+        QPointer<QPrintDialog> dialog=new QPrintDialog(&printer, this);
+        if ( dialog->exec() == QDialog::Accepted ) {
                 QPainter painter ( &printer );
                 ui.kGraphicsView->render ( &painter );
                 painter.end();
         }
+        delete dialog;
 }
 
 void SKGGraphicsView::onSavePDF()
