@@ -26,7 +26,7 @@
 #include <kglobal.h>
 #include <QWidget>
 #include <QtDesigner/QDesignerExportWidget>
-
+#include "skgbasegui_export.h"
 class QGraphicsScene;
 class QGraphicsView;
 class KMenu;
@@ -35,7 +35,7 @@ class QAction;
 /**
  * This file is a Graphic view with more functionalities for skrooge
  */
-class KDE_EXPORT SKGGraphicsView : public QWidget
+class SKGBASEGUI_EXPORT SKGGraphicsView : public QWidget
 {
         Q_OBJECT
         Q_PROPERTY( QString state READ getState WRITE setState USER true)
@@ -164,6 +164,7 @@ private:
         KMenu* mainMenu;
         QAction* actShowToolBar;
         QAction* actAntialiasing;
+        bool toolBarVisible;
 };
 
 #endif // SKGGRAPHICSVIEW_H
