@@ -27,6 +27,11 @@ SKGInterfacePlugin::SKGInterfacePlugin(QObject * parent)
 SKGInterfacePlugin::~SKGInterfacePlugin()
 {}
 
+void SKGInterfacePlugin::processArguments(const QStringList& iArgument)
+{
+        Q_UNUSED(iArgument);
+}
+
 void SKGInterfacePlugin::close() {}
 
 void SKGInterfacePlugin::refresh() {}
@@ -41,8 +46,20 @@ SKGTabWidget* SKGInterfacePlugin::getWidget()
         return NULL;
 }
 
-SKGWidget* SKGInterfacePlugin::getDashboardWidget()
+int SKGInterfacePlugin::getNbDashboardWidgets()
 {
+        return 0;
+}
+
+QString SKGInterfacePlugin::getDashboardWidgetTitle(int iIndex)
+{
+        Q_UNUSED(iIndex);
+        return "";
+}
+
+SKGWidget* SKGInterfacePlugin::getDashboardWidget(int iIndex)
+{
+        Q_UNUSED(iIndex);
         return NULL;
 }
 
