@@ -27,7 +27,7 @@
 #include "skgdocument.h"
 #include "skgtabwidget.h"
 #include "skgerror.h"
-
+#include "skgbasegui_export.h"
 class SKGMainPanel;
 class KConfigSkeleton;
 class QDockWidget;
@@ -35,7 +35,7 @@ class QDockWidget;
 /**
  * This file is Skrooge plugin interface definition.
  */
-class KDE_EXPORT SKGInterfacePlugin : public KParts::Plugin
+class SKGBASEGUI_EXPORT SKGInterfacePlugin : public KParts::Plugin
 {
         Q_OBJECT ;
 public:
@@ -53,11 +53,16 @@ public:
 
         /**
          * Called to initialise the plugin
-         * @param iParent the SKGMainPanel main panel parent
          * @param iDocument the SKGDocumentBank main document
          * @param iArgument the arguments
          */
-        virtual void setupActions(SKGMainPanel* iParent, SKGDocument* iDocument, const QStringList& iArgument) =0;
+        virtual void setupActions(SKGDocument* iDocument, const QStringList& iArgument) =0;
+
+        /**
+         * This function is called when the application is launched again with new arguments
+         * @param iArgument the arguments
+         */
+        virtual void processArguments(const QStringList& iArgument);
 
         /**
          * Must be modified to close properly the plugin.
@@ -76,10 +81,24 @@ public:
         virtual SKGTabWidget* getWidget();
 
         /**
-         * The dashboard widget of the plugin.
+         * The number of dashboard widgets of the plugin.
+         * @return The number of dashboard widgets of the plugin
+         */
+        virtual int getNbDashboardWidgets();
+
+        /**
+         * Get a dashboard widget title of the plugin.
+         * @param iIndex the index of the widget
+         * @return The title
+         */
+        virtual QString getDashboardWidgetTitle(int iIndex);
+
+        /**
+         * Get a dashboard widget of the plugin.
+         * @param iIndex the index of the widget
          * @return The dashboard widget of the plugin
          */
-        virtual SKGWidget* getDashboardWidget();
+        virtual SKGWidget* getDashboardWidget(int iIndex);
 
         /**
          * The dock widget of the plugin.
