@@ -23,7 +23,7 @@
 #include "skgtraces.h"
 #include "skgservices.h"
 #include "skginterfaceplugin.h"
-#include "skrooge.h"
+#include "skgbasegui_settings.h"
 #include "skgtransactionmng.h"
 
 #include <KTemporaryFile>
@@ -50,6 +50,7 @@
 #include <kcombobox.h>
 #include <kselectaction.h>
 #include <kstandarddirs.h>
+#include <kstringhandler.h>
 
 #include <QtGui/QProgressBar>
 #include <QtGui/QHeaderView>
@@ -58,6 +59,7 @@
 #include <QResizeEvent>
 
 bool SKGMainPanel::currentActionCanceled=false;
+SKGMainPanel* SKGMainPanel::mainPanel=NULL;
 SKGMainPanel::SKGMainPanel ( KSplashScreen* iSplashScreen, SKGDocument* iDocument, const QStringList& iArguments )
                 : KParts::MainWindow(),
                 tabView ( new KTabWidget ( this ) ),
@@ -68,6 +70,19 @@ SKGMainPanel::SKGMainPanel ( KSplashScreen* iSplashScreen, SKGDocument* iDocumen
 {
         SKGTRACEIN ( 1, "SKGMainPanel::SKGMainPanel" );
 
+        KSharedConfigPtr config=KSharedConfig::openConfig ( "skroogerc" );
+        KConfigGroup prefskg=config->group ( "skrooge" );
+        if (prefskg.readEntry ( "update_modified_contexts", 100)==100) {
+                //First call, we set default values
+                prefskg.writeEntry ( "update_modified_contexts", 2 );
+
+                KConfigGroup pref=config->group ( "Notification Messages" );
+                pref.writeEntry ( "updateContextOnClose", false );
+        }
+
+        //Set main panel
+        mainPanel=this;
+
         // accept dnd
         setAcceptDrops ( true );
 
@@ -76,9 +91,9 @@ SKGMainPanel::SKGMainPanel ( KSplashScreen* iSplashScreen, SKGDocument* iDocumen
         // tell the KXmlGuiWindow that this is indeed the main widget
         setCentralWidget ( tabView );
 
+        refreshTabPosition();
         tabView->setTabReorderingEnabled ( true );
-        tabView->setHoverCloseButton ( true );
-        tabView->setHoverCloseButtonDelayed ( true );
+        tabView->setTabsClosable ( true );
         tabView->setTabCloseActivatePrevious ( true );
         tabView->setAutomaticResizeTabs ( true );
         tabView->setTabBarHidden ( false );
@@ -116,55 +131,50 @@ SKGMainPanel::SKGMainPanel ( KSplashScreen* iSplashScreen, SKGDocument* iDocumen
         //Load plugins
         int nb=offers.count();
         SKGTRACEL ( 1 ) << nb << " plugins found" << endl;
-        if ( spScreen ) spScreen->showMessage ( i18n ( "Loading plugins..." ), Qt::AlignLeft, QColor ( 221, 130, 8 ) ); // krazy:exclude=doublequote_chars
+        if ( spScreen ) spScreen->showMessage ( i18n ( "Loading plugins..." ), Qt::AlignLeft, QColor ( 221, 130, 8 ) ); // krazy:exclude=qmethods
         SKGError err;
         for ( int i=0; i<nb; ++i ) {
                 KService::Ptr service = offers.at ( i );
                 QString name=service->name();
+                QString id=service->property("X-Krunner-ID", QVariant::String).toString();
                 QString msg=i18n ( "Loading plugin %1/%2: %3...", i+1, nb, name );
                 SKGTRACEL ( 1 ) << msg << endl;
-                if ( spScreen ) spScreen->showMessage ( msg, Qt::AlignLeft, QColor ( 221, 130, 8 ) );
+                if ( spScreen ) spScreen->showMessage ( msg, Qt::AlignLeft, QColor ( 221, 130, 8 ) ); // krazy:exclude=qmethods
                 KPluginLoader loader ( service->library() );
                 KPluginFactory *factory =loader.factory();
                 if ( factory ) {
                         SKGInterfacePlugin *pluginInterface = factory->create<SKGInterfacePlugin> ( this );
-                        if ( pluginInterface ) {
-                                if ( pluginInterface->isEnabled() ) {
-                                        pluginInterface->setupActions ( this, currentBankDocument, iArguments );
+                        if ( pluginInterface && pluginInterface->isEnabled()) {
+                                pluginInterface->setupActions(currentBankDocument, iArguments);
 
-                                        //Store plugin
-                                        int nbplugin=pluginsList.count();
-                                        int pos=nbplugin;
-                                        for ( int j=nbplugin-1; j>=0; --j ) {
-                                                if ( pluginInterface->getOrder() <pluginsList.at ( j )->getOrder() ) {
-                                                        pos=j;
-                                                }
+                                //Store plugin
+                                int nbplugin=pluginsList.count();
+                                int pos=nbplugin;
+                                for ( int j=nbplugin-1; j>=0; --j ) {
+                                        if ( pluginInterface->getOrder() <pluginsList.at ( j )->getOrder() ) {
+                                                pos=j;
                                         }
+                                }
 
-                                        pluginsList.insert ( pos, pluginInterface );
-                                        pluginInterface->setObjectName ( name );
+                                pluginsList.insert ( pos, pluginInterface );
+                                pluginInterface->setObjectName ( id );
 
-                                        //Build temporary tips file
-                                        if ( tipsFileOpened ) {
-                                                QStringList tipsList=pluginInterface->tips();
-                                                int nbtips=tipsList.count();
-                                                for ( int t=0; t<nbtips; ++t ) {
-                                                        tipsFound=true;
-                                                        stream << "<tip category=\""
-                                                        << name
-                                                        << "\"><html>"<< tipsList.at ( t )
-                                                        << "</html></tip>"
-                                                        << endl;
-                                                }
+                                //Build temporary tips file
+                                if ( tipsFileOpened ) {
+                                        QStringList tipsList=pluginInterface->tips();
+                                        int nbtips=tipsList.count();
+                                        for ( int t=0; t<nbtips; ++t ) {
+                                                tipsFound=true;
+                                                stream << "<tip category=\""
+                                                << id
+                                                << "\"><html>"<< SKGServices::stringToHtml(tipsList.at ( t ))
+                                                << "</html></tip>"
+                                                << endl;
                                         }
                                 }
-                        } else {
-                                err.addError ( ERR_FAIL, i18n ( "Plugin's interface %1 not found in %2", name, service->library() ) );
                         }
                 } else {
-                        SKGTRACEL ( 1 ) << loader.errorString() << endl;
-                        err.addError ( ERR_FAIL, loader.errorString() );
-                        err.addError ( ERR_FAIL, i18n ( "Loading plugin %1 failed because the factory could not be found in %2", name, service->library() ) );
+                        currentBankDocument->sendMessage(i18n ( "Loading plugin %1 failed because the factory could not be found in %2", id, service->library() ));
                 }
         }
 
@@ -225,6 +235,7 @@ SKGMainPanel::SKGMainPanel ( KSplashScreen* iSplashScreen, SKGDocument* iDocumen
 
         //Add plugin in client in right order
         int shortCutIndex=0;
+        QString shortCutPrefix="Ctrl+";
         int nbplugin=pluginsList.count();
         for ( int j=0; j<nbplugin; ++j ) {
                 SKGInterfacePlugin *pluginInterface=pluginsList.at ( j );
@@ -250,8 +261,16 @@ SKGMainPanel::SKGMainPanel ( KSplashScreen* iSplashScreen, SKGDocument* iDocumen
                                         if (action) {
                                                 action->setCheckable(false);
                                                 action->setData(j);
-                                                ++shortCutIndex;
-                                                action->setShortcut("Ctrl+"+SKGServices::intToString(shortCutIndex));
+                                                if (!shortCutPrefix.isEmpty()) {
+                                                        ++shortCutIndex;
+                                                        if (shortCutIndex==10) shortCutIndex=0;
+                                                        action->setShortcut(shortCutPrefix+SKGServices::intToString(shortCutIndex));
+
+                                                        if (shortCutIndex==0) {
+                                                                if (shortCutPrefix=="Ctrl+") shortCutPrefix+="Alt+";
+                                                                else shortCutPrefix="";
+                                                        }
+                                                }
                                                 connect(action, SIGNAL(triggered(bool)), this, SLOT(onOpenContext()));
                                         }
                                 }
@@ -367,6 +386,13 @@ SKGMainPanel::~SKGMainPanel()
         kNormalMessage=NULL;
 }
 
+void SKGMainPanel::processArguments(const QStringList& iArgument)
+{
+        foreach(SKGInterfacePlugin * plugin, pluginsList) {
+                if (plugin) plugin->processArguments(iArgument);
+        }
+}
+
 void SKGMainPanel::registedGlobalAction ( const QString& iIdentifier, KAction* iAction )
 {
         registeredGlogalAction[iIdentifier]=iAction;
@@ -413,7 +439,7 @@ void SKGMainPanel::setupActions()
         // New Tab
         addTabAction = new KAction ( KIcon ( "tab-new-background" ), i18n ( "New &Tab" ), this );
         actionCollection()->addAction ( QLatin1String ( "new_tab" ), addTabAction );
-        addTabAction->setShortcut ( Qt::CTRL + Qt::Key_T );
+        addTabAction->setShortcut ( Qt::CTRL + Qt::SHIFT + Qt::Key_W );
         connect ( addTabAction,SIGNAL ( triggered() ), this, SLOT ( addTab() ) );
 
         registedGlobalAction ( "tab-new-background", addTabAction );
@@ -439,13 +465,27 @@ void SKGMainPanel::setupActions()
 
         registedGlobalAction ( "tab_closeallother", closeAllOtherPagesAction );
 
-        saveDefaultStateAction = new KAction ( KIcon ( "document-save" ), i18n ( "Save state as default" ), this );
+        saveDefaultStateAction = new KAction ( KIcon ( "document-save" ), i18n ( "Save context state" ), this );
         actionCollection()->addAction ( QLatin1String ( "tab_savedefaultstate" ), saveDefaultStateAction );
         saveDefaultStateAction->setShortcut ( Qt::CTRL + Qt::ALT +Qt::Key_S );
         connect ( saveDefaultStateAction,SIGNAL ( triggered() ), this, SLOT ( saveDefaultState() ) );
 
         registedGlobalAction ( "tab_savedefaultstate", saveDefaultStateAction );
 
+        resetDefaultStateAction = new KAction ( KIcon ( "edit-clear" ), i18n ( "Reset context state" ), this );
+        actionCollection()->addAction ( QLatin1String ( "tab_resetdefaultstate" ), resetDefaultStateAction );
+        resetDefaultStateAction->setShortcut ( Qt::CTRL + Qt::ALT +Qt::Key_R );
+        connect ( resetDefaultStateAction,SIGNAL ( triggered() ), this, SLOT ( resetDefaultState() ) );
+
+        registedGlobalAction ( "tab_resetdefaultstate", resetDefaultStateAction );
+
+        overwriteBookmarkStateAction = new KAction ( KIcon ( "document-save" ), i18n ( "Overwrite bookmark state" ), this );
+        actionCollection()->addAction ( QLatin1String ( "tab_overwritebookmark" ), overwriteBookmarkStateAction );
+        connect ( overwriteBookmarkStateAction,SIGNAL ( triggered() ), this, SLOT ( overwriteBookmarkState() ) );
+        overwriteBookmarkStateAction->setShortcut ( Qt::CTRL + Qt::SHIFT +Qt::Key_S );
+
+        registedGlobalAction ( "tab_overwritebookmark", overwriteBookmarkStateAction );
+
         tipOfDayAction=KStandardAction::tipOfDay ( this, SLOT ( onTipOfDay() ), actionCollection() );
 
         //Contextual menu
@@ -457,7 +497,9 @@ void SKGMainPanel::setupActions()
         QAction* sep=new QAction ( this );
         sep->setSeparator ( true );
         tabView->insertAction ( 0, sep );
+        tabView->insertAction ( 0, getGlobalAction ( "tab_resetdefaultstate" ) );
         tabView->insertAction ( 0, getGlobalAction ( "tab_savedefaultstate" ) );
+        tabView->insertAction ( 0, getGlobalAction ( "tab_overwritebookmark" ) );
 }
 
 bool SKGMainPanel::queryClose()
@@ -484,7 +526,7 @@ bool SKGMainPanel::queryFileClose()
         bool output=true;
         if ( currentBankDocument->getCurrentTransaction() ) {
                 QApplication::setOverrideCursor ( QCursor ( Qt::ArrowCursor ) );
-                KMessageBox::information ( this,i18n ( "Application can be closed until an operation is running." ) );
+                KMessageBox::information ( this,i18n ( "Skrooge cannot be closed when an operation is running." ) );
                 QApplication::restoreOverrideCursor();
                 output=false;
         } else if ( currentBankDocument->isFileModified() && currentBankDocument->getDatabaseMode() !=SKGDocument::DirectAccess ) {
@@ -537,20 +579,35 @@ void SKGMainPanel::optionsPreferences()
 {
         SKGTRACEIN ( 1, "SKGMainPanel::optionsPreferences" );
         //Synchronize setting with confirmation panel
-        KMessageBox::ButtonCode confirm;
-        int ask=KMessageBox::shouldBeShownYesNo ( "updateBookmarkOnClose", confirm );
+        {
+                KMessageBox::ButtonCode confirm;
+                int ask=KMessageBox::shouldBeShownYesNo ( "updateBookmarkOnClose", confirm );
 
-        KSharedConfigPtr config=KSharedConfig::openConfig ( "skroogerc" );
-        KConfigGroup pref=config->group ( "skrooge" );
-        if ( ask ) {
-                pref.writeEntry ( "update_modified_bookmarks", 0 );
-        } else if ( confirm==KMessageBox::Yes ) {
-                pref.writeEntry ( "update_modified_bookmarks", 1 );
-        } else {
-                pref.writeEntry ( "update_modified_bookmarks", 2 );
+                KSharedConfigPtr config=KSharedConfig::openConfig ( "skroogerc" );
+                KConfigGroup pref=config->group ( "skrooge" );
+                if ( ask ) {
+                        pref.writeEntry ( "update_modified_bookmarks", 0 );
+                } else if ( confirm==KMessageBox::Yes ) {
+                        pref.writeEntry ( "update_modified_bookmarks", 1 );
+                } else {
+                        pref.writeEntry ( "update_modified_bookmarks", 2 );
+                }
         }
+        {
+                KMessageBox::ButtonCode confirm;
+                int ask=KMessageBox::shouldBeShownYesNo ( "updateContextOnClose", confirm );
 
-        skrooge::self()->readConfig();
+                KSharedConfigPtr config=KSharedConfig::openConfig ( "skroogerc" );
+                KConfigGroup pref=config->group ( "skrooge" );
+                if ( ask ) {
+                        pref.writeEntry ( "update_modified_contexts", 0 );
+                } else if ( confirm==KMessageBox::Yes ) {
+                        pref.writeEntry ( "update_modified_contexts", 1 );
+                } else {
+                        pref.writeEntry ( "update_modified_contexts", 2 );
+                }
+        }
+        skgbasegui_settings::self()->readConfig();
 
         // The preference dialog is derived from prefs_base.ui
         //
@@ -560,12 +617,12 @@ void SKGMainPanel::optionsPreferences()
         if ( KConfigDialog::showDialog ( "settings" ) )  {
                 return;
         }
-        KConfigDialog *dialog = new KConfigDialog ( this, "settings", skrooge::self() );
+        KConfigDialog *dialog = new KConfigDialog ( this, "settings", skgbasegui_settings::self() );
 
         //Add main
         QWidget* widget=new QWidget();
         uipref.setupUi ( widget );
-        dialog->addPage ( widget, skrooge::self(), i18n ( "General" ), "preferences-other" );
+        dialog->addPage ( widget, skgbasegui_settings::self(), i18n ( "General" ), "preferences-other" );
 
         //Add plugin in client in right order
         int nbplugin=pluginsList.count();
@@ -587,6 +644,14 @@ void SKGMainPanel::optionsPreferences()
         refresh();
 }
 
+void SKGMainPanel::refreshTabPosition()
+{
+        KSharedConfigPtr config=KSharedConfig::openConfig ( "skroogerc" );
+        KConfigGroup pref=config->group ( "skrooge" );
+        QTabWidget::TabPosition tabposition=(QTabWidget::TabPosition) pref.readEntry ( "main_tabs_position", 0 );
+        tabView->setTabPosition(tabposition);
+}
+
 void SKGMainPanel::onSettingsChanged()
 {
         SKGError err;
@@ -606,27 +671,53 @@ void SKGMainPanel::onSettingsChanged()
                 if ( iconInSystemtray() ) kSystemTrayIcon->show();
                 else kSystemTrayIcon->hide();
 
-                //
+                //Setting for tab position
+                refreshTabPosition();
+
+                //Setting for bookmarks modification
                 KSharedConfigPtr config=KSharedConfig::openConfig ( "skroogerc" );
                 KConfigGroup pref=config->group ( "skrooge" );
-                int option=pref.readEntry ( "update_modified_bookmarks", 0 );
+                {
+                        int option=pref.readEntry ( "update_modified_bookmarks", 0 );
 
-                KConfigGroup prefNotificationMessages=config->group ( "Notification Messages" );
-                if ( option==0 ) {
-                        //ASK: remove following setting
-                        //[Notification Messages]
-                        //updateBookmarkOnClose=false
-                        prefNotificationMessages.deleteEntry ( "updateBookmarkOnClose" );
-                } else if ( option==1 ) {
-                        //ALWAYS: set following setting
-                        //[Notification Messages]
-                        //updateBookmarkOnClose=true
-                        prefNotificationMessages.writeEntry ( "updateBookmarkOnClose", true );
-                } else {
-                        //NEVER: set following setting
-                        //[Notification Messages]
-                        //updateBookmarkOnClose=false
-                        prefNotificationMessages.writeEntry ( "updateBookmarkOnClose", false );
+                        KConfigGroup prefNotificationMessages=config->group ( "Notification Messages" );
+                        if ( option==0 ) {
+                                //ASK: remove following setting
+                                //[Notification Messages]
+                                //updateBookmarkOnClose=false
+                                prefNotificationMessages.deleteEntry ( "updateBookmarkOnClose" );
+                        } else if ( option==1 ) {
+                                //ALWAYS: set following setting
+                                //[Notification Messages]
+                                //updateBookmarkOnClose=true
+                                prefNotificationMessages.writeEntry ( "updateBookmarkOnClose", true );
+                        } else {
+                                //NEVER: set following setting
+                                //[Notification Messages]
+                                //updateBookmarkOnClose=false
+                                prefNotificationMessages.writeEntry ( "updateBookmarkOnClose", false );
+                        }
+                }
+                {
+                        int option=pref.readEntry ( "update_modified_contexts", 2 );
+
+                        KConfigGroup prefNotificationMessages=config->group ( "Notification Messages" );
+                        if ( option==0 ) {
+                                //ASK: remove following setting
+                                //[Notification Messages]
+                                //updateContextOnClose=false
+                                prefNotificationMessages.deleteEntry ( "updateContextOnClose" );
+                        } else if ( option==1 ) {
+                                //ALWAYS: set following setting
+                                //[Notification Messages]
+                                //updateContextOnClose=true
+                                prefNotificationMessages.writeEntry ( "updateContextOnClose", true );
+                        } else {
+                                //NEVER: set following setting
+                                //[Notification Messages]
+                                //updateContextOnClose=false
+                                prefNotificationMessages.writeEntry ( "updateContextOnClose", false );
+                        }
                 }
         }
         QApplication::restoreOverrideCursor();
@@ -655,7 +746,11 @@ void SKGMainPanel::refresh()
         closeAllOtherPagesAction->setEnabled ( tabView->count() >1 );
 
         SKGTabWidget* toSave= (SKGTabWidget*) tabView->currentWidget();
-        saveDefaultStateAction->setEnabled(toSave && !(toSave->getDefaultStateAttibute().isEmpty()));
+        if (toSave) {
+                if (saveDefaultStateAction) saveDefaultStateAction->setEnabled(toSave && !(toSave->getDefaultStateAttribute().isEmpty()));
+                if (resetDefaultStateAction) resetDefaultStateAction->setEnabled(toSave && !(toSave->getDefaultStateAttribute().isEmpty()));
+                if (overwriteBookmarkStateAction) overwriteBookmarkStateAction->setEnabled(toSave && !(toSave->getBookmarkID().isEmpty()));
+        }
 
         //Set window title
         QString modified;
@@ -691,7 +786,7 @@ SKGTabWidget* SKGMainPanel::setNewTabContent ( SKGInterfacePlugin* plugin, int i
 
                         QString param=parameters;
                         if (param.isEmpty()) {
-                                QString def=w->getDefaultStateAttibute();
+                                QString def=w->getDefaultStateAttribute();
                                 if (!def.isEmpty()) {
                                         param=currentBankDocument->getParameter(def);
                                 }
@@ -700,10 +795,12 @@ SKGTabWidget* SKGMainPanel::setNewTabContent ( SKGInterfacePlugin* plugin, int i
                         connect ( w, SIGNAL ( selectionChanged() ), SLOT ( refresh() ) );
 
                         if ( index==-1 ) {
+                                SKGTRACEIN ( 20, "SKGMainPanel::setNewTabContent-addTab" );
                                 tabView->addTab ( w, KIcon ( plugin->icon() ), title2 );
                                 tabView->setCurrentWidget ( w );
 
                         } else {
+                                SKGTRACEIN ( 20, "SKGMainPanel::setNewTabContent-insertTab" );
                                 tabView->insertTab ( index, w, KIcon ( plugin->icon() ), title2 );
                                 tabView->setCurrentWidget ( w );
 
@@ -798,16 +895,57 @@ void SKGMainPanel::saveDefaultState()
         QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
         SKGTabWidget* toSave= (SKGTabWidget*) tabView->currentWidget();
         if (toSave) {
-                QString name=toSave->getDefaultStateAttibute();
+                //Get bookmarks uuid
+                QString uuid=toSave->getBookmarkID();
+
+                //Reset bookmarks uuid to overwrite context state
+                toSave->setBookmarkID("");
+
+                //Overwrite
+                toSave->overwrite(false);
+
+                //Set original bookmarks uuid
+                toSave->setBookmarkID(uuid);
+        }
+        QApplication::restoreOverrideCursor();
+}
+
+void SKGMainPanel::overwriteBookmarkState()
+{
+        SKGTRACEIN ( 1, "SKGMainPanel::overwriteBookmarkState" );
+        SKGError err;
+
+        QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
+        SKGTabWidget* toSave= (SKGTabWidget*) tabView->currentWidget();
+        if (toSave) {
+                //Get bookmarks uuid
+                QString uuid=toSave->getBookmarkID();
+                if (!uuid.isEmpty()) {
+                        //Overwrite
+                        toSave->overwrite(false);
+                }
+        }
+        QApplication::restoreOverrideCursor();
+}
+
+void SKGMainPanel::resetDefaultState()
+{
+        SKGTRACEIN ( 1, "SKGMainPanel::resetDefaultState" );
+        SKGError err;
+
+        QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
+        SKGTabWidget* toSave= (SKGTabWidget*) tabView->currentWidget();
+        if (toSave) {
+                QString name=toSave->getDefaultStateAttribute();
                 if (!name.isEmpty()) {
-                        SKGBEGINTRANSACTION ( *currentBankDocument, i18n ( "Save default parameters" ), err );
-                        err=currentBankDocument->setParameter ( name, toSave->getState() );
+                        SKGBEGINTRANSACTION ( *currentBankDocument, i18n ( "Reset default state" ), err );
+                        err=currentBankDocument->setParameter ( name, "" );
                 }
         }
         QApplication::restoreOverrideCursor();
 
         //status bar
-        if (err.isSucceeded()) err=SKGError(0, i18n("Defaut state saved"));
+        if (err.isSucceeded()) err=SKGError(0, i18n("Default state has been reset"));
         displayErrorMessage ( err );
 }
 
@@ -864,7 +1002,7 @@ void SKGMainPanel::onTipOfDay()
         }
 }
 
-void SKGMainPanel::onTrayActivated ( KSystemTrayIcon::ActivationReason reason )
+void SKGMainPanel::onTrayActivated ( QSystemTrayIcon::ActivationReason reason )
 {
         SKGTRACEIN ( 1, "SKGMainPanel::onTrayActivated" );
         if ( reason==KSystemTrayIcon::Trigger ) {
@@ -924,14 +1062,15 @@ void SKGMainPanel::displayErrorMessage ( const SKGError& iError )
 
         if ( iError.isFailed() ) {
                 QApplication::setOverrideCursor ( QCursor ( Qt::ArrowCursor ) );
-                int rc=KMessageBox::warningContinueCancel ( parent, iError.getFullMessage(),
-                                i18n ( "Warning" ),
-                                KStandardGuiItem::cont(),
-                                KGuiItem ( i18n ( "History" ), KIcon ( "dialog-information" ) ) );
-                QApplication::restoreOverrideCursor();
+                int rc=KMessageBox::Cancel;
+                if (iError.getHistoricalSize()) rc=KMessageBox::warningContinueCancel ( parent, iError.getFullMessage(),
+                                                           i18n ( "Error" ),
+                                                           KStandardGuiItem::cont(),
+                                                           KGuiItem ( i18n ( "History" ), KIcon ( "dialog-information" ) ) );
                 if ( rc==KMessageBox::Cancel ) {
-                        KMessageBox::information ( parent, iError.getFullMessageWithHistorical(), i18n ( "History" ) );
+                        KMessageBox::error ( parent, iError.getFullMessageWithHistorical(), i18n ( "Error" ) );
                 }
+                QApplication::restoreOverrideCursor();
         } else {
                 //Status bar
                 SKGMainPanel *parent2 = qobject_cast<SKGMainPanel *> ( parent );
@@ -1007,29 +1146,51 @@ QString SKGMainPanel::getSaveFileName ( const KUrl & startDir, const QString & f
 
 }
 
-void SKGMainPanel::fillComboWithDistinctValue (
-        KComboBox* iComboBox,
+void SKGMainPanel::fillWithDistinctValue (
+        QWidget* iWidget,
         const SKGDocument* iDoc,
         const QString& iTable,
         const QString& iAttribut,
         const QString& iWhereClause )
 {
-        SKGTRACEIN ( 10, "SKGMainPanel::fillComboWithDistinctValue" );
+        SKGTRACEIN ( 10, "SKGMainPanel::fillWithDistinctValue" );
 
-        if ( iComboBox ) {
+        if ( iWidget ) {
                 //Get list
                 QStringList list;
                 SKGServices::getDistinctValues ( iDoc, iTable, iAttribut, iWhereClause, list );
                 if ( list.count() && !list.at ( 0 ).isEmpty() ) list.insert ( 0, "" );
 
-                //Fill combo
-                iComboBox->clear();
-                iComboBox->addItems ( list );
-
                 //Fill completion
-                KCompletion *comp = iComboBox->completionObject();
-                comp->clear ();
-                comp->insertItems ( list );
+                KComboBox *kcmb = qobject_cast<KComboBox *>(iWidget);
+                if (kcmb) {
+                        //Sorting list
+                        //Correction bug 202341 vvv
+                        qSort(list.begin(), list.end(), naturalLessThan);
+                        //Correction bug 202341 ^^^
+
+                        //Fill combo
+                        kcmb->clear();
+                        kcmb->addItems ( list );
+
+                        KCompletion *comp = kcmb->completionObject();
+                        if (comp) {
+                                comp->setIgnoreCase(true);
+                                comp->setSoundsEnabled(true);
+                                comp->clear ();
+                                comp->insertItems ( list );
+                        }
+                }
         }
 }
+
+bool SKGMainPanel::naturalLessThan(const QString &s1, const QString &s2)
+{
+        return (KStringHandler::naturalCompare(s1, s2, Qt::CaseInsensitive)<0);
+}
+
+SKGMainPanel* SKGMainPanel::getMainPanel()
+{
+        return mainPanel;
+}
 #include "skgmainpanel.moc"
