@@ -44,34 +44,41 @@ SKGObjectModelBase::SKGObjectModelBase(SKGDocument* iDocument,
                                        bool iResetOnCreation)
                 : QAbstractItemModel(parent), isResetRealyNeeded(iResetOnCreation), document(iDocument),
                 whereClause(iWhereClause),
-                parentAttribute(iParentAttribute)
+                parentAttribute(iParentAttribute),refreshBlocked(false)
 {
         SKGTRACEIN(1, "SKGObjectModelBase::SKGObjectModelBase");
 
-        listSupportedDefault 	<< "t_name"
-        << "t_value"
-        << "d_lastmodifdate"
-        << "d_date"
-        << "t_savestep"
-        ;
         setTable(iTable);
 
         //Build schemas
-        SKGModelTemplate def;
-        def.id="default";
-        def.name=tr("Default");
-        def.icon="edit-undo";
-        def.schema="";
-        listSchema.push_back(def);
+        if (getRealTable()=="doctransaction") {
+                SKGModelTemplate def;
+                def.id="default";
+                def.name=i18nc("Noun, the default value of an item","Default");
+                def.icon="edit-undo";
+                def.schema="t_name;t_value;d_lastmodifdate;t_savestep";
+                listSchema.push_back(def);
 
-        //Build schemas
-        if (getRealTable()=="parameters") {
-                SKGModelTemplate minimun;
-                minimun.id="minimun";
-                minimun.name=tr("Minimun");
-                minimun.icon="";
-                minimun.schema="t_name;t_value";
-                listSchema.push_back(minimun);
+                SKGModelTemplate minimum;
+                minimum.id="minimum";
+                minimum.name=i18nc("Noun, the minimum value of an item","Minimum");
+                minimum.icon="";
+                minimum.schema="t_name;t_value;d_lastmodifdate|N;t_savestep|N";
+                listSchema.push_back(minimum);
+        } else if (getRealTable()=="parameters") {
+                SKGModelTemplate def;
+                def.id="default";
+                def.name=i18nc("Noun, the default value of an item","Default");
+                def.icon="edit-undo";
+                def.schema="t_name;t_value";
+                listSchema.push_back(def);
+        } else if (getRealTable()=="node") {
+                SKGModelTemplate def;
+                def.id="default";
+                def.name=i18nc("Noun, the default value of an item","Default");
+                def.icon="edit-undo";
+                def.schema="t_name";
+                listSchema.push_back(def);
         }
 
         connect((const QObject*) document, SIGNAL(tableModified(QString, int)), this, SLOT(dataModified(QString, int)));
@@ -118,31 +125,26 @@ QList<SKGObjectModelBase::SKGModelTemplate> SKGObjectModelBase::getSchemas() con
 
 void SKGObjectModelBase::setSupportedAttributes ( const QStringList & iListAttribute )
 {
+        SKGTRACEIN(1, "SKGObjectModelBase::setSupportedAttributes");
         listSupported.clear();
         listVisibility.clear();
         listSize.clear();
 
-        if (iListAttribute.count()==0) {
-                listSupported=SKGServices::splitCSVLine(listSchema.at(0).schema);
-//			listSupported=listSupportedDefault;
-                int nb=listSupported.count();
-                for (int i=0; i<nb; ++i) {
-                        listVisibility.push_back(true);
-                        listSize.push_back(-1);
-                }
-        } else {
-                int nb=iListAttribute.count();
-                for (int i=0; i<nb; ++i) {
-                        QStringList values = iListAttribute.at(i).split('|');
-                        int nbValues=values.count();
+        QStringList l=iListAttribute;
+        if (l.count()==0 && listSchema.count())  l=SKGServices::splitCSVLine(listSchema.at(0).schema);
 
-                        if (nbValues>0) {
-                                listSupported.push_back(values.at(0));
-                                if (nbValues>1) listVisibility.push_back(values.at(1)=="Y");
-                                else listVisibility.push_back(true);
-                                if (nbValues>2) listSize.push_back(SKGServices::stringToInt(values.at(2)));
-                                else listSize.push_back(-1);
-                        }
+        int nb=l.count();
+        for (int i=0; i<nb; ++i) {
+                QStringList values = l.at(i).split('|');
+                int nbValues=values.count();
+
+                if (nbValues>0) {
+                        listSupported.push_back(values.at(0));
+                        bool visible=true;
+                        if (nbValues>1) visible=(values.at(1)=="Y");
+                        listVisibility.push_back(visible);
+                        if (nbValues>2) listSize.push_back(SKGServices::stringToInt(values.at(2)));
+                        else listSize.push_back(-1);
                 }
         }
         isResetRealyNeeded=true;
@@ -188,9 +190,16 @@ void SKGObjectModelBase::buidCache()
         nodeTable=(getRealTable()=="node");
 }
 
+bool SKGObjectModelBase::blockRefresh(bool iBlocked)
+{
+        bool previous=refreshBlocked;
+        refreshBlocked=iBlocked;
+        return previous;
+}
+
 void SKGObjectModelBase::refresh()
 {
-        if (!isResetRealyNeeded) return;
+        if (!isResetRealyNeeded || refreshBlocked) return;
         SKGTRACEIN(1, "SKGObjectModelBase::refresh");
         emit beforeReset();
         {
@@ -208,18 +217,20 @@ void SKGObjectModelBase::refresh()
                 if (SKGServices::getAttributesList(document, table, listAttibutesTmp).isSucceeded()) {
                         isResetRealyNeeded=false;
                         if (listAttibutesTmp.count()) {
-                                if (listSupported.count()==0) listSupported=listSupportedDefault;
-
                                 //Filter attributes
                                 int nb=listSupported.count();
+                                if (nb==0) {
+                                        setSupportedAttributes(QStringList());
+                                        nb=listSupported.count();
+                                }
                                 for (int i=0 ; i<nb ; ++i) {
                                         QString att=listSupported[i];
                                         if (listAttibutesTmp.contains(att)) {
                                                 listAttibutes.push_back(att);
-                                                if (att.startsWith("t_")) listAttibuteTypes.push_back(SKGObjectModelBase::STRING);
-                                                else if (att.startsWith("f_")) listAttibuteTypes.push_back(SKGObjectModelBase::DOUBLE);
-                                                else if (att.startsWith("i_")) listAttibuteTypes.push_back(SKGObjectModelBase::INTEGER);
-                                                else if (att.startsWith("d_")) listAttibuteTypes.push_back(SKGObjectModelBase::DATE);
+                                                if (att.startsWith(QLatin1String("t_"))) listAttibuteTypes.push_back(SKGObjectModelBase::STRING);
+                                                else if (att.startsWith(QLatin1String("f_"))) listAttibuteTypes.push_back(SKGObjectModelBase::DOUBLE);
+                                                else if (att.startsWith(QLatin1String("i_"))) listAttibuteTypes.push_back(SKGObjectModelBase::INTEGER);
+                                                else if (att.startsWith(QLatin1String("d_"))) listAttibuteTypes.push_back(SKGObjectModelBase::DATE);
                                                 else listAttibuteTypes.push_back(SKGObjectModelBase::OTHER);
                                         }
                                 }
@@ -273,7 +284,7 @@ void SKGObjectModelBase::refresh()
                                 childrensids.push_back(id);
 
                                 parentChildRelations.insert(idparent, childrensids);
-                                objectsHashTableRows.insert(id, t);
+                                objectsHashTableRows.insert(id, childrensids.count()-1);
                                 objectsHashTable.insert(id, c);
                         }
                 }
@@ -298,7 +309,7 @@ int SKGObjectModelBase::rowCount(const QModelIndex &parent ) const
         if (parent.isValid()) idParent = parent.internalId();
 
         QList<int> children=parentChildRelations.value(idParent);
-        //SKGTRACE << table << "-rowCount(" << idParent << " )=" << (children ? children->count() : 0) << endl;
+        //SKGTRACE << table << "-rowCount(" << idParent << " )=" << children.count() << endl;
         return children.count();
 
 }
@@ -320,12 +331,12 @@ QModelIndex SKGObjectModelBase::index ( int row, int column, const QModelIndex &
         int idChild=parentChildRelations.value(idParent).at(row);
 
         //SKGTRACE << table << "-" << idParent << "(" << row << ") ==> " << idChild << endl;
-        return createIndex(row, column, idChild);
+        return (idChild ? createIndex(row, column, idChild) : QModelIndex());
 }
 
 QModelIndex SKGObjectModelBase::parent ( const QModelIndex & index ) const
 {
-        if (!index.isValid() || index.column()!=0) return QModelIndex();
+        if (!index.isValid()) return QModelIndex();
         _SKGTRACEIN(10, "SKGObjectModelBase::parent");
 
         int idChild=0;
@@ -348,12 +359,12 @@ int SKGObjectModelBase::getIndexAttribute (const QString& iAttributeName ) const
 
 QString SKGObjectModelBase::getAttribute (int iIndex ) const
 {
-        return listAttibutes.at(iIndex);
+        return listAttibutes.value(iIndex);
 }
 
 SKGObjectModelBase::AttributeType SKGObjectModelBase::getAttributeType (int iIndex ) const
 {
-        return listAttibuteTypes.at(iIndex);
+        return listAttibuteTypes.value(iIndex);
 }
 
 QVariant SKGObjectModelBase::headerData ( int section, Qt::Orientation orientation, int role ) const
@@ -369,16 +380,26 @@ QVariant SKGObjectModelBase::headerData ( int section, Qt::Orientation orientati
                         return getDocument()->getDisplay(getTable()+'.'+att);
                 } else if (role == Qt::UserRole ) {
                         QString att;
-                        if (section>=0 && section< listAttibutes.count()) att=listAttibutes[section];
+                        if (section>=0 && section< listAttibutes.count()) att=listAttibutes.at(section);
                         else att=SKGServices::intToString(section);
 
+                        int indexAtt=listSupported.indexOf(att);
+
                         att=getDocument()->getDisplay(getTable()+'.'+att);
 
-                        if (section>=0 && section< listVisibility.count()) {
-                                att+=QString("|")+(listVisibility[section] ? "Y" : "N");
-                                if (section>=0 && section< listSize.count()) att+='|'+SKGServices::intToString(listSize.at(section));
+
+                        if (indexAtt>=0 && indexAtt< listVisibility.count()) {
+                                bool visible=listVisibility.at(indexAtt);
+                                att+=QString("|")+(visible ? "Y" : "N");
+                                if (indexAtt>=0 && indexAtt< listSize.count()) att+='|'+SKGServices::intToString(listSize.at(indexAtt));
                         }
                         return att;
+                } else if ( role == Qt::DecorationRole ) {
+                        QString att;
+                        if ( section>=0 && section< listAttibutes.count() ) att=listAttibutes[section];
+                        else att=SKGServices::intToString ( section );
+
+                        return getDocument()->getIcon(getTable()+'.'+att);
                 }
         }
         return QVariant();
@@ -432,6 +453,8 @@ QVariant SKGObjectModelBase::data(const QModelIndex &index, int role) const
                 }
 
                 if (doctransactionTable && att=="t_savestep") return "";
+
+                //return val+"("+SKGServices::intToString(rowCount(index))+")";
                 return val;
         }
 
@@ -514,6 +537,12 @@ QVariant SKGObjectModelBase::data(const QModelIndex &index, int role) const
                 }
                 break;
         }
+        case 99: {
+                SKGObjectBase* obj = getObjectPointer(index);
+                if (obj) return SKGServices::stringToDouble(obj->getAttribute("f_sortorder"));
+
+                break;
+        }
         default : {}
         }
 
@@ -670,72 +699,11 @@ void SKGObjectModelBase::dataModified(const QString& iTableName, int iIdTransact
                 SKGTRACEL(1) << "getTable=" << getRealTable() << endl;
                 SKGTRACEL(1) << "Parameters=" << iTableName << " , " << iIdTransaction << endl;
 
-                //Get modifications
-                /*     int nb=0;
-                     SKGObjectModificationList modifications;
-                     if (iIdTransaction!=0) {
-                             document->getModifications(iIdTransaction, modifications);
-                             nb=modifications.count();
-                     }
-
-                     if (1==1 || iTableName=="node" || iTableName=="doctransaction" || getTable()=="v_operation_consolidated" || iIdTransaction==0 || nb>50) {
-                */
                 //Full refresh
                 isResetRealyNeeded=true;
 
                 //Refresh model
                 refresh();
-                /* } else {
-                         //Treat
-                         emit layoutAboutToBeChanged();
-
-                         for (int i=0; i<nb; ++i) {
-                                 SKGObjectModification mod=modifications[i];
-                                 if (getRealTable()==mod.table) {
-                                         if (mod.type==D) {
-                                                 //Delete
-                                                 int pos=-1;
-                                                 int nbo=parentChildRelations.value("")->count();
-                                                 for (int j=0; pos==-1 && j<nbo; ++j) {
-                                                         if (mod.uuid==parentChildRelations.value("")->at(j).getUniqueID()) pos=j;
-                                                 }
-
-                                                 if (pos!=-1) {
-                                                         beginRemoveRows(QModelIndex(), pos, pos);
-                                                         parentChildRelations.value("")->removeAt(pos);
-                                                         endRemoveRows();
-                                                 }
-                                         } else if (mod.type==I) {
-                                                 //Insert
-                                                 int pos=rowCount();
-                                                 beginInsertRows(QModelIndex(), pos, pos);
-                                                 SKGObjectBase tmp(document, getTable(), mod.id);
-                                                 parentChildRelations.value("")->push_back(tmp);
-                                                 endInsertRows();
-
-                                                 QModelIndex topLeft=index(pos, 0);
-                                                 QModelIndex bottomRight=index(pos, columnCount());
-                                                 emit dataChanged (topLeft, bottomRight);
-                                         } else if (mod.type==U) {
-                                                 //Update
-                                                 int nbo=parentChildRelations.value("")->count();
-                                                 for (int j=0; j<nbo; ++j) {
-                                                         if (mod.uuid==parentChildRelations.value("")->at(j).getUniqueID()) {
-                                                                 QModelIndex idx=index(j, 0, QModelIndex());
-                                                                 SKGObjectBase* obj = (SKGObjectBase*) idx.internalPointer();
-                                                                 if (obj) {
-                                                                         obj->load();
-
-                                                                         QModelIndex bottomRight=index(j, columnCount());
-                                                                         emit dataChanged (idx, bottomRight);
-                                                                 }
-                                                         }
-                                                 }
-                                         }
-                                 }
-                         }
-                         emit  layoutChanged();
-                 }*/
         }
 }
 
