@@ -22,7 +22,7 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgobjectbase.h"
-
+#include "skgbasegui_export.h"
 #include <kglobal.h>
 #include <QAbstractItemModel>
 #include <QStringList>
@@ -32,7 +32,7 @@ class SKGDocument;
 /**
  * The Table model managing SKGObjectBase
  */
-class KDE_EXPORT SKGObjectModelBase : public QAbstractItemModel
+class SKGBASEGUI_EXPORT SKGObjectModelBase : public QAbstractItemModel
 {
         Q_OBJECT
         Q_ENUMS(AttributeType);
@@ -88,6 +88,13 @@ public:
          */
         virtual void refresh();
 
+        /**
+         * Allows to block a refresh
+         * @param iBlocked blocking status
+         * @return previous value
+         */
+        virtual bool blockRefresh(bool iBlocked);
+
         /**
          * Returns the number of row for the given parent.
          * @param parent the parent
@@ -287,12 +294,12 @@ public:
                                   const QModelIndex &parent);
 signals:
         /**
-         * Emited before reset
+         * Emitted before reset
          */
         void beforeReset();
 
         /**
-         * Emited after reset
+         * Emitted after reset
          */
         void afterReset();
 
@@ -322,11 +329,6 @@ protected:
          */
         QList<AttributeType> listAttibuteTypes;
 
-        /**
-         *list of supported attributes
-         */
-        QStringList listSupportedDefault;
-
         /**
          *list of supported schemas
          */
@@ -359,6 +361,7 @@ private:
         QList<int> listSize;
         bool doctransactionTable;
         bool nodeTable;
+        bool refreshBlocked;
 };
 
 #endif
