@@ -45,16 +45,21 @@ bool SKGSortFilterProxyModel::filterAcceptsRow ( int source_row, const QModelInd
         _SKGTRACEIN(10, "SKGSortFilterProxyModel::filterAcceptsRow");
 
         //Initialisation
-        bool output=false;
+        bool output=(filterRegExp().isEmpty());
 
-        //Get source
-        QAbstractItemModel* model=this->sourceModel();
-        if (model) {
-                QRegExp regexp(filterRegExp());
-                int nbcol=model->columnCount();
-                for (int i=0; !output && i<nbcol; ++i) {
-                        QModelIndex index0 = model->index(source_row, i, source_parent);
-                        if (index0.isValid()) output=(regexp.indexIn(model->data(index0).toString())!=-1);
+        if (!output) {
+                //Get source
+                QAbstractItemModel* model=this->sourceModel();
+                if (model) {
+                        QRegExp regexp(filterRegExp());
+                        int nbcol=model->columnCount();
+                        for (int i=0; !output && i<nbcol; ++i) {
+                                QModelIndex index0 = model->index(source_row, i, source_parent);
+                                if (index0.isValid()) {
+                                        output=(regexp.indexIn(model->data(index0).toString())!=-1);
+                                        if (!output)  output=(regexp.indexIn(model->data(index0, Qt::UserRole).toString())!=-1);
+                                }
+                        }
                 }
         }
         return output;
