@@ -33,7 +33,6 @@
 #include <kmenu.h>
 #include <klocale.h>
 #include <kfiledialog.h>
-#include <kmessagebox.h>
 
 #include <QDomDocument>
 #include <QHeaderView>
@@ -46,6 +45,7 @@
 #include <QPrinter>
 #include <QPainter>
 #include <QDesktopServices>
+#include <QTimer>
 
 SKGTableView::SKGTableView ( QWidget *parent )
                 : QTableView ( parent ),
@@ -54,6 +54,16 @@ SKGTableView::SKGTableView ( QWidget *parent )
                 smoothScrolling ( false ), actSmoothScrolling ( NULL ),
                 document ( NULL )
 {
+        //Delayed resize
+        timerDelayedResize = new QTimer( this );
+        timerDelayedResize->setSingleShot( true );
+        connect( timerDelayedResize, SIGNAL( timeout() ), this, SLOT( resizeColumnsToContents() ), Qt::QueuedConnection );
+
+        timerSelectionChanged = new QTimer( this );
+        timerSelectionChanged->setSingleShot( true );
+        connect( timerSelectionChanged, SIGNAL( timeout() ), this, SIGNAL( selectionChangedDelayed() ), Qt::QueuedConnection );
+
+        //Menu
         QHeaderView* hori=horizontalHeader();
         hori->setContextMenuPolicy ( Qt::CustomContextMenu );
         header_menu = new KMenu ( this );
@@ -61,6 +71,7 @@ SKGTableView::SKGTableView ( QWidget *parent )
         setContextMenuPolicy ( Qt::ActionsContextMenu );
         connect ( hori,SIGNAL ( customContextMenuRequested ( const QPoint & ) ),this,SLOT ( showHeaderMenu ( const QPoint& ) ) );
 
+        //Headers
         // hori->setResizeMode(QHeaderView::ResizeToContents);
         hori->setMovable ( true );
 
@@ -73,13 +84,14 @@ SKGTableView::SKGTableView ( QWidget *parent )
         switchSmoothScrolling();
 
         connect ( horizontalHeader(), SIGNAL ( sectionMoved ( int, int, int ) ), this, SLOT ( moveSection() ), Qt::QueuedConnection );
-        connect ( horizontalHeader(), SIGNAL ( geometriesChanged() ), this, SLOT ( setupHeaderMenu() ), Qt::QueuedConnection );
 }
 
 SKGTableView::~SKGTableView()
 {
         document=NULL;
         header_menu=NULL;
+        timerDelayedResize=NULL;
+        timerSelectionChanged=NULL;
 }
 
 bool SKGTableView::isAutoResized()
@@ -95,6 +107,7 @@ bool SKGTableView::isSmoothScrolling()
 QString SKGTableView::getState()
 {
         SKGTRACEIN ( 10, "SKGTableView::getState" );
+
         QDomDocument doc ( "SKGML" );
         QDomElement root = doc.createElement ( "parameters" );
         doc.appendChild ( root );
@@ -106,8 +119,10 @@ QString SKGTableView::getState()
 
         QHeaderView* hHeader=horizontalHeader();
         if ( hHeader && model ) {
-                root.setAttribute ( "sortOrder", SKGServices::intToString ( ( int ) hHeader->sortIndicatorOrder() ) );
-                root.setAttribute ( "sortColumn", model->getAttribute ( hHeader->sortIndicatorSection() ) );
+                if (isSortingEnabled()) {
+                        root.setAttribute ( "sortOrder", SKGServices::intToString ( ( int ) hHeader->sortIndicatorOrder() ) );
+                        root.setAttribute ( "sortColumn", model->getAttribute ( hHeader->sortIndicatorSection() ) );
+                }
 
                 //Memorize order
                 int nb=hHeader->count();
@@ -141,6 +156,8 @@ QString SKGTableView::getState()
 void SKGTableView::setState ( const QString& iState )
 {
         SKGTRACEIN ( 10, "SKGTableView::setState" );
+        resetColumnsOrder();
+
         QDomDocument doc ( "SKGML" );
 
         QString viewState=iState;
@@ -167,8 +184,9 @@ void SKGTableView::setState ( const QString& iState )
                 QString alternatingRowColors=root.attribute ( "alternatingRowColors" );
 
                 //Set column order
+                QStringList listAtt;
                 if ( !columns.isEmpty() ) {
-                        QStringList listAtt=SKGServices::splitCSVLine ( columns, ';' );
+                        listAtt=SKGServices::splitCSVLine ( columns, ';' );
                         QStringList sizes=SKGServices::splitCSVLine ( columnsSize, ';' );
                         QStringList visibilities=SKGServices::splitCSVLine ( columnsVisibility, ';' );
 
@@ -184,18 +202,17 @@ void SKGTableView::setState ( const QString& iState )
                                 }
 
                         }
-                        if ( model ) {
-                                model->setSupportedAttributes ( listAtt );
-                                model->refresh();
-                        }
+                }
+                if ( model ) {
+                        model->setSupportedAttributes ( listAtt );
+                        model->refresh();
                 }
 
                 //Set autoResize
                 if ( !columnsAutoResize.isEmpty() ) {
                         autoResize= ( columnsAutoResize=="Y" );
                         horizontalHeader()->setResizeMode ( autoResize ? QHeaderView::Fixed : QHeaderView::Interactive );
-                        if (autoResize) resizeColumnsToContents();
-                } else resizeColumnsToContents();
+                }
 
                 //Set smoothScrolling
                 if ( !smoothScrollings.isEmpty() ) {
@@ -204,7 +221,8 @@ void SKGTableView::setState ( const QString& iState )
                 }
 
                 //Set sort
-                if ( model && !sortOrder.isEmpty() && !sortColumn.isEmpty() ) {
+                if ( model && isSortingEnabled() && !sortOrder.isEmpty() && !sortColumn.isEmpty() ) {
+                        SKGTRACEIN ( 10, "SKGTableView::setState-sortByColumn" );
                         int index=SKGServices::splitCSVLine ( columns, ';' ).indexOf ( sortColumn );
                         if ( index==-1 ) index=model->getIndexAttribute ( sortColumn );
                         if ( index==-1 ) index=0;
@@ -225,6 +243,8 @@ void SKGTableView::setState ( const QString& iState )
 
                 this->sortByColumn ( 0, Qt::AscendingOrder );
         }
+
+        setupHeaderMenu();
 }
 
 void SKGTableView::showHeaderMenu ( const QPoint& pos )
@@ -245,6 +265,7 @@ void SKGTableView::moveSection()
 
 void SKGTableView::setupHeaderMenu ( bool iRefreshColumnSize )
 {
+        SKGTRACEIN ( 10, "SKGTableView::setupHeaderMenu" );
         SKGObjectModelBase* model= ( SKGObjectModelBase* ) this->model();
         QSortFilterProxyModel *proxyModel = qobject_cast<QSortFilterProxyModel *> ( model );
         if ( proxyModel ) model= ( SKGObjectModelBase* ) proxyModel->sourceModel();
@@ -351,9 +372,36 @@ void SKGTableView::setupHeaderMenu ( bool iRefreshColumnSize )
 
                 QAction* actTXT = exp->addAction ( KIcon ( "text-plain" ), i18n ( "Export TXT..." ) );
                 connect ( actTXT, SIGNAL ( triggered ( bool ) ), this, SLOT ( onExportTXT() ) );
+
+                if (autoResize) resizeColumnsToContentsDelayed();
         }
 }
 
+void SKGTableView::setSelectionModel ( QItemSelectionModel * selectionModel )
+{
+        if (this->selectionModel()) disconnect(this->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT ( onSelectionChanged() ) );
+        QTableView::setSelectionModel (selectionModel);
+        if (selectionModel) connect(selectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT ( onSelectionChanged() ) );
+}
+
+void SKGTableView::onSelectionChanged()
+{
+        if (timerSelectionChanged) timerSelectionChanged->start( 300 );
+}
+
+void SKGTableView::resizeColumnsToContentsDelayed()
+{
+        SKGTRACEIN ( 10, "SKGTableView::resizeColumnsToContentsDelayed" );
+        if (timerDelayedResize) timerDelayedResize->start( 300 );
+}
+
+
+void SKGTableView::resizeColumnsToContents()
+{
+        SKGTRACEIN ( 10, "SKGTableView::resizeColumnsToContents" );
+        QTableView::resizeColumnsToContents();
+}
+
 void SKGTableView::saveDefaultClicked()
 {
         SKGError err;
@@ -367,7 +415,7 @@ void SKGTableView::switchAutoResize()
 {
         autoResize=actAutoResize->isChecked();
         horizontalHeader()->setResizeMode ( autoResize ? QHeaderView::Fixed : QHeaderView::Interactive );
-        if ( autoResize ) resizeColumnsToContents();
+        if ( autoResize ) resizeColumnsToContentsDelayed();
 }
 
 void SKGTableView::switchSmoothScrolling()
@@ -403,9 +451,20 @@ void SKGTableView::showHideColumn()
         QAction* sender=static_cast<QAction*> ( this->sender() );
         if ( sender ) {
                 QHeaderView* hHeader=horizontalHeader();
+                if (hHeader) {
+                        int idx=sender->data().toInt();
+                        hHeader->setSectionHidden ( idx, !hHeader->isSectionHidden ( idx ) );
+                }
+        }
+}
 
-                int idx=sender->data().toInt();
-                hHeader->setSectionHidden ( idx, !hHeader->isSectionHidden ( idx ) );
+void SKGTableView::resetColumnsOrder()
+{
+        QHeaderView* hHeader=horizontalHeader();
+        int nbcol=hHeader->count();
+        for ( int i=0; i<nbcol; ++i ) {
+                int idx=hHeader->visualIndex ( i );
+                if ( idx!=i ) hHeader->moveSection ( idx,i );
         }
 }
 
@@ -421,18 +480,11 @@ void SKGTableView::changeSchema()
         if ( proxyModel ) model= ( SKGObjectModelBase* ) proxyModel->sourceModel();
         if ( model ) {
                 //Reset column oder
-                QHeaderView* hHeader=horizontalHeader();
-                int nbcol=hHeader->count();
-                for ( int i=0; i<nbcol; ++i ) {
-                        int idx=hHeader->visualIndex ( i );
-                        if ( idx!=i ) hHeader->moveSection ( idx,i );
-                }
+                resetColumnsOrder();
 
                 model->setSupportedAttributes ( list );
                 model->refresh();
-                hHeader->setSortIndicator ( 0, Qt::AscendingOrder );
-
-                resizeColumnsToContents();
+                horizontalHeader()->setSortIndicator ( 0, Qt::AscendingOrder );
 
                 setupHeaderMenu();
         }
@@ -697,6 +749,7 @@ void SKGTableView::timerEvent ( QTimerEvent *event )
 void SKGTableView::mousePressEvent ( QMouseEvent * event )
 {
         if ( event && event->button() ==Qt::LeftButton && ! ( this->indexAt ( event->pos() ).isValid() ) ) {
+                emit clickEmptyArea();
                 clearSelection();
         }
         QTableView::mousePressEvent ( event );
@@ -712,7 +765,7 @@ SKGStringListList SKGTableView::getTable()
         int nb=model->columnCount();
         QStringList cols;
         for ( int i=0; i<nb; i++ ) {
-                cols.append ( model->headerData ( i,Qt::Horizontal, Qt::UserRole ).toString() );
+                cols.append ( model->headerData ( i,Qt::Horizontal, Qt::UserRole ).toString().split('|').at(0) );
         }
         table.append ( cols );
 
@@ -740,7 +793,7 @@ void SKGTableView::onExportCSV()
                 QFile file ( fileName );
                 if ( !file.open ( QIODevice::WriteOnly | QIODevice::Text ) ) {
                         err.setReturnCode ( ERR_INVALIDARG );
-                        err.setMessage ( tr ( "Save file [%1] failed" ).arg ( fileName ) );
+                        err.setMessage (  i18n( "Save file [%1] failed" , fileName ) );
                 } else {
                         QTextStream out ( &file );
                         QStringList dump=SKGServices::tableToDump ( getTable(), SKGServices::DUMP_CSV );
@@ -770,7 +823,7 @@ void SKGTableView::onExportTXT()
         QFile file ( fileName );
         if ( !file.open ( QIODevice::WriteOnly | QIODevice::Text ) ) {
                 err.setReturnCode ( ERR_INVALIDARG );
-                err.setMessage ( tr ( "Save file [%1] failed" ).arg ( fileName ) );
+                err.setMessage (  i18n( "Save file [%1] failed" , fileName ) );
         } else {
                 QTextStream out ( &file );
                 QStringList dump=SKGServices::tableToDump ( getTable(), SKGServices::DUMP_TEXT );
