@@ -23,6 +23,7 @@
  */
 #include "skgservices.h"
 #include "skgobjectbase.h"
+#include "skgbasegui_export.h"
 
 #include <kglobal.h>
 #include <QStringList>
@@ -33,11 +34,12 @@
 #include <kmenu.h>
 
 class SKGDocument;
+class QTimer;
 
 /**
  * This file is Skrooge tab widget used by plugins
  */
-class KDE_EXPORT SKGTableView : public QTableView
+class SKGBASEGUI_EXPORT SKGTableView : public QTableView
 {
         Q_OBJECT
         Q_PROPERTY( QString state READ getState WRITE setState USER true)
@@ -104,6 +106,23 @@ public:
          */
         virtual int getNbSelectedObjects();
 
+        /**
+         * Sets the current selection model to the given selectionModel.
+         * @param selectionModel the selection model
+         */
+        virtual void setSelectionModel ( QItemSelectionModel * selectionModel );
+
+signals:
+        /**
+         * Emitted when the empty area
+         */
+        void clickEmptyArea();
+
+        /**
+         * Emitted 300ms after selection changed
+         */
+        void selectionChangedDelayed();
+
 protected:
 
         /**
@@ -149,6 +168,21 @@ public slots:
          */
         virtual void switchSmoothScrolling();
 
+        /**
+         * Reset columns order
+         */
+        virtual void resetColumnsOrder();
+
+        /**
+         * Resizes all columns based on the size hints of the delegate used to render each item in the columns.
+         */
+        virtual void resizeColumnsToContents();
+
+        /**
+         * Resizes all columns based on the size hints of the delegate used to render each item in the columns.
+         */
+        virtual void resizeColumnsToContentsDelayed();
+
 private slots:
         void onExportPDF();
         void onExportCSV();
@@ -162,6 +196,8 @@ private slots:
         void changeSchema();
         void saveDefaultClicked();
 
+        void onSelectionChanged();
+
 private:
         Q_DISABLE_COPY(SKGTableView);
 
@@ -186,6 +222,8 @@ private:
         QPoint speed;
         QList<QEvent*> ignored;
         QBasicTimer ticker;
+        QTimer* timerDelayedResize;
+        QTimer* timerSelectionChanged;
 };
 
 #endif // SKGTABLEVIEW_H
