@@ -36,6 +36,7 @@
 #include <QPainter>
 #include <QTableWidgetItem>
 #include <QDesktopServices>
+#include <kstringhandler.h>
 
 #include <math.h>
 
@@ -55,7 +56,7 @@ SKGTableWithGraph::SKGTableWithGraph(QWidget *parent)
 
         mainMenu = new KMenu(ui.kTable);
 
-        QMenu* exp=mainMenu->addMenu(i18n("Export"));
+        QMenu* exp=mainMenu->addMenu(i18nc("Verb, action to export items in another format","Export"));
 
         QAction* actCSV = exp->addAction(KIcon("text-csv"), i18n("Export CSV..."));
         connect(actCSV, SIGNAL(triggered(bool)), this, SLOT(onExportCSV()));
@@ -78,10 +79,10 @@ SKGTableWithGraph::SKGTableWithGraph(QWidget *parent)
         }
         ui.kTable->verticalHeader()->setDefaultSectionSize(ui.kTable->verticalHeader()->minimumSectionSize());
 
-        ui.kDisplayMode->addItem(i18n("Stack"));
-        ui.kDisplayMode->addItem(i18n("Histogram"));
-        ui.kDisplayMode->addItem(i18n("Pie"));
-        ui.kDisplayMode->addItem(i18n("Concentric pie"));
+        ui.kDisplayMode->addItem(KIcon("skrooge-chart-bar-stacked"), i18nc("Noun, a type of graph, with bars stacked upon each other","Stack"));
+        ui.kDisplayMode->addItem(KIcon("skrooge-chart-bar"), i18nc("Noun, a type of graph, with bars placed besides each other","Histogram"));
+        ui.kDisplayMode->addItem(KIcon("skrooge-chart-pie"), i18nc("Noun, a type of graph that looks like a sliced pie","Pie"));
+        ui.kDisplayMode->addItem(KIcon("skrooge-chart-ring"), i18nc("Noun, a type of graph that looks like concentric slices of a pie (a la filelight)","Concentric pie"));
 
         connect(ui.kDisplayMode, SIGNAL(currentIndexChanged(int)), this, SLOT(redrawGraph()), Qt::QueuedConnection);
         connect(ui.kAllPositive, SIGNAL(stateChanged(int)), this, SLOT(redrawGraph()), Qt::QueuedConnection);
@@ -183,8 +184,8 @@ void SKGTableWithGraph::setState(const QString& iState )
 
                 QString sortOrder=root.attribute ( "sortOrder");
                 QString sortColumn=root.attribute ( "sortColumn");
-                if (sortOrder.isEmpty()) sortOrder="0";
-                if (sortColumn.isEmpty()) sortColumn="0";
+                if (sortOrder.isEmpty()) sortOrder='0';
+                if (sortColumn.isEmpty()) sortColumn='0';
                 ui.kTable->horizontalHeader()->setSortIndicator(SKGServices::stringToInt(sortColumn),
                                 (Qt::SortOrder) SKGServices::stringToInt(sortOrder));
 
@@ -196,8 +197,6 @@ void SKGTableWithGraph::setState(const QString& iState )
                 ui.kDisplayMode->setCurrentIndex(0);
                 //^^^ Correction bug 2278703:Zoom fit when opening report tab
         }
-
-        refresh();
 }
 
 void SKGTableWithGraph::onOneLevelMore()
@@ -240,7 +239,8 @@ bool SKGTableWithGraph::listSort(const QStringList &s1, const QStringList &s2)
         QString v1=s1.at(sortColumn);
         QString v2=s2.at(sortColumn);
         if (sortColumn==0) {
-                return (sortOrder ? v1.toLower() > v2.toLower() : v1.toLower() < v2.toLower());
+                int v=KStringHandler::naturalCompare(v1, v2, Qt::CaseInsensitive);
+                return (sortOrder ? v>0 : v<0);
         }
 
         double vd1=SKGServices::stringToDouble(v1);
@@ -253,20 +253,6 @@ void SKGTableWithGraph::refresh()
         SKGTRACEIN(10, "SKGTableWithGraph::refresh");
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
-        /*    {
-        SKGTRACEIN(10, "test-Filltable");
-        ui.kTable->clear();
-        ui.kTable->setRowCount(10);
-        ui.kTable->setColumnCount(10);
-        for (int i=0; i<9; ++i) {
-        for (int j=0; j<9; ++j) {
-        SKGTRACEIN(10, "test-setItem");
-        QTableWidgetItem* item=new QTableWidgetItem("A");
-        ui.kTable->setItem(i, j, item);
-        }
-        }
-        }*/
-
         //Create grouped table
         int nbLevelMax=0;
         int nbCols=-1;
@@ -341,7 +327,7 @@ void SKGTableWithGraph::refresh()
         int nblines=groupedTable.count();
         if (showSumAndAverage) {
                 QStringList sums;
-                sums.push_back(i18n("Sum"));
+                sums.push_back(i18nc("Noun, the numerical sum of a list of values","Sum"));
                 for (int i=1; i<nbCols; ++i) {
                         double sum=0;
                         for (int j=1; j<nblines; ++j) {
@@ -357,8 +343,8 @@ void SKGTableWithGraph::refresh()
         if (nbCols>2 && showSumAndAverage) {
                 //Add title
                 QStringList newLine=groupedTable.at(0);
-                newLine.push_back(tr("Sum"));
-                newLine.push_back(tr("Average"));
+                newLine.push_back(i18nc("Noun, the numerical sum of a list of values","Sum"));
+                newLine.push_back(i18nc("Noun, the numerical average of a list of values","Average"));
                 groupedTable.replace(0, newLine);
 
                 for (int i=1; i<nblines; ++i) {
@@ -535,7 +521,8 @@ void SKGTableWithGraph::redrawGraph()
                         nbColumns=nbColumns-2; //Sum and average
                         --sumColumnIndex;
                 }
-                QPen dotPen=QPen(Qt::DotLine);
+                QPen dotPen=QPen(Qt::SolidLine); //WARNING: Qt::DotLine is very bad for performances
+                dotPen.setColor (Qt::gray);
 
                 int mode=ui.kDisplayMode->currentIndex();
                 bool inPositive=false;
@@ -758,16 +745,7 @@ void SKGTableWithGraph::redrawGraph()
                         } else {
                                 //STACK & HISTOGRAMM
                                 double scaleText=0;
-
-                                //Axis y
-                                QGraphicsLineItem* item=scene->addLine(0, -ymin+margin, 0, -ymax-margin);
-                                item->setFlag(QGraphicsItem::ItemIsSelectable, false);
-                                addArrow(QPointF(0, -ymax-margin), margin/2, 45, 90);
-
-                                //Axis x
-                                item=scene->addLine(-margin, 0, maxX, 0);
-                                item->setFlag(QGraphicsItem::ItemIsSelectable, false);
-                                addArrow(QPointF(maxX, 0), margin/2, 45, 180);
+                                QGraphicsLineItem* item;
 
                                 //Lines x
                                 int ystep=computeStepSize( ymax-ymin, 10 );
@@ -776,6 +754,7 @@ void SKGTableWithGraph::redrawGraph()
                                                 item=scene->addLine(-margin, -y, maxX, -y);
                                                 item->setPen(dotPen);
                                                 item->setFlag(QGraphicsItem::ItemIsSelectable, false);
+                                                item->setZValue(1);
 
                                                 QGraphicsTextItem* textItem=scene->addText(SKGServices::intToString(y));
                                                 textItem->setPos(-margin, -y);
@@ -790,6 +769,7 @@ void SKGTableWithGraph::redrawGraph()
                                                 item=scene->addLine(-margin, -y, maxX, -y);
                                                 item->setPen(dotPen);
                                                 item->setFlag(QGraphicsItem::ItemIsSelectable, false);
+                                                item->setZValue(1);
 
                                                 QGraphicsTextItem* textItem=scene->addText(SKGServices::intToString(y));
                                                 textItem->setPos(-margin, -y);
@@ -800,15 +780,15 @@ void SKGTableWithGraph::redrawGraph()
 
                                 if (mode==1) {
                                         //Line y
-                                        int xstep=width*(nbRows+1);
+                                        double xstep=width*(nbRows+1);
                                         int j=1;
-                                        for (int x=-width/2+xstep; x<maxX; x=x+xstep) {
+                                        for (double x=xstep-width/2; x<maxX; x=x+xstep) {
                                                 QGraphicsLineItem* item=scene->addLine(x, -ymin+margin, x, -ymax-margin);
                                                 item->setPen(dotPen);
                                                 item->setFlag(QGraphicsItem::ItemIsSelectable, false);
 
                                                 QString yname=ui.kTable->horizontalHeaderItem(j)->text();
-                                                ++j;
+                                                if (j<nbColumns-1) ++j;
 
                                                 QGraphicsTextItem* textItem=scene->addText(yname);
                                                 textItem->setPos(x-xstep, 0);
@@ -816,6 +796,19 @@ void SKGTableWithGraph::redrawGraph()
                                                 textItem->setFlag(QGraphicsItem::ItemIsSelectable, false);
                                         }
                                 }
+
+
+                                //Axis y
+                                item=scene->addLine(0, -ymin+margin, 0, -ymax-margin);
+                                item->setFlag(QGraphicsItem::ItemIsSelectable, false);
+                                addArrow(QPointF(0, -ymax-margin), margin/2, 45, 90);
+                                item->setZValue(2);
+
+                                //Axis x
+                                item=scene->addLine(-margin, 0, maxX, 0);
+                                item->setFlag(QGraphicsItem::ItemIsSelectable, false);
+                                addArrow(QPointF(maxX, 0), margin/2, 45, 180);
+                                item->setZValue(2);
                         }
                 }
         }
@@ -862,6 +855,7 @@ void SKGTableWithGraph::addArrow(const QPointF& iPeak, double iSize, double iArr
                 item->rotate(iDegree);
                 item->moveBy(iPeak.x(), iPeak.y());
                 item->setFlag(QGraphicsItem::ItemIsSelectable, false);
+                item->setZValue(2);
         }
 }
 
@@ -878,7 +872,7 @@ void SKGTableWithGraph::onExportCSV()
                 QFile file(fileName);
                 if (!file.open(QIODevice::WriteOnly | QIODevice::Text)) {
                         err.setReturnCode(ERR_INVALIDARG);
-                        err.setMessage(tr("Save file [%1] failed").arg(fileName));
+                        err.setMessage(i18n("Save file [%1] failed",fileName));
                 } else {
                         QTextStream out(&file);
                         QStringList dump=SKGServices::tableToDump(getTable(), SKGServices::DUMP_CSV);
@@ -909,7 +903,7 @@ void SKGTableWithGraph::onExportTXT()
                 QFile file(fileName);
                 if (!file.open(QIODevice::WriteOnly | QIODevice::Text)) {
                         err.setReturnCode(ERR_INVALIDARG);
-                        err.setMessage(tr("Save file [%1] failed").arg(fileName));
+                        err.setMessage(i18n("Save file [%1] failed",fileName));
                 } else {
                         QTextStream out(&file);
                         QStringList dump=SKGServices::tableToDump(getTable(), SKGServices::DUMP_TEXT);
