@@ -22,6 +22,7 @@
 #include "skgtabwidget.h"
 #include "skgnodeobject.h"
 #include "skgservices.h"
+#include "skgdocument.h"
 #include "skgtransactionmng.h"
 #include "skgtraces.h"
 #include "skgmainpanel.h"
@@ -30,8 +31,8 @@
 
 #include <QtGui/QWidget>
 
-SKGTabWidget::SKGTabWidget(SKGMainPanel* iParent, SKGDocument* iDocument)
-                : SKGWidget(iDocument), parent(iParent)
+SKGTabWidget::SKGTabWidget(SKGDocument* iDocument)
+                : SKGWidget(iDocument)
 {
         SKGTRACEIN(5, "SKGTabWidget::SKGTabWidget");
 }
@@ -39,48 +40,12 @@ SKGTabWidget::SKGTabWidget(SKGMainPanel* iParent, SKGDocument* iDocument)
 SKGTabWidget::~SKGTabWidget()
 {
         SKGTRACEIN(5, "SKGTabWidget::~SKGTabWidget");
-        parent=NULL;
 }
 
 bool SKGTabWidget::close()
 {
         SKGTRACEIN(5, "SKGTabWidget::close");
-        //Is this widget linked to a bookmark ?
-        if (bookmarkID.length()) {
-                //Yes. Is state modified ?
-                SKGNodeObject node(getDocument(), SKGServices::stringToInt(bookmarkID));
-                if (node.exist()) {
-                        QStringList data=SKGServices::splitCSVLine(node.getData());
-                        QString fullname=node.getFullName();
-                        if (data.count()>3) {
-                                QString currentState=getState().trimmed();
-                                QString oldState=data[3].trimmed();
-                                SKGTRACEL(5) << "oldState     =" << oldState << endl;
-                                SKGTRACEL(5) << "currentState =" << currentState << endl;
-                                if (currentState!=oldState) {
-                                        QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
-                                        int conf=KMessageBox::questionYesNo(this,
-                                                                            tr("Bookmark [%1] has been modified. Do you want to update it with current state ?").arg(fullname),
-                                                                            tr("Bookmark has been modified"),
-                                                                            KStandardGuiItem::yes(),
-                                                                            KStandardGuiItem::no(),
-                                                                            QString("updateBookmarkOnClose"));
-                                        QApplication::restoreOverrideCursor();
-                                        if (conf==KMessageBox::Yes) {
-                                                SKGError err;
-                                                {
-                                                        SKGBEGINTRANSACTION(*getDocument(), tr("Bookmark update [%1]").arg(fullname), err);
-                                                        data[3]=currentState;
-                                                        if (err.isSucceeded()) err=node.setData(SKGServices::stringsToCsv(data));
-                                                        if (err.isSucceeded()) err=node.save();
-                                                }
-                                                SKGMainPanel::displayErrorMessage(err);
-                                        }
-                                }
-                        }
-                }
-        }
-
+        overwrite();
         return QWidget::close();
 }
 
@@ -95,11 +60,6 @@ int SKGTabWidget::getNbSelectedObjects()
         return getSelectedObjects().count();
 }
 
-SKGMainPanel * SKGTabWidget::getMainPanel()
-{
-        return parent;
-}
-
 QWidget* SKGTabWidget::getWidgetForPrint()
 {
         return this;
@@ -114,4 +74,74 @@ QString SKGTabWidget::getBookmarkID()
 {
         return bookmarkID;
 }
+
+void SKGTabWidget::overwrite(bool iUserConfirmation)
+{
+        //Is this widget linked to a bookmark ?
+        if (bookmarkID.length()) {
+                //Yes. Is state modified ?
+                SKGNodeObject node(getDocument(), SKGServices::stringToInt(bookmarkID));
+                if (node.exist()) {
+                        QStringList data=SKGServices::splitCSVLine(node.getData());
+                        QString fullname=node.getFullName();
+                        if (data.count()>3) {
+                                QString currentState=getState().trimmed();
+                                QString oldState=data[3].trimmed();
+                                SKGTRACEL(5) << "oldState     =" << oldState << endl;
+                                SKGTRACEL(5) << "currentState =" << currentState << endl;
+                                if (currentState!=oldState) {
+                                        QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
+                                        int conf=KMessageBox::Yes;
+                                        if (iUserConfirmation) conf=KMessageBox::questionYesNo(this,
+                                                                            i18n("Bookmark [%1] has been modified. Do you want to update it with current state ?",fullname),
+                                                                            i18n("Bookmark has been modified"),
+                                                                            KStandardGuiItem::yes(),
+                                                                            KStandardGuiItem::no(),
+                                                                            QString("updateBookmarkOnClose"));
+                                        QApplication::restoreOverrideCursor();
+                                        if (conf==KMessageBox::Yes) {
+                                                SKGError err;
+                                                {
+                                                        SKGBEGINTRANSACTION(*getDocument(), i18n("Bookmark update [%1]",fullname), err);
+                                                        data[3]=currentState;
+                                                        if (err.isSucceeded()) err=node.setData(SKGServices::stringsToCsv(data));
+                                                        if (err.isSucceeded()) err=node.save();
+                                                }
+                                                if (err.isSucceeded()) err=SKGError(0, i18n("Bookmark updated"));
+                                                SKGMainPanel::displayErrorMessage(err);
+                                        }
+                                }
+                        }
+                }
+        } else {
+                //No. It is a page opened from context or from an other page
+                QString name=getDefaultStateAttribute();
+                if (!name.isEmpty()) {
+                        QString currentState=getState().trimmed();
+                        QString oldState=getDocument()->getParameter(name);
+                        SKGTRACEL(5) << "oldState     =" << oldState << endl;
+                        SKGTRACEL(5) << "currentState =" << currentState << endl;
+                        if (currentState!=oldState) {
+                                QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
+                                int conf=KMessageBox::Yes;
+                                if (iUserConfirmation) conf=KMessageBox::questionYesNo(this,
+                                                                    i18n("Page has been modified. Do you want to update it with current state ?"),
+                                                                    i18n("Page has been modified"),
+                                                                    KStandardGuiItem::yes(),
+                                                                    KStandardGuiItem::no(),
+                                                                    QString("updateContextOnClose"));
+                                QApplication::restoreOverrideCursor();
+                                if (conf==KMessageBox::Yes) {
+                                        SKGError err;
+                                        {
+                                                SKGBEGINTRANSACTION ( *getDocument(), i18n ( "Save default state" ), err );
+                                                err=getDocument()->setParameter(name, currentState);
+                                        }
+                                        if (err.isSucceeded()) err=SKGError(0, i18n("Default state saved"));
+                                        SKGMainPanel::displayErrorMessage(err);
+                                }
+                        }
+                }
+        }
+}
 #include "skgtabwidget.moc"
