@@ -23,7 +23,7 @@
  */
 #include <kglobal.h>
 #include <QWidget>
-
+#include "skgbasegui_export.h"
 #include "skgobjectbase.h"
 #include "skgwidget.h"
 
@@ -32,7 +32,7 @@ class SKGMainPanel;
 /**
  * This file is Skrooge tab widget used by plugins
  */
-class KDE_EXPORT SKGTabWidget : public SKGWidget
+class SKGBASEGUI_EXPORT SKGTabWidget : public SKGWidget
 {
         Q_OBJECT
 
@@ -40,7 +40,7 @@ public:
         /**
          * Default Constructor
          */
-        SKGTabWidget(SKGMainPanel* iParent, SKGDocument* iDocument);
+        SKGTabWidget(SKGDocument* iDocument);
 
         /**
          * Default Destructor
@@ -61,12 +61,6 @@ public:
          */
         virtual int getNbSelectedObjects();
 
-        /**
-         * Get main panel
-         * @return pointer on main panel
-         */
-        virtual SKGMainPanel* getMainPanel();
-
         /**
          * Get the widget must be printed
          * @return a widget
@@ -85,6 +79,13 @@ public:
          */
         virtual QString getBookmarkID();
 
+        /**
+         * Overwrite bookmark if page is opened from a bookmark
+         * Overwrite context if page is opened from a context
+         * @param iNeedUserConfirmation to display a confirmation panel
+         */
+        virtual void overwrite(bool iNeedUserConfirmation=true);
+
 signals:
         /**
          * This signal must be launched when the selection is modified
@@ -101,7 +102,6 @@ public slots:
 private:
         Q_DISABLE_COPY(SKGTabWidget);
 
-        SKGMainPanel* parent;
         QString       bookmarkID;
 };
 
