@@ -45,6 +45,7 @@
 #include <QPrinter>
 #include <QPainter>
 #include <QDesktopServices>
+#include <QTimer>
 
 SKGTreeView::SKGTreeView ( QWidget *parent )
                 : QTreeView ( parent ),
@@ -52,6 +53,16 @@ SKGTreeView::SKGTreeView ( QWidget *parent )
                 smoothScrolling ( false ), actSmoothScrolling ( NULL ),
                 document ( NULL )
 {
+        //Delayed resize
+        timerDelayedResize = new QTimer( this );
+        timerDelayedResize->setSingleShot( true );
+        connect( timerDelayedResize, SIGNAL( timeout() ), this, SLOT( resizeColumnsToContents() ), Qt::QueuedConnection );
+
+        timerSelectionChanged = new QTimer( this );
+        timerSelectionChanged->setSingleShot( true );
+        connect( timerSelectionChanged, SIGNAL( timeout() ), this, SIGNAL( selectionChangedDelayed() ), Qt::QueuedConnection );
+
+        //Menu
         QHeaderView* hori=header();
         hori->setContextMenuPolicy ( Qt::CustomContextMenu );
         header_menu = new KMenu ( this );
@@ -59,6 +70,7 @@ SKGTreeView::SKGTreeView ( QWidget *parent )
         setContextMenuPolicy ( Qt::ActionsContextMenu );
         connect ( hori,SIGNAL ( customContextMenuRequested ( const QPoint & ) ),this,SLOT ( showHeaderMenu ( const QPoint& ) ) );
 
+        //Headers
         hori->setMovable ( true );
 
         header()->setResizeMode ( QHeaderView::Fixed );
@@ -68,13 +80,17 @@ SKGTreeView::SKGTreeView ( QWidget *parent )
         switchSmoothScrolling();
 
         connect ( header(), SIGNAL ( sectionMoved ( int, int, int ) ), this, SLOT ( moveSection() ), Qt::QueuedConnection );
-        connect ( header(), SIGNAL ( geometriesChanged() ), this, SLOT ( setupHeaderMenu() ), Qt::QueuedConnection );
+
+        connect ( this, SIGNAL ( collapsed(QModelIndex) ), this, SLOT ( onCollapse(QModelIndex) ), Qt::QueuedConnection );
+        connect ( this, SIGNAL ( expanded(QModelIndex) ), this, SLOT ( onExpand(QModelIndex) ), Qt::QueuedConnection );
 }
 
 SKGTreeView::~SKGTreeView()
 {
         document=NULL;
         header_menu=NULL;
+        timerDelayedResize=NULL;
+        timerSelectionChanged=NULL;
 }
 
 bool SKGTreeView::isAutoResized()
@@ -101,8 +117,10 @@ QString SKGTreeView::getState()
 
         QHeaderView* hHeader=header();
         if ( hHeader && model ) {
-                root.setAttribute ( "sortOrder", SKGServices::intToString ( ( int ) hHeader->sortIndicatorOrder() ) );
-                root.setAttribute ( "sortColumn", model->getAttribute ( hHeader->sortIndicatorSection() ) );
+                if (isSortingEnabled()) {
+                        root.setAttribute ( "sortOrder", SKGServices::intToString ( ( int ) hHeader->sortIndicatorOrder() ) );
+                        root.setAttribute ( "sortColumn", model->getAttribute ( hHeader->sortIndicatorSection() ) );
+                }
 
                 //Memorize order
                 int nb=hHeader->count();
@@ -135,6 +153,8 @@ QString SKGTreeView::getState()
 void SKGTreeView::setState ( const QString& iState )
 {
         SKGTRACEIN ( 10, "SKGTreeView::setState" );
+        resetColumnsOrder();
+
         QDomDocument doc ( "SKGML" );
 
         QString viewState=iState;
@@ -160,8 +180,9 @@ void SKGTreeView::setState ( const QString& iState )
                 QString alternatingRowColors=root.attribute ( "alternatingRowColors" );
 
                 //Set column order
+                QStringList listAtt;
                 if ( !columns.isEmpty() ) {
-                        QStringList listAtt=SKGServices::splitCSVLine ( columns, ';' );
+                        listAtt=SKGServices::splitCSVLine ( columns, ';' );
                         QStringList sizes=SKGServices::splitCSVLine ( columnsSize, ';' );
                         QStringList visibilities=SKGServices::splitCSVLine ( columnsVisibility, ';' );
 
@@ -177,18 +198,17 @@ void SKGTreeView::setState ( const QString& iState )
                                 }
 
                         }
-                        if ( model ) {
-                                model->setSupportedAttributes ( listAtt );
-                                model->refresh();
-                        }
+                }
+                if ( model ) {
+                        model->setSupportedAttributes ( listAtt );
+                        model->refresh();
                 }
 
                 //Set autoResize
                 if ( !columnsAutoResize.isEmpty() ) {
                         autoResize= ( columnsAutoResize=="Y" );
                         header()->setResizeMode ( autoResize ? QHeaderView::Fixed : QHeaderView::Interactive );
-                        if (autoResize) resizeColumnsToContents();
-                } else resizeColumnsToContents();
+                }
 
                 //Set smoothScrolling
                 if ( !smoothScrollings.isEmpty() ) {
@@ -197,7 +217,7 @@ void SKGTreeView::setState ( const QString& iState )
                 }
 
                 //Set sort
-                if ( model && !sortOrder.isEmpty() && !sortColumn.isEmpty() ) {
+                if ( model && isSortingEnabled() && !sortOrder.isEmpty() && !sortColumn.isEmpty() ) {
                         int index=SKGServices::splitCSVLine ( columns, ';' ).indexOf ( sortColumn );
                         if ( index==-1 ) index=model->getIndexAttribute ( sortColumn );
                         if ( index==-1 ) index=0;
@@ -215,10 +235,19 @@ void SKGTreeView::setState ( const QString& iState )
 
                 this->sortByColumn ( 0, Qt::AscendingOrder );
         }
+
+        setupHeaderMenu();
+}
+
+void SKGTreeView::resizeColumnsToContentsDelayed()
+{
+        SKGTRACEIN ( 10, "SKGTreeView::resizeColumnsToContentsDelayed" );
+        if (timerDelayedResize) timerDelayedResize->start( 300 );
 }
 
 void SKGTreeView::resizeColumnsToContents()
 {
+        SKGTRACEIN ( 10, "SKGTreeView::resizeColumnsToContents" );
         int nb=header()->count();
         for ( int i=0; i<nb; ++i ) {
                 resizeColumnToContents ( i );
@@ -243,6 +272,7 @@ void SKGTreeView::moveSection()
 
 void SKGTreeView::setupHeaderMenu ( bool iRefreshColumnSize )
 {
+        SKGTRACEIN ( 10, "SKGTreeView::setupHeaderMenu" );
         SKGObjectModelBase* model= ( SKGObjectModelBase* ) this->model();
         QSortFilterProxyModel *proxyModel = qobject_cast<QSortFilterProxyModel *> ( model );
         if ( proxyModel ) model= ( SKGObjectModelBase* ) proxyModel->sourceModel();
@@ -342,9 +372,23 @@ void SKGTreeView::setupHeaderMenu ( bool iRefreshColumnSize )
 
                 QAction* actTXT = exp->addAction ( KIcon ( "text-plain" ), i18n ( "Export TXT..." ) );
                 connect ( actTXT, SIGNAL ( triggered ( bool ) ), this, SLOT ( onExportTXT() ) );
+
+                if (autoResize) resizeColumnsToContentsDelayed();
         }
 }
 
+void SKGTreeView::setSelectionModel ( QItemSelectionModel * selectionModel )
+{
+        if (this->selectionModel()) disconnect(this->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT ( onSelectionChanged() ) );
+        QTreeView::setSelectionModel (selectionModel);
+        if (selectionModel) connect(selectionModel, SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT ( onSelectionChanged() ) );
+}
+
+void SKGTreeView::onSelectionChanged()
+{
+        if (timerSelectionChanged) timerSelectionChanged->start( 300 );
+}
+
 void SKGTreeView::saveDefaultClicked()
 {
         SKGError err;
@@ -358,7 +402,7 @@ void SKGTreeView::switchAutoResize()
 {
         autoResize=actAutoResize->isChecked();
         header()->setResizeMode ( autoResize ? QHeaderView::Fixed : QHeaderView::Interactive );
-        if ( autoResize ) resizeColumnsToContents();
+        if ( autoResize ) resizeColumnsToContentsDelayed();
 }
 
 void SKGTreeView::switchSmoothScrolling()
@@ -400,11 +444,21 @@ void SKGTreeView::showHideColumn()
         }
 }
 
+void SKGTreeView::resetColumnsOrder()
+{
+        QHeaderView* hHeader=header();
+        int nbcol=hHeader->count();
+        for ( int i=0; i<nbcol; ++i ) {
+                int idx=hHeader->visualIndex ( i );
+                if ( idx!=i ) hHeader->moveSection ( idx,i );
+        }
+}
+
 void SKGTreeView::changeSchema()
 {
         QStringList list;
 
-        QAction* sender= ( QAction* ) this->sender();
+        QAction* sender=static_cast<QAction*> ( this->sender() );
         if ( sender )  list=SKGServices::splitCSVLine ( sender->data().toString(), ';' );
 
         SKGObjectModelBase* model= ( SKGObjectModelBase* ) this->model();
@@ -412,24 +466,22 @@ void SKGTreeView::changeSchema()
         if ( proxyModel ) model= ( SKGObjectModelBase* ) proxyModel->sourceModel();
         if ( model ) {
                 //Reset column oder
-                QHeaderView* hHeader=header();
-                int nbcol=hHeader->count();
-                for ( int i=0; i<nbcol; ++i ) {
-                        int idx=hHeader->visualIndex ( i );
-                        if ( idx!=i ) hHeader->moveSection ( idx,i );
-                }
+                resetColumnsOrder();
 
                 model->setSupportedAttributes ( list );
                 model->refresh();
-                hHeader->setSortIndicator ( 0, Qt::AscendingOrder );
-
-                resizeColumnsToContents();
+                header()->setSortIndicator ( 0, Qt::AscendingOrder );
 
                 setupHeaderMenu();
         }
 
 }
 
+void SKGTreeView::setAlternatingRowColors ( bool enable )
+{
+        QTreeView::setAlternatingRowColors ( enable );
+}
+
 SKGObjectBase::SKGListSKGObjectBase SKGTreeView::getSelectedObjects()
 {
         SKGObjectBase::SKGListSKGObjectBase selection;
@@ -472,11 +524,6 @@ void SKGTreeView::saveSelection()
         }
 }
 
-void SKGTreeView::setAlternatingRowColors ( bool enable )
-{
-        QTreeView::setAlternatingRowColors ( enable );
-}
-
 void SKGTreeView::resetSelection()
 {
         QItemSelectionModel *selModel=selectionModel();
@@ -492,6 +539,20 @@ void SKGTreeView::resetSelection()
                 if ( model ) {
                         int nbRows=model->rowCount ( QModelIndex() );
                         if ( nbRows ) {
+                                //Expand nodes
+                                foreach ( const QString& exp, expandedNodes ) {
+                                        for ( int i=0; i<nbRows; ++i ) {
+                                                QModelIndex index=model->index ( i, 0, QModelIndex() );
+                                                SKGObjectBase obj=model->getObject ( index );
+                                                if ( obj.getUniqueID() ==exp ) {
+                                                        QModelIndex idxs= ( proxyModel ? proxyModel->mapFromSource ( index ) : index );
+                                                        setExpanded(idxs, true);
+                                                        break;
+                                                }
+                                        }
+                                }
+
+                                //Set selection
                                 foreach ( const QString& sel, selection ) {
                                         for ( int i=0; i<nbRows; ++i ) {
                                                 QModelIndex index=model->index ( i, 0, QModelIndex() );
@@ -510,6 +571,35 @@ void SKGTreeView::resetSelection()
         }
 }
 
+void SKGTreeView::onExpand(const QModelIndex & index)
+{
+        SKGObjectModelBase* model= ( SKGObjectModelBase* ) this->model();
+        QSortFilterProxyModel *proxyModel = qobject_cast<QSortFilterProxyModel *> ( model );
+        if ( proxyModel ) model= ( SKGObjectModelBase* ) proxyModel->sourceModel();
+
+        QModelIndex idxs= ( proxyModel ? proxyModel->mapToSource ( index ) : index );
+
+        SKGObjectBase obj=model->getObject ( idxs );
+        QString id=obj.getUniqueID();
+        expandedNodes.push_back ( id );
+
+}
+
+void SKGTreeView::onCollapse(const QModelIndex & index)
+{
+        SKGObjectModelBase* model= ( SKGObjectModelBase* ) this->model();
+        QSortFilterProxyModel *proxyModel = qobject_cast<QSortFilterProxyModel *> ( model );
+        if ( proxyModel ) model= ( SKGObjectModelBase* ) proxyModel->sourceModel();
+
+        QModelIndex idxs= ( proxyModel ? proxyModel->mapToSource ( index ) : index );
+
+        SKGObjectBase obj=model->getObject ( idxs );
+
+        QString id=obj.getUniqueID();
+        expandedNodes.removeOne(id);
+}
+
+
 static QPoint scrollOffset ( QWidget *widget )
 {
         int x = 0, y = 0;
@@ -667,6 +757,7 @@ void SKGTreeView::timerEvent ( QTimerEvent *event )
 void SKGTreeView::mousePressEvent ( QMouseEvent * event )
 {
         if ( event && event->button() ==Qt::LeftButton && ! ( this->indexAt ( event->pos() ).isValid() ) ) {
+                emit clickEmptyArea();
                 clearSelection();
         }
         QTreeView::mousePressEvent ( event );
@@ -682,7 +773,7 @@ SKGStringListList SKGTreeView::getTable()
         int nb=model->columnCount();
         QStringList cols;
         for ( int i=0; i<nb; i++ ) {
-                cols.append ( model->headerData ( i,Qt::Horizontal, Qt::UserRole ).toString() );
+                cols.append ( model->headerData ( i,Qt::Horizontal, Qt::UserRole ).toString().split('|').at(0) );
         }
         table.append ( cols );
 
@@ -710,7 +801,7 @@ void SKGTreeView::onExportCSV()
                 QFile file ( fileName );
                 if ( !file.open ( QIODevice::WriteOnly | QIODevice::Text ) ) {
                         err.setReturnCode ( ERR_INVALIDARG );
-                        err.setMessage ( tr ( "Save file [%1] failed" ).arg ( fileName ) );
+                        err.setMessage (  i18n( "Save file [%1] failed" , fileName ) );
                 } else {
                         QTextStream out ( &file );
                         QStringList dump=SKGServices::tableToDump ( getTable(), SKGServices::DUMP_CSV );
@@ -740,7 +831,7 @@ void SKGTreeView::onExportTXT()
         QFile file ( fileName );
         if ( !file.open ( QIODevice::WriteOnly | QIODevice::Text ) ) {
                 err.setReturnCode ( ERR_INVALIDARG );
-                err.setMessage ( tr ( "Save file [%1] failed" ).arg ( fileName ) );
+                err.setMessage (  i18n( "Save file [%1] failed" , fileName ) );
         } else {
                 QTextStream out ( &file );
                 QStringList dump=SKGServices::tableToDump ( getTable(), SKGServices::DUMP_TEXT );
