@@ -23,6 +23,7 @@
  */
 #include "skgservices.h"
 #include "skgobjectbase.h"
+#include "skgbasegui_export.h"
 
 #include <kglobal.h>
 #include <QStringList>
@@ -33,11 +34,12 @@
 #include <kmenu.h>
 
 class SKGDocument;
+class QTimer;
 
 /**
  * This file is Skrooge tab widget used by plugins
  */
-class KDE_EXPORT SKGTreeView : public QTreeView
+class SKGBASEGUI_EXPORT SKGTreeView : public QTreeView
 {
         Q_OBJECT
         Q_PROPERTY( QString state READ getState WRITE setState USER true)
@@ -104,6 +106,23 @@ public:
          */
         virtual int getNbSelectedObjects();
 
+        /**
+         * Sets the current selection model to the given selectionModel.
+         * @param selectionModel the selection model
+         */
+        virtual void setSelectionModel ( QItemSelectionModel * selectionModel );
+
+signals:
+        /**
+         * Emitted when the empty area
+         */
+        void clickEmptyArea();
+
+        /**
+         * Emitted 300ms after selection changed
+         */
+        void selectionChangedDelayed();
+
 protected:
 
         /**
@@ -114,6 +133,7 @@ protected:
         virtual void mousePressEvent ( QMouseEvent * event );
 
 public slots:
+
         /**
          * Save the selection
          */
@@ -130,15 +150,25 @@ public slots:
          */
         virtual void setAlternatingRowColors(bool enable);
 
+        /**
+         * Swith the smooth Scrolling mode
+         */
+        virtual void switchSmoothScrolling();
+
+        /**
+         * Reset columns order
+         */
+        virtual void resetColumnsOrder();
+
         /**
          * Resizes all columns based on the size hints of the delegate used to render each item in the columns.
          */
         virtual void resizeColumnsToContents();
 
         /**
-         * Swith the smooth Scrolling mode
+         * Resizes all columns based on the size hints of the delegate used to render each item in the columns.
          */
-        virtual void switchSmoothScrolling();
+        virtual void resizeColumnsToContentsDelayed();
 
 private slots:
         void onExportPDF();
@@ -153,6 +183,11 @@ private slots:
         void changeSchema();
         void saveDefaultClicked();
 
+        void onSelectionChanged();
+
+        void onExpand(const QModelIndex & index);
+        void onCollapse(const QModelIndex & index);
+
 private:
         Q_DISABLE_COPY(SKGTreeView);
 
@@ -167,7 +202,7 @@ private:
         SKGDocument* document;
         QString parameterName;
         QStringList selection;
-
+        QStringList expandedNodes;
 
         typedef enum { Steady, Pressed, ManualScroll, AutoScroll, Stop } State;
         State state;
@@ -177,6 +212,8 @@ private:
         QPoint speed;
         QList<QEvent*> ignored;
         QBasicTimer ticker;
+        QTimer* timerDelayedResize;
+        QTimer* timerSelectionChanged;
 };
 
 #endif // SKGTREEVIEW_H
