@@ -36,7 +36,7 @@ SKGWidget::~SKGWidget()
         document=NULL;
 }
 
-SKGDocument * SKGWidget::getDocument()
+SKGDocument * SKGWidget::getDocument() const
 {
         return document;
 }
@@ -46,7 +46,7 @@ QString SKGWidget::getState()
         return "";
 }
 
-QString SKGWidget::getDefaultStateAttibute()
+QString SKGWidget::getDefaultStateAttribute()
 {
         return "";
 }
