@@ -22,47 +22,51 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgservices.h"
+#include "skgbasemodeler_export.h"
 
 #include <QStringList>
 #include <QDateTime>
 #include <QHash>
+#include <QVariant>
+#include <QIcon>
 
 class QSqlDatabase;
 class SKGObjectBase;
 class SKGError;
 
-/**
- * This structure defines a type of modification
- */
-enum KDE_EXPORT ModificationType {
-        U, /**< Update */
-        I, /**< Insert */
-        D  /**< Delete */
-};
-/**
-* Describe a modification of an object
-*/
-struct KDE_EXPORT SKGObjectModification {
-        QString uuid; 				/**< The uuid of the object */
-        int id; 				/**< The id of the object */
-        QString table; 				/**< The table of the object */
-        ModificationType type; 			/**< The type of modification */
-} ;
-
-/**
- * A list of SKGObjectModification ==> SKGObjectModificationList
- */
-typedef QList<SKGObjectModification> SKGObjectModificationList;
-
 /**
 * This class manages skg documents
 */
-class KDE_EXPORT SKGDocument : public QObject
+class SKGBASEMODELER_EXPORT SKGDocument : public QObject
 {
         Q_OBJECT;
         Q_ENUMS(UndoRedoMode);
 
 public:
+        /**
+         * This structure defines a type of modification
+         */
+        enum ModificationType {
+                U, /**< Update */
+                I, /**< Insert */
+                D  /**< Delete */
+        };
+
+        /**
+         * Describe a modification of an object
+         */
+        struct SKGObjectModification {
+                QString uuid; 				/**< The uuid of the object */
+                int id; 				/**< The id of the object */
+                QString table; 				/**< The table of the object */
+                ModificationType type; 			/**< The type of modification */
+        } ;
+
+        /**
+         * A list of SKGObjectModification ==> SKGObjectModificationList
+         */
+        typedef QList<SKGObjectModification> SKGObjectModificationList;
+
         /**
          * This structure defines the direction of the UNDO / REDO mechanism
          */
@@ -212,8 +216,8 @@ public:
          * @return the internal identifier of the last transaction
          * 0 if no transaction found
          */
-        virtual int getTransactionToTreat(const UndoRedoMode& iMode = SKGDocument::UNDO, QString* oName = NULL,
-                                          bool* oSaveStep=NULL, QDateTime* oDate=NULL) const;
+        virtual int getTransactionToProcess(const UndoRedoMode& iMode = SKGDocument::UNDO, QString* oName = NULL,
+                                            bool* oSaveStep=NULL, QDateTime* oDate=NULL) const;
 
         /**
          * Return the identifier of the current transaction
@@ -268,10 +272,11 @@ public:
          * @see endTransaction
          * @param iName the file name to load.
          * @param iPassword the password of the SKGDocument.
+         * @param iRestoreTmpFile restore the temporary file if existing.
          * @return an object managing the error.
          *   @see SKGError
          */
-        virtual SKGError load(const QString & iName, const QString & iPassword="");
+        virtual SKGError load(const QString & iName, const QString & iPassword="", bool iRestoreTmpFile=false);
 
         /**
          * To know if the current document has been modified or not.
@@ -315,10 +320,20 @@ public:
         virtual SKGError close();
 
         /**
-         * Set the message associated to this SKGError.
+         * Get a parameter value
          * @param iName the parameter unique identifier.
+         * @param iParentUUID the unique identifier of the object owning this parameter.
+         * @return the value.
          */
-        virtual QString getParameter(const QString& iName) const;
+        virtual QString getParameter(const QString& iName, const QString& iParentUUID="document") const;
+
+        /**
+         * Get a parameter blob
+         * @param iName the parameter unique identifier.
+         * @param iParentUUID the unique identifier of the object owning this parameter.
+         * @return the blob.
+         */
+        virtual QVariant getParameterBlob(const QString& iName, const QString& iParentUUID="document") const;
 
         /**
          * Set a parameter.
@@ -326,10 +341,14 @@ public:
          * @see beginTransaction
          * @param iName the parameter unique identifier.
          * @param iValue the parameter value.
+         * @param iBlob the parameter blob.
+         * @param iParentUUID the unique identifier of the object owning this parameter.
+         * @param oObjectCreated the parameter object created
          * @return an object managing the error.
          *   @see SKGError
          */
-        virtual SKGError setParameter(const QString& iName, const QString& iValue) const;
+        virtual SKGError setParameter(const QString& iName, const QString& iValue, const QVariant& iBlob=QVariant(),
+                                      const QString& iParentUUID="document", SKGObjectBase* oObjectCreated=NULL) const;
 
         /**
          * Get the database pointer.
@@ -385,6 +404,20 @@ public:
          */
         virtual QString getDisplay(const QString& iString) const;
 
+        /**
+         * Get the icon for attribute
+         * @param iString the name of the attribute
+         * @return the icon
+         */
+        virtual QIcon getIcon(const QString& iString) const;
+
+        /**
+         * Get the attribute type
+         * @param iAttributeName the name of an attribute
+         * @return the type
+         */
+        virtual SKGServices::AttibuteType getAttibuteType(const QString& iAttributeName) const;
+
         /**
          * Add a value in the cache. Cache is cleaned after each transaction
          * @param iKey the key
@@ -399,6 +432,23 @@ public:
          */
         virtual QString getCachedValue(const QString& iKey) const;
 
+        /**
+         * Set backup parameters.
+         * The key word \<DATE\> is supported.
+         * Call setBackupParameters() to avoid backup creation.
+         * @param iPrefix the prefix for the backup file
+         * @param iSuffix the suffix for backup file
+         */
+        virtual void setBackupParameters(const QString& iPrefix="", const QString& iSuffix="");
+
+        /**
+         * Get the temporary file for a document
+         * @param iFileName the document
+         * @return the temporary file
+         */
+        static QString getTemporaryFile(const QString iFileName);
+
+
 signals:
         /**
          * This signal is launched by endTransaction on all tables modified when a huge modification occures on the model
@@ -468,6 +518,7 @@ protected:
 private:
         Q_DISABLE_COPY(SKGDocument);
 
+        QString getBackupFile(const QString iFileName);
 
         static SKGError lastCallbackError;
 
@@ -490,6 +541,8 @@ private:
 
         QHash<QString, QString> cache;
         bool inProgress;
+        QString backupPrefix;
+        QString backupSuffix;
 };
 
 #endif
