@@ -96,7 +96,7 @@ QString SKGError::getMessage() const
 
 QString SKGError::getFullMessage() const
 {
-        QString output = "[";
+        QString output('[');
         output += (rc == 0 ? "SUC" : (rc > 0 ? "ERR" : "WAR"));
         output += '-';
 
