@@ -24,6 +24,8 @@
 #include "skgdocument.h"
 #include "skgnamedobject.h"
 
+#include <klocale.h>
+
 #include <QSqlDatabase>
 
 SKGError SKGObjectBase::getObjects(const SKGDocument* iDocument, const QString& iTable,
@@ -90,9 +92,9 @@ SKGError SKGObjectBase::getObject(const SKGDocument* iDocument, const QString& i
         SKGError err = SKGObjectBase::getObjects(iDocument, iTable, iWhereClause, temporaryResult);
         if (err.isSucceeded()) {
                 int size=temporaryResult.size();
-                if (size> 1)  err=SKGError(ERR_INVALIDARG, tr("SKGObjectBase::getObject failed because more than one object returned in [%1] for [%2]").arg(iTable).arg(iWhereClause));
+                if (size> 1)  err=SKGError(ERR_INVALIDARG, i18n("More than one object returned in [%1] for [%2]",iTable,iWhereClause));
                 else {
-                        if (size==0)  err=SKGError(ERR_INVALIDARG, tr("SKGObjectBase::getObject failed because no object returned in [%1] for [%2]").arg(iTable).arg(iWhereClause));
+                        if (size==0)  err=SKGError(ERR_INVALIDARG, i18n("No object returned in [%1] for [%2]",iTable,iWhereClause));
                         else  oObject = *(temporaryResult.begin());
                 }
         }
@@ -138,6 +140,20 @@ bool SKGObjectBase::operator!=(const SKGObjectBase& iObject) const
         return !(*this==iObject);
 }
 
+bool SKGObjectBase::operator<(const SKGObjectBase& iObject) const
+{
+        double d1=SKGServices::stringToDouble(getAttribute("f_sortorder"));
+        double d2=SKGServices::stringToDouble(iObject.getAttribute("f_sortorder"));
+        return (d1<d2);
+}
+
+bool SKGObjectBase::operator>(const SKGObjectBase& iObject) const
+{
+        double d1=SKGServices::stringToDouble(getAttribute("f_sortorder"));
+        double d2=SKGServices::stringToDouble(iObject.getAttribute("f_sortorder"));
+        return (d1>d2);
+}
+
 QString SKGObjectBase::getUniqueID() const
 {
         return SKGServices::intToString(id) + '-' + getRealTable();
@@ -269,9 +285,9 @@ SKGError SKGObjectBase::load()
         if (err.isSucceeded()) {
                 int size=result.size();
                 if ( size== 1) {
-                        err = SKGError(ERR_INVALIDARG, tr("SKGObjectBase::load of [%1] with [%2] failed because it was not found in the database").arg(table).arg(wc));
+                        err = SKGError(ERR_INVALIDARG, i18n("Load of [%1] with [%2] failed because it was not found in the database",table,wc));
                 } else if (size != 2) {
-                        err = SKGError(ERR_INVALIDARG, tr("SKGObjectBase::load of [%1] with [%2] failed because of bad size of result (found %3 object(s))").arg(table).arg(wc).arg(size-1));
+                        err = SKGError(ERR_INVALIDARG, i18n("Load of [%1] with [%2] failed because of bad size of result (found %3 object(s))",table,wc,size-1));
                 } else {
                         SKGStringListListIterator itrow = result.begin();
                         QStringList columns = *(itrow);
@@ -296,7 +312,7 @@ SKGError SKGObjectBase::save(bool iInsertOrUpdate, bool iReloadAfterSave)
         SKGError err;
         SKGTRACEINRC(20, "SKGObjectBase::save", err);
 
-        if (!document) err=SKGError(ERR_POINTER, tr("Operation impossible because the document is missing"));
+        if (!document) err=SKGError(ERR_POINTER, i18n("Operation impossible because the document is missing"));
         else {
                 //Check if we are in a transaction
                 err = document->checkExistingTransaction();
@@ -357,26 +373,38 @@ SKGError SKGObjectBase::save(bool iInsertOrUpdate, bool iReloadAfterSave)
                 err = load();
         }
 
-        if (err.isFailed()) err.addError(ERR_FAIL, tr("%1 on [%2] failed").arg("SKGObjectBase::save").arg(getUniqueID()));
-
         return err;
 }
 
-SKGError SKGObjectBase::remove() const
+SKGError SKGObjectBase::remove(bool iSendMessage) const
 {
         SKGError err;
         SKGTRACEINRC(20, "SKGObjectBase::remove", err);
-        if (!document) err=SKGError(ERR_POINTER, tr("Operation impossible because the document is missing"));
+        if (!document) err=SKGError(ERR_POINTER, i18n("Operation impossible because the document is missing"));
         else {
                 //Check if we are in a transaction
                 err = document->checkExistingTransaction();
 
                 //delete order
-                if (err.isSucceeded()) err=((SKGDocument*) document)->sendMessage(tr("[%1] has been deleted").arg(getDisplayName()), false);
-                if (err.isSucceeded()) err=SKGServices::executeSqliteOrder(document, "DELETE FROM "+getRealTable()+" where id="+SKGServices::intToString(id));
-        }
+                QString viewForDelete=QString("v_")+getRealTable()+"_delete";
 
-        if (err.isFailed()) err.addError(ERR_FAIL, tr("%1 on [%2] failed").arg("SKGObjectBase::delete").arg(getUniqueID()));
+                //Check if the delete view exist
+                SKGStringListList temporaryResult;
+                SKGServices::executeSelectSqliteOrder(document, "PRAGMA table_info( " + viewForDelete + " );",temporaryResult);
+                if (temporaryResult.count()>1) { //At least one attribute
+                        //Delete view exists, check if the delete is authorized
+                        int nb=0;
+                        SKGObjectBase::getNbObjects(document, viewForDelete,"id="+SKGServices::intToString(id), nb);
+                        if (nb!=1) {
+                                err=SKGError(ERR_FAIL, i18n("You are not authorized to delete this object"));
+                        }
+                }
+
+                QString displayname=getDisplayName(); //Must be done before the delete order
+                if (err.isSucceeded()) err=SKGServices::executeSqliteOrder(document, "DELETE FROM "+getRealTable()+" WHERE id="+SKGServices::intToString(id));
+                if (iSendMessage && err.isSucceeded() && !displayname.isEmpty())
+                        err=((SKGDocument*) document)->sendMessage(i18n("[%1] has been deleted",displayname), false);
+        }
 
         return err;
 }
@@ -394,70 +422,20 @@ SKGError SKGObjectBase::dump()
         return err;
 }
 
-QStringList SKGObjectBase::getProperties() const
-{
-        SKGTRACEIN(10, "SKGObjectBase::getProperties");
-        QStringList output;
-
-        //Get parameter
-        SKGListSKGObjectBase params;
-        SKGError err = SKGObjectBase::getObjects(getDocument() , "parameters",
-                        "t_uuid_parent='"+getUniqueID()+'\'', params);
-        if (err.isSucceeded()) {
-                int nb=params.count();
-                for (int i=0; i<nb; ++i) {
-                        output.push_back(params[i].getAttribute("t_name"));
-                }
-        }
-        return output;
-}
-
-SKGObjectBase SKGObjectBase::getPropertyObject(const QString& iName) const
-{
-        SKGTRACEIN(10, "SKGObjectBase::getPropertyObject");
-        SKGTRACEL(10) << "Input parameter [iName]=[" << iName << ']' << endl;
-
-        //Get parameter
-        SKGObjectBase property;
-        SKGObjectBase::getObject(getDocument() , "parameters",
-                                 "t_name='"+iName+"' AND t_uuid_parent='"+getUniqueID()+'\'',
-                                 property);
-        return property;
-}
-
 QString SKGObjectBase::getProperty(const QString& iName) const
 {
-        SKGTRACEIN(10, "SKGObjectBase::getProperty");
-        SKGTRACEL(10) << "Input parameter [iName]=[" << iName << ']' << endl;
-        QString output = "";
-
-        //Get parameter
-        SKGObjectBase param;
-        SKGError err = SKGObjectBase::getObject(getDocument() , "parameters",
-                                                "t_name='"+iName+"' AND t_uuid_parent='"+getUniqueID()+'\'',
-                                                param);
-        if (err.isSucceeded()) output = param.getAttribute("t_value");
-
-        return output;
+        return getDocument()->getParameter(iName, getUniqueID());
 }
 
-SKGError SKGObjectBase::setProperty(const QString& iName, const QString& iValue)
+QVariant SKGObjectBase::getPropertyBlob(const QString& iName) const
 {
-        SKGError err;
-        SKGTRACEINRC(10, "SKGObjectBase::setProperty", err);
-        SKGTRACEL(10) << "Input parameter [iName]=[" << iName << ']' << endl;
-        SKGTRACEL(10) << "Input parameter [iValue]=[" << iValue << ']' << endl;
-        if (getUniqueID().isEmpty()) err=SKGError(ERR_FAIL, tr("%1 failed because linked object is not yet saved in the database.").arg("SKGObjectBase::setProperty"));
-        else {
-                SKGNamedObject param(getDocument() , "parameters");
-                if (err.isSucceeded()) err = param.setName(iName);
-                if (err.isSucceeded()) err = param.setAttribute("t_value", iValue);
-                if (err.isSucceeded()) err = param.setAttribute("t_uuid_parent", getUniqueID());
-                if (err.isSucceeded()) err = param.save();
+        return getDocument()->getParameterBlob(iName, getUniqueID());
+}
+
+SKGError SKGObjectBase::setProperty(const QString& iName, const QString& iValue, const QVariant& iBlob, SKGObjectBase* oObjectCreated)
+{
+        return getDocument()->setParameter(iName, iValue, iBlob, getUniqueID(), oObjectCreated);
 
-                if (err.isFailed()) err.addError(ERR_FAIL, tr("SKGObjectBase::setProperty(%1,%2) failed").arg(iName).arg(iValue));
-        }
-        return err;
 }
 
 #include "skgobjectbase.moc"
