@@ -23,15 +23,17 @@
 #include "skgtraces.h"
 #include "skgdocument.h"
 
+#include <klocale.h>
+
 #include <sys/time.h>
 
 #include <QSqlDatabase>
 #include <QSqlQuery>
 #include <QSqlRecord>
 #include <QSqlError>
+#include <QSqlDriver>
 #include <QVariant>
 #include <QRegExp>
-#include <QSqlDriver>
 #include <QFile>
 #include <QtCrypto>
 
@@ -77,13 +79,35 @@ QString SKGServices::stringToSqlString(const QString& iString)
         return output;
 }
 
-QString SKGServices::stringsToCsv(const QStringList& iList)
+QString SKGServices::stringToHtml(const QString& iString)
+{
+        QString output=iString;
+        output.replace('&',"&amp;"); //Must be done first
+        output.replace('<',"&lt;");
+        output.replace('>',"&gt;");
+        output.replace('"',"&quot;");
+
+        return output;
+}
+
+QString SKGServices::htmlToString(const QString& iString)
+{
+        QString output=iString;
+        output.replace("&lt;", "<");
+        output.replace("&gt;", ">");
+        output.replace("&quot;", "\"");
+        output.replace("&amp;", "&");
+
+        return output;
+}
+
+QString SKGServices::stringsToCsv(const QStringList& iList, const QChar& iSeparator)
 {
         QString output;
         int nb=iList.count();
         for (int i=0; i<nb; ++i) {
                 output.append(SKGServices::stringToCsv(iList[i]));
-                if (i<nb-1) output.append(";");
+                if (i<nb-1) output.append(iSeparator);
         }
 
         return output;
@@ -152,11 +176,12 @@ QDateTime SKGServices::stringToTime(const QString& iDateString)
         return output;
 }
 
-QStringList SKGServices::splitCSVLine(const QString& iString, const QChar& iSeparator, bool iCoteDefineBlock)
+QStringList SKGServices::splitCSVLine(const QString& iString, const QChar& iSeparator, bool iCoteDefineBlock, QChar* oRealSeparator)
 {
         QStringList items;
         QString item;
         bool isInBlock = false;
+        QChar realSeparator=iSeparator;
 
         int nb=iString.length();
         for (int pos = 0; pos < nb; ++pos) {
@@ -169,14 +194,15 @@ QStringList SKGServices::splitCSVLine(const QString& iString, const QChar& iSepa
                                         item="";
                                         isInBlock = false;
 
-                                        ++pos; //to ignore next separator
+                                        ++pos; //To ignore next separator
+                                        if (pos<nb) realSeparator=iString.at(pos); //To get the real separator
                                 }
                         }
 
                         if (isInBlock) item+=c;
                 } else  if (c=='\"' && iCoteDefineBlock) {
                         isInBlock = true;
-                } else  if (QString(c)==iSeparator) {
+                } else  if (QString(c)==realSeparator) {
                         items.push_back(item);
                         item="";
                         isInBlock = false;
@@ -185,7 +211,9 @@ QStringList SKGServices::splitCSVLine(const QString& iString, const QChar& iSepa
                 }
         }
 
-        if (!item.isEmpty() || (nb>0 && iString.at(nb-1)==iSeparator)) items.push_back(item);
+        if (!item.isEmpty() || (nb>0 && iString.at(nb-1)==realSeparator)) items.push_back(item);
+
+        if (oRealSeparator) *oRealSeparator=realSeparator;
 
         return items;
 }
@@ -400,7 +428,7 @@ QStringList SKGServices::tableToDump(const SKGStringListList& iTable, DumpMode i
 QString SKGServices::getRealTable(const QString& iTable)
 {
         QString output=iTable;
-        if (output.length() > 2 && output.startsWith("v_")) {
+        if (output.length() > 2 && output.startsWith(QLatin1String("v_"))) {
                 output = output.mid(2, output.length() - 2);
 
                 int pos=output.indexOf("_");
@@ -418,7 +446,7 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
         SKGTRACEL(10) << "Input parameter [iFileTarget]=[" << iFileTarget << ']' << endl;
         if (iPassword.isEmpty()) {
                 if (!QFile::copy(iFileSource, iFileTarget)) {
-                        err = SKGError(ERR_FAIL, tr("copy of %1 to %2 failed").arg(iFileSource).arg(iFileTarget));
+                        err = SKGError(ERR_FAIL, i18n("copy of %1 to %2 failed",iFileSource,iFileTarget));
                 }
         } else {
                 QCA::Initializer init;
@@ -439,7 +467,7 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
                                    iEncrypt ? QCA::Encode : QCA::Decode,
                                    key, iv);
                 QFile fileInput(iFileSource);
-                if (!fileInput.open(QIODevice::ReadOnly)) err=SKGError(ERR_INVALIDARG, tr("Open file [%1] failed").arg(iFileSource));
+                if (!fileInput.open(QIODevice::ReadOnly)) err=SKGError(ERR_INVALIDARG, i18n("Open file [%1] failed",iFileSource));
                 else {
                         QByteArray input = fileInput.readAll();
 
@@ -450,30 +478,30 @@ SKGError SKGServices::cryptFile(const QString& iFileSource, const QString& iFile
                         QCA::SecureArray u = cipher.update(input);
 
                         // We need to check if that update() call worked.
-                        if (!cipher.ok()) {
-                                err=SKGError(ERR_FAIL, tr("Encryption failed"));
-                        }
+                        if (!cipher.ok()) err=SKGError(ERR_FAIL, i18n("Encryption failed"));
+
                         // output the results of that stage
-                        QFile fileOutput(iFileTarget);
-                        if (!fileOutput.open(QIODevice::WriteOnly)) err=SKGError(ERR_INVALIDARG, tr("Write file [%1] failed").arg(iFileTarget));
-                        else {
-                                fileOutput.write(u.toByteArray());
+                        if (err.isSucceeded()) {
+                                QFile fileOutput(iFileTarget);
+                                if (!fileOutput.open(QIODevice::WriteOnly)) err=SKGError(ERR_INVALIDARG, i18n("Write file [%1] failed",iFileTarget));
+                                else {
+                                        fileOutput.write(u.toByteArray());
 
-                                // Because we are using PKCS7 padding, we need to output the final (padded) block
-                                // Note that we should always call final() even with no padding, to clean up
-                                QCA::SecureArray f = cipher.final();
+                                        // Because we are using PKCS7 padding, we need to output the final (padded) block
+                                        // Note that we should always call final() even with no padding, to clean up
+                                        QCA::SecureArray f = cipher.final();
 
-                                // Check if the final() call worked
-                                if (!cipher.ok()) {
-                                        err=SKGError(ERR_FAIL, tr("Encryption failed"));
+                                        // Check if the final() call worked
+                                        if (!cipher.ok()) err=SKGError(ERR_FAIL, i18n("Encryption failed"));
+
+                                        // and output the resulting block. The ciphertext is the results of update()
+                                        // and the result of final()
+                                        fileOutput.write(f.toByteArray());
+
+                                        //Close the file
+                                        fileOutput.flush();
+                                        fileOutput.close();
                                 }
-                                // and output the resulting block. The ciphertext is the results of update()
-                                // and the result of final()
-                                fileOutput.write(f.toByteArray());
-
-                                //Close the file
-                                fileOutput.flush();
-                                fileOutput.close();
                         }
                 }
         }
@@ -535,11 +563,11 @@ SKGError SKGServices::copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iM
                                 if (err.isSucceeded() && !iFromFileToMemory && !QFile(dbFileName).exists()) {
                                         //Set error message
                                         err.setReturnCode(ERR_FAIL);
-                                        err.setMessage(tr("Creation file [%1] failed").arg(dbFileName));
+                                        err.setMessage(i18n("Creation file [%1] failed",dbFileName));
                                 }
                         }
                 }
-                if (err.isFailed()) err.addError(SQLLITEERROR + ERR_FAIL, tr("copySqliteDatabase::copySqliteDatabase() failed"));
+                if (err.isFailed()) err.addError(SQLLITEERROR + ERR_FAIL, i18n("%1 failed", QString("copySqliteDatabase::copySqliteDatabase()")));
         }
         return err;
 }
@@ -549,7 +577,7 @@ SKGError SKGServices::executeSqliteOrder(const SKGDocument* iDocument, const QSt
         SKGError err;
         _SKGTRACEINRC(10, "SKGServices::ExecuteSqlOrder(SKGDocument)", err);
         if (iDocument == NULL) {
-                err = SKGError(ERR_POINTER, tr("No database defined"));
+                err = SKGError(ERR_POINTER, i18n("No database defined"));
         } else {
                 err = SKGServices::executeSqliteOrder(iDocument->getDatabase(), iSqlOrder, iLastId);
         }
@@ -563,7 +591,7 @@ SKGError SKGServices::executeSqliteOrder(QSqlDatabase* iDb, const QString& iSqlO
         SKGTRACEL(20) << "Input parameter [iSqlOrder]=[" << iSqlOrder << ']' << endl;
 
         if (iDb == NULL) {
-                err = SKGError(ERR_POINTER, tr("No database defined"));
+                err = SKGError(ERR_POINTER, i18n("No database defined"));
         } else {
                 QStringList listSqlOrder=iSqlOrder.split(";;", QString::SkipEmptyParts);
                 int nb=listSqlOrder.size();
@@ -581,15 +609,23 @@ SKGError SKGServices::executeSqliteOrder(QSqlDatabase* iDb, const QString& iSqlO
 
                         if (!query.exec(iSqlOrder)) {
                                 QSqlError sqlError=query.lastError();
-                                QString msg=iSqlOrder+':'+sqlError.text();
-                                QVariant v = iDb->driver()->handle();
-                                sqlite3 *handle = *static_cast<sqlite3 **>(v.data());
-                                if (handle != 0) { // check that it is not NULL
-                                        QString dmsg=sqlite3_errmsg(handle);
-                                        if (!dmsg.isEmpty()) msg+=". "+dmsg;
+                                if (sqlError.number()!=SQLITE_CONSTRAINT) {
+                                        SKGTRACE << "WARNING: " << iSqlOrder << endl;
+                                        SKGTRACE << "         returns :" << sqlError.text() << endl;
                                 }
 
+                                QString msg=iSqlOrder+':'+sqlError.text();
                                 err = SKGError(SQLLITEERROR + sqlError.number(), msg);
+
+                                QVariant v = iDb->driver()->handle();
+                                if (v.isValid() && qstrcmp(v.typeName(), "sqlite3*")==0) {
+                                        sqlite3* handle = *static_cast<sqlite3 **>(v.data());
+                                        if (handle != NULL) { // check that it is not NULL
+                                                QString dmsg=sqlite3_errmsg(handle);
+                                                if (!dmsg.isEmpty()) err.addError(SQLLITEERROR + sqlError.number(), dmsg);
+                                        }
+                                }
+
                         } else {
                                 if (iLastId) *iLastId=query.lastInsertId().toInt();
                         }
@@ -629,7 +665,7 @@ SKGError SKGServices::dumpSelectSqliteOrder(const SKGDocument* iDocument, const
         SKGError err;
         _SKGTRACEINRC(10, "SKGServices::dumpSelectSqliteOrder(SKGDocument)", err);
 
-        if (iDocument == NULL) err = SKGError(ERR_POINTER, tr("No database defined"));
+        if (iDocument == NULL) err = SKGError(ERR_POINTER, i18n("No database defined"));
         else  err = SKGServices::dumpSelectSqliteOrder(iDocument->getDatabase(), iSqlOrder, oStream, iMode);
         return err;
 }
@@ -657,7 +693,7 @@ SKGError SKGServices::dumpSelectSqliteOrder(const SKGDocument* iDocument, const
 {
         SKGError err;
         _SKGTRACEINRC(10, "SKGServices::dumpSelectSqliteOrder(SKGDocument)", err);
-        if (iDocument == NULL) err = SKGError(ERR_POINTER, tr("No database defined"));
+        if (iDocument == NULL) err = SKGError(ERR_POINTER, i18n("No database defined"));
         else  err = SKGServices::dumpSelectSqliteOrder(iDocument->getDatabase(), iSqlOrder, oResult, iMode);
         return err;
 }
@@ -678,7 +714,7 @@ SKGError SKGServices::dumpSelectSqliteOrder(const SKGDocument* iDocument, const
 {
         SKGError err;
         _SKGTRACEINRC(10, "SKGServices::dumpSelectSqliteOrder(SKGDocument)", err);
-        if (iDocument == NULL) err = SKGError(ERR_POINTER, tr("No database defined"));
+        if (iDocument == NULL) err = SKGError(ERR_POINTER, i18n("No database defined"));
         else err = SKGServices::dumpSelectSqliteOrder(iDocument->getDatabase(), iSqlOrder, oResult, iMode);
         return err;
 }
@@ -690,7 +726,7 @@ SKGError SKGServices::executeSelectSqliteOrder(QSqlDatabase* iDb, const QString&
         //initialisation
         oResult.clear();
 
-        if (iDb == NULL) err = SKGError(ERR_POINTER, tr("No database defined"));
+        if (iDb == NULL) err = SKGError(ERR_POINTER, i18n("No database defined"));
         else {
                 QSqlQuery query(QString(), *iDb);
                 double elapse=0;
@@ -703,9 +739,9 @@ SKGError SKGServices::executeSelectSqliteOrder(QSqlDatabase* iDb, const QString&
                         err = SKGError(SQLLITEERROR + sqlError.number(), iSqlOrder+':'+sqlError.text());
                 } else {
                         if (SKGServices::SKGSqlTraces) {
-                                elapse=SKGServices::getMicroTime() - elapse;
-                                if (elapse>=SKGServices::SKGSqlTraces) {
-                                        SKGTRACE << "executeSqliteOrder :" << iSqlOrder << " TIME=" << elapse << " ms" << endl;
+                                double elapse1=SKGServices::getMicroTime() - elapse;
+                                if (elapse1>=SKGServices::SKGSqlTraces) {
+                                        SKGTRACE << "executeSqliteOrder :" << iSqlOrder << " TIME=" << elapse1 << " ms" << endl;
                                 }
                         }
 
@@ -739,6 +775,12 @@ SKGError SKGServices::executeSelectSqliteOrder(QSqlDatabase* iDb, const QString&
                                 }
                                 oResult.push_back(line);
                         }
+                        if (SKGServices::SKGSqlTraces) {
+                                double elapse1=SKGServices::getMicroTime() - elapse;
+                                if (elapse1>=SKGServices::SKGSqlTraces) {
+                                        SKGTRACE << "executeSqliteOrder (with fetch) :" << iSqlOrder << " TIME=" << elapse1 << " ms" << endl;
+                                }
+                        }
                 }
         }
         return err;
@@ -749,7 +791,7 @@ SKGError SKGServices::executeSelectSqliteOrder(const SKGDocument* iDocument, con
         SKGError err;
         _SKGTRACEINRC(10, "SKGServices::executeSelectSqliteOrder(SKGDocument)", err);
         oResult.clear();
-        if (iDocument == NULL) err = SKGError(ERR_POINTER, tr("No database defined"));
+        if (iDocument == NULL) err = SKGError(ERR_POINTER, i18n("No database defined"));
         else  err = SKGServices::executeSelectSqliteOrder(iDocument->getDatabase(), iSqlOrder, oResult);
         return err;
 }
@@ -767,8 +809,11 @@ SKGError SKGServices::getDistinctValues(const SKGDocument* iDocument, const QStr
                         "SELECT DISTINCT " + iAttribute +
                         " FROM " + iTable + " WHERE (" +
                         (iWhereClause.length() ? iWhereClause : "1=1") +
-                        ") ORDER BY " + iAttribute,
-                        temporaryResult);
+                        ") ORDER BY " + iAttribute
+                        //Correction bug 202167 vvv
+                        +" COLLATE NOCASE"
+                        //Correction bug 202167 ^^^
+                        , temporaryResult);
         if (err.isSucceeded()) {
                 SKGStringListListIterator it = temporaryResult.begin();
                 ++it; //to forget column name
@@ -803,16 +848,24 @@ SKGError SKGServices::getAttributesDescription(const SKGDocument* iDocument, con
 
         //Search
         SKGStringListList temporaryResult;
-        err = SKGServices::executeSelectSqliteOrder((SKGDocument*) iDocument,
-                        "PRAGMA table_info( " + iTable + " );",temporaryResult);
-        if (err.isSucceeded()) {
+        err = SKGServices::executeSelectSqliteOrder((SKGDocument*) iDocument, "PRAGMA table_info( " + iTable + " );",temporaryResult);
+        if (err.isSucceeded() && iDocument) {
                 int nblines=temporaryResult.count();
+                QString realTable=SKGServices::getRealTable(iTable);
+
                 for (int i=1; i<nblines; ++i) { // the first one is ignored because it is the headers
                         QStringList line=temporaryResult[i];
 
                         SKGAttributeInfo attribute;
                         attribute.name=line[1];
-                        attribute.type=line[2];
+
+                        QString attname=realTable+'.'+attribute.name;
+                        attribute.display=iDocument->getDisplay(attname);
+                        if (attribute.display==attname) {
+                                attribute.display="";
+                        }
+                        attribute.icon=iDocument->getIcon(attname);
+                        attribute.type=iDocument->getAttibuteType(attribute.name);
                         attribute.notnull=(line[3]=="0");
                         attribute.defaultvalue=line[4];
                         oResult.push_back(attribute);
@@ -845,7 +898,7 @@ double SKGServices::getMicroTime()
         gettimeofday(&tv, &tz);
 
         //return time
-        return (static_cast<double>(1000.0 * tv.tv_sec)) + (static_cast<double>(tv.tv_usec / 1000.0));
+        return (static_cast<double>(1000.0 * tv.tv_sec)) + (static_cast<double>(tv.tv_usec / 1000));
 }
 
 #include "skgservices.moc"
