@@ -131,19 +131,35 @@ SKGTraces::~SKGTraces()
         }
 }
 
-void SKGTraces::exit(int rc)
+void SKGTraces::cleanProfilingStatistics()
 {
-        if (SKGPerfo) {
-                SKGTRACESEPARATOR;
-                SKGTRACE << "methode , nb call , millisecondes , moyenne , min , max , propre , moyenne propre" << endl << flush;
+        SKGTraces::SKGPerfoMethode.clear();
+}
 
-                while (!SKGTraces::SKGPerfoMethode.empty()) {
+void SKGTraces::dumpProfilingStatistics()
+{
+        QStringList dump=getProfilingStatistics();
+
+        int nbl=dump.count();
+        for (int i=0; i<nbl; ++i) {
+                SKGTRACE << dump[i] << endl;
+        }
+}
+
+QStringList SKGTraces::getProfilingStatistics()
+{
+        QStringList output;
+        if (SKGPerfo) {
+                output.push_back("method , nb call , millisecondes , average , min , max , own time , average own time");
+
+                SKGPerfoMap SKGPerfoMethodeCopy=SKGPerfoMethode;
+                while (!SKGPerfoMethodeCopy.empty()) {
 
                         //Recheche du temps propre maximal
                         double maxtime = -1;
                         SKGPerfoMapIterator max;
                         SKGPerfoMapIterator it2;
-                        for (it2 = SKGTraces::SKGPerfoMethode.begin() ; it2 != SKGTraces::SKGPerfoMethode.end(); ++it2) {
+                        for (it2 = SKGPerfoMethodeCopy.begin() ; it2 != SKGPerfoMethodeCopy.end(); ++it2) {
                                 if (it2.value().TimePropre > maxtime) {
                                         maxtime = it2.value().TimePropre;
                                         max = it2;
@@ -152,34 +168,20 @@ void SKGTraces::exit(int rc)
 
                         //dump max
                         if (maxtime!=-1) {
-                                SKGTRACE << max.key()
-                                << " , " << max.value().NbCall
-                                << " , " << max.value().Time
-                                << " , " << (max.value().Time) / (static_cast<double>(max.value().NbCall))
-                                << " , " << max.value().TimeMin
-                                << " , " << max.value().TimeMax
-                                << " , " << max.value().TimePropre
-                                << " , " << (max.value().TimePropre) / (static_cast<double>(max.value().NbCall))
-                                << endl << flush;
+                                output.push_back(max.key()
+                                                 + " , " + SKGServices::intToString(max.value().NbCall)
+                                                 + " , " + SKGServices::doubleToString(max.value().Time)
+                                                 + " , " + SKGServices::doubleToString((max.value().Time) / (static_cast<double>(max.value().NbCall)))
+                                                 + " , " + SKGServices::doubleToString(max.value().TimeMin)
+                                                 + " , " + SKGServices::doubleToString(max.value().TimeMax)
+                                                 + " , " + SKGServices::doubleToString(max.value().TimePropre)
+                                                 + " , " + SKGServices::doubleToString((max.value().TimePropre) / (static_cast<double>(max.value().NbCall))));
 
                                 //Remove it
-                                SKGTraces::SKGPerfoMethode.erase(max);
+                                SKGPerfoMethodeCopy.erase(max);
                         }
                 }
         }
 
-        //Clear
-        SKGTraces::SKGPerfoMethode.clear();
-
-        if (rc == 0) {
-                SKGTRACESEPARATOR;
-                SKGTRACE << "SUCCEEDED" << endl << flush;
-                SKGTRACESEPARATOR;
-        } else {
-                SKGTRACESEPARATOR;
-                SKGTRACE << "FAILED" << endl << flush;
-                SKGTRACESEPARATOR;
-        }
-
-        ::exit(rc);
+        return output;
 }
