@@ -24,7 +24,7 @@
 #include "skgdefine.h"
 
 #include <QTextStream>
-#include <QString>
+#include <QStringList>
 #include <QMap>
 #include <QStack>
 
@@ -105,7 +105,7 @@ class SKGError;
 /**
 * This class manages traces
 */
-class KDE_EXPORT SKGTraces
+class SKGBASEMODELER_EXPORT SKGTraces
 {
 public:
         /**
@@ -125,11 +125,19 @@ public:
         virtual ~SKGTraces();
 
         /**
-        * Exit
-        * @param rc
-        *   The return code
+         * Clean profiling statistics
+         */
+        static void cleanProfilingStatistics();
+
+        /**
+        * Get profiling statistics
         */
-        static void exit(int rc);
+        static QStringList getProfilingStatistics();
+
+        /**
+         * Dump profiling statistics
+         */
+        static void dumpProfilingStatistics();
 
 public:
         /**
