@@ -37,7 +37,7 @@ int main(int argc, char** argv)
         //Test class SKGError
         {
                 SKGError err;
-		SKGTEST("ERR:Default RC", err.getReturnCode(), 0);
+                SKGTEST("ERR:Default RC", err.getReturnCode(), 0);
                 SKGTEST("ERR:Default RC", err.getReturnCode(), 0);
                 SKGTEST("ERR:isWarning", err.isWarning(), false);
                 SKGTEST("ERR:isSucceeded", err.isSucceeded(), true);
@@ -165,6 +165,9 @@ int main(int argc, char** argv)
                 SKGTEST("STR:stringToCsv", SKGServices::stringToCsv("AB \"C\" DE"), "\"AB \"\"C\"\" DE\"");
                 SKGTEST("STR:stringToCsv", SKGServices::stringToCsv("AB \"C\";DE"), "\"AB \"\"C\"\";DE\"");
 
+                SKGTEST("STR:stringToHtml", SKGServices::stringToHtml("<hello>&<world>"), "&lt;hello&gt;&amp;&lt;world&gt;");
+                SKGTEST("STR:htmlToString", SKGServices::htmlToString("&lt;hello&gt;&amp;&lt;world&gt;"), "<hello>&<world>");
+
                 QStringList parameters=SKGServices::splitCSVLine(SKGServices::stringToCsv("Y")+';'+SKGServices::stringToCsv("A;B"));
                 SKGTEST("STR:splitCSVLine count", parameters.count(), 2);
                 SKGTEST("STR:splitCSVLine", parameters[0], "Y");
@@ -176,6 +179,14 @@ int main(int argc, char** argv)
                 SKGTEST("STR:splitCSVLine", parameters[1], "B;C");
                 SKGTEST("STR:splitCSVLine", parameters[2], "D");
 
+                QChar realsep;
+                parameters=SKGServices::splitCSVLine("\"A\",18,\"B\"", ';', true, &realsep);
+                SKGTEST("STR:splitCSVLine count", parameters.count(), 3);
+                SKGTEST("STR:splitCSVLine", parameters[0], "A");
+                SKGTEST("STR:splitCSVLine", parameters[1], "18");
+                SKGTEST("STR:splitCSVLine", parameters[2], "B");
+                SKGTEST("STR:sep", realsep, ',');
+
                 parameters=SKGServices::splitCSVLine("30/05/2008;RETRAIT ESPECES AGENCE;                                ;      100,00;DEBIT;");
                 SKGTEST("STR:splitCSVLine count", parameters.count(), 6);
 
@@ -186,7 +197,7 @@ int main(int argc, char** argv)
 
                 //Error
                 SKGTESTERROR("SKGServices::executeSqliteOrder", SKGServices::executeSqliteOrder((const SKGDocument*) NULL, "", NULL), false);
-	}
+        }
 
         //End test
         SKGENDTEST();
