@@ -115,6 +115,16 @@ void fileTest(SKGDocument::DatabaseMode iMode, int& nberror, int& nbcheck, bool
                 SKGTESTERROR("DOC:setParameter", document1.setParameter("ATT3", "VAL3"), true);
                 SKGTESTERROR("DOC:endTransaction", document1.endTransaction(true), true);
                 SKGTESTERROR("DOC:save", document1.save(), true);
+
+                SKGTESTERROR("DOC:beginTransaction", document1.beginTransaction("tt"), true);
+                SKGTESTERROR("DOC:changePassword", document1.changePassword("pwd"), true);
+                SKGTESTERROR("DOC:endTransaction", document1.endTransaction(true), true);
+                SKGTESTERROR("DOC:save", document1.save(), true);
+        }
+        {
+                SKGDocument document1(iMode);
+                SKGTESTERROR("DOC:load", document1.load(filename1, ""), (document1.getDatabaseMode()!=SKGDocument::CopiedInFile));
+                SKGTESTERROR("DOC:load", document1.load(filename1, "pwd"), true);
         }
 
         QFile(filename1).remove();
