@@ -76,7 +76,8 @@ int nbcheck = 0;
  */
 #define SKGENDTEST()\
 SKGTRACE << nberror << " errors / " << nbcheck << " checks =" << (100*(static_cast<double>(nberror)) / (static_cast<double>(nbcheck))) << "%" << endl;\
-SKGTraces::exit(nberror);
+SKGTraces::dumpProfilingStatistics();\
+return nberror;
 
 /**
  * @def SKGRETURNTEST()
