@@ -257,15 +257,15 @@ int main(int argc, char** argv)
                 SKGTESTERROR("MAXDEPTH.endTransaction", err, true);
                 SKGTEST("MAXDEPTH.getNbTransaction", document1.getNbTransaction(), 3);
 
-                SKGObjectModificationList oModifications;
-                SKGTESTERROR("MAXDEPTH.getModifications", document1.getModifications(document1.getTransactionToTreat(), oModifications), true);
+                SKGDocument::SKGObjectModificationList oModifications;
+                SKGTESTERROR("MAXDEPTH.getModifications", document1.getModifications(document1.getTransactionToProcess(), oModifications), true);
                 SKGTEST("MAXDEPTH.oModifications.count", oModifications.count(), 2);
-                SKGTEST("MAXDEPTH.oModifications.id", oModifications[0].id, 6);
+                SKGTEST("MAXDEPTH.oModifications.id", oModifications[0].id, 7);
                 SKGTEST("MAXDEPTH.oModifications.table", oModifications[0].table, "parameters");
-                SKGTEST("MAXDEPTH.oModifications.type", oModifications[0].type, U);
-                SKGTEST("MAXDEPTH.oModifications.id", oModifications[1].id, 7);
+                SKGTEST("MAXDEPTH.oModifications.type", oModifications[0].type, SKGDocument::U);
+                SKGTEST("MAXDEPTH.oModifications.id", oModifications[1].id, 8);
                 SKGTEST("MAXDEPTH.oModifications.table", oModifications[1].table, "parameters");
-                SKGTEST("MAXDEPTH.oModifications.type", oModifications[1].type, I);
+                SKGTEST("MAXDEPTH.oModifications.type", oModifications[1].type, SKGDocument::I);
         }
 
         {
@@ -531,13 +531,33 @@ int main(int argc, char** argv)
                 SKGTESTERROR("MSG.endTransaction", document1.endTransaction(true), true);
 
                 QStringList msg;
-                SKGTESTERROR("MSG.getMessages", document1.getMessages(document1.getTransactionToTreat(SKGDocument::UNDO), msg), true);
+                SKGTESTERROR("MSG.getMessages", document1.getMessages(document1.getTransactionToProcess(SKGDocument::UNDO), msg), true);
                 SKGTEST("MSG.msg.count", msg.count(), 3);
                 SKGTEST("MSG.msg", msg.at(0), "Bonjour");
                 SKGTEST("MSG.msg", msg.at(1), "Hello");
                 SKGTEST("MSG.msg", msg.at(2), "World");
         }
 
+        {
+                //Test clean after save
+                SKGDocument document1;
+                SKGTESTERROR("CLEAN.initialize()", document1.initialize(), true);
+
+                SKGTESTERROR("CLEAN.beginTransaction", document1.beginTransaction("T1"), true);
+                SKGTESTERROR("CLEAN.setParameter", document1.setParameter("SKG_UNDO_CLEAN_AFTER_SAVE", "Y"), true);
+                SKGTESTERROR("CLEAN.setParameter", document1.setParameter("ATT", "VAL1"), true);
+                SKGTESTERROR("CLEAN.endTransaction", document1.endTransaction(true), true);
+
+                SKGTESTERROR("CLEAN.beginTransaction", document1.beginTransaction("T2"), true);
+                SKGTESTERROR("CLEAN.setParameter", document1.setParameter("ATT", "VAL2"), true);
+                SKGTESTERROR("CLEAN.endTransaction", document1.endTransaction(true), true);
+
+                SKGTEST("CLEAN.getNbTransaction", document1.getNbTransaction(SKGDocument::UNDO), 2);
+
+                QString filename1 = getTestPath("OUT")+"/filename1.skg";
+                SKGTESTERROR("CLEAN.saveAs", document1.saveAs(filename1, true), true);
+                SKGTEST("CLEAN.getNbTransaction", document1.getNbTransaction(SKGDocument::UNDO), 0);
+        }
         //End test
         SKGENDTEST();
 }
