@@ -51,11 +51,10 @@ public:
 
         /**
          * Called to initialise the plugin
-         * @param iParent the SKGMainPanel main panel parent
          * @param iDocument the SKGDocumentBank main document
          * @param iArgument the arguments
          */
-        virtual void setupActions(SKGMainPanel* iParent, SKGDocument* iDocument, const QStringList& iArgument);
+        virtual void setupActions(SKGDocument* iDocument, const QStringList& iArgument);
 
         /**
          * Must be modified to close properly the plugin.
@@ -63,10 +62,24 @@ public:
         virtual void close();
 
         /**
-         * The dashboard widget of the plugin.
+         * The number of dashboard widgets of the plugin.
+         * @return The number of dashboard widgets of the plugin
+         */
+        virtual int getNbDashboardWidgets();
+
+        /**
+         * Get a dashboard widget title of the plugin.
+         * @param iIndex the index of the widget
+         * @return The title
+         */
+        virtual QString getDashboardWidgetTitle(int iIndex);
+
+        /**
+         * Get a dashboard widget of the plugin.
+         * @param iIndex the index of the widget
          * @return The dashboard widget of the plugin
          */
-        virtual SKGWidget* getDashboardWidget();
+        virtual SKGWidget* getDashboardWidget(int iIndex);
 
         /**
          * The context widget of the plugin.
@@ -130,7 +143,7 @@ public:
 
 private:
         Q_DISABLE_COPY(SKGBankPlugin);
-        SKGMainPanel *parent;
+
         SKGDocument* currentBankDocument;
 
         Ui::skgbankplugin_pref ui;
