@@ -35,12 +35,17 @@
 #include <QFile>
 #include <QDir>
 
-SKGBankPluginWidget::SKGBankPluginWidget ( SKGMainPanel* iParent, SKGDocumentBank* iDocument )
-                : SKGTabWidget ( iParent, iDocument )
+SKGBankPluginWidget::SKGBankPluginWidget ( SKGDocumentBank* iDocument )
+                : SKGTabWidget (iDocument )
 {
         SKGTRACEIN ( 10, "SKGBankPluginWidget::SKGBankPluginWidget" );
 
         ui.setupUi ( this );
+
+        timer = new QTimer( this );
+        timer->setSingleShot( true );
+        connect( timer, SIGNAL( timeout() ), this, SLOT( refreshInfoZone() ) );
+
         //Add Standard KDE Icons to buttons to Accounts
         ui.kAccountCreatorUpdate->setIcon ( KIcon ( "dialog-ok-apply" ) );
         ui.kAccountCreatorAdd->setIcon ( KIcon ( "list-add" ) );
@@ -58,24 +63,27 @@ SKGBankPluginWidget::SKGBankPluginWidget ( SKGMainPanel* iParent, SKGDocumentBan
         ui.kAccountCreatorType->addItem ( i18n ( "Other" ) );
 
         //Bind account creation view
-        objectModel = new SKGObjectModel ( ( SKGDocumentBank* ) getDocument(), "v_account_display", "1=0", this );
+        objectModel = new SKGObjectModel ( ( SKGDocumentBank* ) getDocument(), "v_account_display", "1=0", this, "", false);
         SKGSortFilterProxyModel* modelProxy = new SKGSortFilterProxyModel ( this );
         modelProxy->setSourceModel ( objectModel );
         modelProxy->setSortRole ( Qt::UserRole );
         modelProxy->setDynamicSortFilter ( true );
 
+        ui.kFilterEdit->setProxy(modelProxy);
+
         ui.kAccountTableViewEdition->setModel ( modelProxy );
         ui.kAccountTableViewEdition->setWindowTitle ( i18n ( "Accounts" ) );
 
         //Add registered global action in contextual menu
-        if ( iParent ) {
-                ui.kAccountTableViewEdition->insertAction ( 0, iParent->getGlobalAction ( "edit_delete" ) );
+
+        if (SKGMainPanel::getMainPanel()) {
+                ui.kAccountTableViewEdition->insertAction ( 0, SKGMainPanel::getMainPanel()->getGlobalAction ( "edit_delete" ) );
                 QAction* sep=new QAction ( this );
                 sep->setSeparator ( true );
                 ui.kAccountTableViewEdition->insertAction ( 0, sep );
-                ui.kAccountTableViewEdition->insertAction ( 0, iParent->getGlobalAction ( "open_report" ) );
+                ui.kAccountTableViewEdition->insertAction ( 0, SKGMainPanel::getMainPanel()->getGlobalAction ( "open_report" ) );
         }
-        connect ( ui.kAccountTableViewEdition->selectionModel(), SIGNAL ( selectionChanged ( QItemSelection,QItemSelection ) ), this, SLOT ( onSelectionChanged() ) );
+        connect ( ui.kAccountTableViewEdition, SIGNAL ( selectionChangedDelayed() ), this, SLOT ( onSelectionChanged() ) );
         connect ( objectModel, SIGNAL ( beforeReset() ), ui.kAccountTableViewEdition, SLOT ( saveSelection() ) );
         connect ( objectModel, SIGNAL ( afterReset() ), ui.kAccountTableViewEdition, SLOT ( resetSelection() ) );
 
@@ -115,6 +123,7 @@ SKGBankPluginWidget::SKGBankPluginWidget ( SKGMainPanel* iParent, SKGDocumentBan
 
         //Refresh
         connect ( ( const QObject* ) getDocument(), SIGNAL(tableModified(QString, int)), this, SLOT(dataModified(QString, int)), Qt::QueuedConnection );
+        connect ( ( const QObject* ) getDocument(), SIGNAL ( transactionSuccessfullyEnded ( int ) ), this, SLOT ( onSelectionChanged() ), Qt::QueuedConnection );
         dataModified("", 0);
 }
 
@@ -122,6 +131,7 @@ SKGBankPluginWidget::~SKGBankPluginWidget()
 {
         SKGTRACEIN ( 10, "SKGBankPluginWidget::~SKGBankPluginWidget" );
         objectModel=NULL;
+        timer=NULL;
 }
 
 void SKGBankPluginWidget::onSelectionChanged()
@@ -161,16 +171,6 @@ void SKGBankPluginWidget::onSelectionChanged()
                         ui.kAccountCreatorType->setText ( account.getAttribute ( "t_TYPENLS" ) );
                         ui.kAccountCreatorAddress->setText ( account.getAttribute ( "t_agency_address" ) );
                         ui.kAccountCreatorComment->setText ( account.getAttribute ( "t_comment" ) );
-                } else {
-                        ui.kAccountCreatorIcon->setText ( "" );
-                        ui.kAccountCreatorBank->setText ( "" );
-                        ui.kAccountCreatorAccount->setText ( "" );
-                        ui.kAccountCreatorBankNumber->setText ( "" );
-                        ui.kAccountCreatorAgencyNumber->setText ( "" );
-                        ui.kAccountCreatorNumber->setText ( "" );
-                        //Not done because of it's a combo ui.kAccountCreatorType->setText("");
-                        ui.kAccountCreatorAddress->setText ( "" );
-                        ui.kAccountCreatorComment->setText ( "" );
                 }
 
                 onAccountCreatorModified();
@@ -180,10 +180,7 @@ void SKGBankPluginWidget::onSelectionChanged()
 
 int SKGBankPluginWidget::getCurrentMode()
 {
-        if (ui.kAllFrm->isVisible()) return 2;
-        else if (ui.kIntermediateFrm->isVisible()) return 1;
-        else if (ui.kCommonFrm->isVisible()) return 0;
-        return -1;
+        return mode;
 }
 
 void SKGBankPluginWidget::onBtnModeClicked()
@@ -203,21 +200,23 @@ void SKGBankPluginWidget::onBtnModeClicked()
 
 void SKGBankPluginWidget::setCurrentMode(int iMode)
 {
+        mode=iMode;
+
         ui.kAllFrm->hide();
         ui.kIntermediateFrm->hide();
-        ui.kCommonFrm->setVisible(iMode>=0);
-        ui.kBtnFrm->setVisible(iMode>=0);
+        ui.kCommonFrm->setVisible(mode>=0);
+        ui.kBtnFrm->setVisible(mode>=0);
 
         ui.kStandardBtn->setChecked(false);
         ui.kIntermediateBtn->setChecked(false);
         ui.kAllBtn->setChecked(false);
 
-        if (iMode==0) {
+        if (mode==0) {
                 ui.kStandardBtn->setChecked(true);
-        } else if (iMode==1) {
+        } else if (mode==1) {
                 ui.kIntermediateFrm->show();
                 ui.kIntermediateBtn->setChecked(true);
-        } else if (iMode==2) {
+        } else if (mode==2) {
                 ui.kIntermediateFrm->show();
                 ui.kAllFrm->show();
                 ui.kAllBtn->setChecked(true);
@@ -308,7 +307,7 @@ void SKGBankPluginWidget::onAddAccountClicked()
         QApplication::restoreOverrideCursor();
 
         //Display error
-        getMainPanel()->displayErrorMessage ( err );
+        SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
 }
 
 SKGObjectBase::SKGListSKGObjectBase SKGBankPluginWidget::getSelectedObjects()
@@ -385,7 +384,7 @@ void SKGBankPluginWidget::onModifyAccountClicked()
         QApplication::restoreOverrideCursor();
 
         //Display error
-        getMainPanel()->displayErrorMessage ( err );
+        SKGMainPanel::getMainPanel()->displayErrorMessage ( err );
 }
 
 void SKGBankPluginWidget::onDoubleClickedAccount()
@@ -408,19 +407,12 @@ void SKGBankPluginWidget::onDoubleClickedAccount()
                 }
 
                 root.setAttribute ( "account", accountObj.getName() );
-                getMainPanel()->setNewTabContent ( getMainPanel()->getPluginByName ( "Skrooge operation plugin" ), -1, doc.toString() );
+                SKGMainPanel::getMainPanel()->setNewTabContent ( SKGMainPanel::getMainPanel()->getPluginByName ( "Skrooge operation plugin" ), -1, doc.toString() );
 
         }
         QApplication::restoreOverrideCursor();
 }
 
-void SKGBankPluginWidget::onFilterRegExpChanged()
-{
-        SKGTRACEIN ( 10, "SKGBankPluginWidget::onFilterRegExpChanged" );
-        QRegExp regExp ( ui.kFilterEdit->text(), Qt::CaseInsensitive );
-        ( ( SKGSortFilterProxyModel* ) ui.kAccountTableViewEdition->model() )->setFilterRegExp ( regExp );
-}
-
 void SKGBankPluginWidget::onFilterChanged()
 {
         SKGTRACEIN ( 10, "SKGBankPluginWidget::onFilterChanged" );
@@ -436,11 +428,7 @@ void SKGBankPluginWidget::onFilterChanged()
         //Update model
         if ( objectModel ) {
                 objectModel->setFilter ( filter );
-                objectModel->refresh();
-
-                //Correction bug 2299394 vvv
-                if ( ui.kAccountTableViewEdition->isAutoResized() ) ui.kAccountTableViewEdition->resizeColumnsToContents();
-                //Correction bug 2299394 ^^^
+                ui.kAccountTableViewEdition->setState ( ui.kAccountTableViewEdition->getState() );
         }
 
         QApplication::restoreOverrideCursor();
@@ -467,6 +455,21 @@ void SKGBankPluginWidget::onComputeRIB()
         ui.kRib->setText ( SKGServices::intToString ( 97 - ( ( 89 * b + 15 * g + 76 * d + 3 * c ) % 97 ) ) );
 }
 
+void SKGBankPluginWidget::cleanEditor()
+{
+        if (getNbSelectedObjects()==0) {
+                ui.kAccountCreatorIcon->setText ( "" );
+                ui.kAccountCreatorBank->setText ( "" );
+                ui.kAccountCreatorAccount->setText ( "" );
+                ui.kAccountCreatorBankNumber->setText ( "" );
+                ui.kAccountCreatorAgencyNumber->setText ( "" );
+                ui.kAccountCreatorNumber->setText ( "" );
+                //Not done because of it's a combo ui.kAccountCreatorType->setText("");
+                ui.kAccountCreatorAddress->setText ( "" );
+                ui.kAccountCreatorComment->setText ( "" );
+        }
+}
+
 QString SKGBankPluginWidget::getState()
 {
         SKGTRACEIN ( 10, "SKGBankPluginWidget::getState" );
@@ -475,7 +478,7 @@ QString SKGBankPluginWidget::getState()
         doc.appendChild ( root );
 
         root.setAttribute ( "hideUseless", ui.kHideUseless->checkState() ==Qt::Checked ? "Y" : "N" );
-        root.setAttribute ( "filter", ui.kFilterEdit->text() );
+        root.setAttribute ( "filter", ui.kFilterEdit->lineEdit()->text() );
         root.setAttribute ( "currentPage", getCurrentMode() );
 
         //Memorize table settings
@@ -498,13 +501,17 @@ void SKGBankPluginWidget::setState ( const QString& iState )
         if ( !filter.isEmpty() ) ui.kFilterEdit->setText ( filter );
         if ( !currentPage.isEmpty() ) setCurrentMode ( SKGServices::stringToInt ( currentPage ) );
 
-        onFilterChanged();
+        if (objectModel) {
+                bool previous=objectModel->blockRefresh(true);
+                onFilterChanged();
+                objectModel->blockRefresh(previous);
+        }
 
         //!!! Must be done here after onFilterChanged
         ui.kAccountTableViewEdition->setState ( root.attribute ( "view" ) );
 }
 
-QString SKGBankPluginWidget::getDefaultStateAttibute()
+QString SKGBankPluginWidget::getDefaultStateAttribute()
 {
         return "SKGBANK_DEFAULT_PARAMETERS";
 }
@@ -513,6 +520,7 @@ void SKGBankPluginWidget::dataModified(const QString& iTableName, int iIdTransac
 
 {
         SKGTRACEIN ( 10, "SKGBankPluginWidget::dataModified" );
+        Q_UNUSED(iIdTransaction);
 
         //Refresh widgets
         QSqlDatabase* db = getDocument()->getDatabase();
@@ -523,7 +531,7 @@ void SKGBankPluginWidget::dataModified(const QString& iTableName, int iIdTransac
                 //Correction bug 2299394 ^^^
 
                 //Refresh info area
-                refreshInfoZone();
+                if (timer) timer->start( 300 );
         }
 }
 
@@ -534,7 +542,7 @@ void SKGBankPluginWidget::refreshInfoZone()
         //Refresh info area
         SKGStringListList listTmp;
         SKGServices::executeSelectSqliteOrder ( getDocument(),
-                                                "SELECT SUM(f_CURRENTAMOUNT), SUM(f_CHECKED), SUM(f_COMING_SOON) from v_account_display",
+                                                "SELECT TOTAL(f_CURRENTAMOUNT), TOTAL(f_CHECKED), TOTAL(f_COMING_SOON) from v_account_display",
                                                 listTmp );
         if ( listTmp.count() ==2 ) {
                 KLocale* locale=KGlobal::locale();
