@@ -25,6 +25,7 @@
 #include "skgtabwidget.h"
 
 #include <QStringList>
+#include <QTimer>
 
 class SKGDocumentBank;
 class SKGObjectModel;
@@ -40,7 +41,7 @@ public:
         /**
          * Default Constructor
          */
-        SKGBankPluginWidget ( SKGMainPanel* iParent, SKGDocumentBank* iDocument );
+        SKGBankPluginWidget ( SKGDocumentBank* iDocument );
 
         /**
          * Default Destructor
@@ -79,7 +80,7 @@ public:
          * MUST BE OVERWRITTEN
          * @return attribute name to save the default state.
          */
-        virtual QString getDefaultStateAttibute();
+        virtual QString getDefaultStateAttribute();
 
         /**
          * Get the widget must be printed
@@ -95,10 +96,9 @@ private slots:
         void onDoubleClickedAccount();
         void onSelectionChanged();
         void onFilterChanged();
-        void onFilterRegExpChanged();
         void onComputeRIB();
         void onBtnModeClicked();
-
+        void cleanEditor();
         void refreshInfoZone();
 
 private:
@@ -109,8 +109,9 @@ private:
 
         Ui::skgbankplugin_base ui;;
         SKGObjectModel* objectModel;
-
         QStringList listBankNumbers;
+        int mode;
+        QTimer* timer;
 };
 
 #endif // SKGDEBUGPLUGIN_H
