@@ -51,11 +51,10 @@ public:
 
         /**
          * Called to setupActions the plugin
-         * @param iParent the SKGMainPanel main panel parent
          * @param iDocument the SKGDocumentBank main document
          * @param iArgument the arguments
          */
-        virtual void setupActions(SKGMainPanel* iParent, SKGDocument* iDocument, const QStringList& iArgument);
+        virtual void setupActions(SKGDocument* iDocument, const QStringList& iArgument);
 
         /**
          * Must be modified to close properly the plugin.
@@ -115,7 +114,7 @@ private slots:
 private:
         Q_DISABLE_COPY(SKGBookmarkPlugin);
 
-        SKGMainPanel *parent;
+
         SKGDocument* currentBankDocument;
         QDockWidget* dockWidget;
         QString docUniqueIdentifier;
