@@ -34,8 +34,8 @@
 #include <QHeaderView>
 #include <QResizeEvent>
 
-SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(SKGMainPanel* iParent, SKGDocument* iDocument)
-                : SKGTabWidget(iParent, iDocument)
+SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(SKGDocument* iDocument)
+                : SKGTabWidget(iDocument)
 {
         SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget");
 
@@ -48,10 +48,10 @@ SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(SKGMainPanel* iParent,
         ui.kBookmarksList->setContextMenuPolicy(Qt::CustomContextMenu);
 
         mainMenu = new KMenu(ui.kBookmarksList);
-        actDelete = mainMenu->addAction(KIcon("list-remove"), i18n("Delete"));
+        actDelete = mainMenu->addAction(KIcon("list-remove"), i18nc("Verb, delete an item","Delete"));
         connect(actDelete, SIGNAL(triggered(bool)), this, SLOT(onRemoveBookmark()));
 
-        actRename = mainMenu->addAction(KIcon("edit-rename"), i18n("Rename"));
+        actRename = mainMenu->addAction(KIcon("edit-rename"), i18nc("Verb, change the name of an item","Rename"));
         connect(actRename, SIGNAL(triggered(bool)), this, SLOT(onRenameBookmark()));
 
         mainMenu->addSeparator();
@@ -62,7 +62,7 @@ SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(SKGMainPanel* iParent,
         actAddBookmark = mainMenu->addAction(KIcon("list-add"), i18n("Bookmark current page"));
         connect(actAddBookmark, SIGNAL(triggered(bool)), this, SLOT(onAddBookmark()));
 
-        actSetAutostart = mainMenu->addAction(KIcon("user-online"), i18n("Autostart"));
+        actSetAutostart = mainMenu->addAction(KIcon("user-online"), i18nc("Verb, automatically load when skrooge is started","Autostart"));
         connect(actSetAutostart, SIGNAL(triggered(bool)), this, SLOT(onSetAutostart()));
 
         actUnsetAutostart = mainMenu->addAction(KIcon("user-offline"), i18n("Remove Autostart"));
@@ -76,10 +76,15 @@ SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(SKGMainPanel* iParent,
         modelproxy->setSourceModel(modelview);
         ui.kBookmarksList->setModel(modelproxy);
 
+        ui.kFilterEdit->setProxy(modelproxy);
+
         connect(ui.kBookmarksList->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(refresh()));
         connect(ui.kBookmarksList, SIGNAL(pressed(QModelIndex)), this, SLOT(onBeforeOpenBookmark()));
         connect(ui.kBookmarksList, SIGNAL(clicked(QModelIndex)), this, SLOT(onOpenBookmark(QModelIndex)));
         connect(ui.kBookmarksList, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(onOpenBookmarkFolder(QModelIndex)));
+
+        connect(modelview, SIGNAL(beforeReset()), ui.kBookmarksList, SLOT(saveSelection()));
+        connect(modelview, SIGNAL(afterReset()), ui.kBookmarksList, SLOT(resetSelection()));
 }
 
 SKGBookmarkPluginDockWidget::~SKGBookmarkPluginDockWidget()
@@ -109,13 +114,6 @@ SKGObjectBase::SKGListSKGObjectBase SKGBookmarkPluginDockWidget::getSelectedObje
         return ui.kBookmarksList->getSelectedObjects();
 }
 
-void SKGBookmarkPluginDockWidget::onBookmarkFilterRegExpChanged()
-{
-        SKGTRACEIN(10, "SKGBookmarkPluginDockWidget::onBookmarkFilterRegExpChanged");
-        QRegExp regExp(ui.kFilterEdit->text(), Qt::CaseInsensitive);
-        ((SKGSortFilterProxyModel*) ui.kBookmarksList->model())->setFilterRegExp(regExp);
-}
-
 void SKGBookmarkPluginDockWidget::onSetAutostart()
 {
         SKGTRACEIN(10, "SKGBookmarkPluginDockWidget::onSetAutoStart");
@@ -152,7 +150,7 @@ void SKGBookmarkPluginDockWidget::setAutostart(const QString& value)
 
         //status bar
         if (err.isSucceeded()) err=SKGError(0, value == "Y" ? i18n("Autostart bookmarks") : i18n("Do not Autostart bookmarks"));
-        getMainPanel()->displayErrorMessage(err);
+        SKGMainPanel::getMainPanel()->displayErrorMessage(err);
 
 }
 
@@ -166,27 +164,29 @@ void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool
         nodes.push_back(iNode);
 
         int setForcusOn=0;
-        int nbTab=getMainPanel()->countTab();
+        int nbTab=SKGMainPanel::getMainPanel()->countTab();
         if (nbTab) {
                 setForcusOn=nbTab-1;
                 if (middleClick) {
                         setForcusOn=nbTab;
                 } else {
-                        setForcusOn=getMainPanel()->currentTabIndex();
+                        setForcusOn=SKGMainPanel::getMainPanel()->currentTabIndex();
                 }
         }
 
-        int tabNumberForNextOpen=(middleClick || iFirstInNewPage ? -1 : getMainPanel()->currentTabIndex());
+        int tabNumberForNextOpen=(middleClick || iFirstInNewPage ? -1 : SKGMainPanel::getMainPanel()->currentTabIndex());
         for (int i=0; i<nodes.count(); ++i) { //WARNING: This list is modified dynamically
                 SKGNodeObject selectedNode=nodes.at(i);
                 QStringList data=SKGServices::splitCSVLine(selectedNode.getData());
                 if (data.count()>3) {
                         //This bookmark has information ==> we open it
-                        SKGTabWidget* w=getMainPanel()->setNewTabContent(getMainPanel()->getPluginByName(data[0]),tabNumberForNextOpen, data[3], selectedNode.getName());
+                        SKGTabWidget* w=SKGMainPanel::getMainPanel()->setNewTabContent(SKGMainPanel::getMainPanel()->getPluginByName(data[0]),tabNumberForNextOpen, data[3], selectedNode.getName());
                         selectedNode.opened = true;
                         tabNumberForNextOpen=-1;
                         if (w) {
                                 w->setBookmarkID(SKGServices::intToString(selectedNode.getID()));
+
+                                SKGMainPanel::getMainPanel()->refresh();
                         }
                 } else {
                         //This bookmark is a folder ==> we open children by recursion
@@ -199,7 +199,7 @@ void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool
         }
 
         //Set focus on first page
-        getMainPanel()->setCurrentTabIndex(setForcusOn);
+        SKGMainPanel::getMainPanel()->setCurrentTabIndex(setForcusOn);
 
         QApplication::restoreOverrideCursor();
 }
@@ -267,7 +267,7 @@ void SKGBookmarkPluginDockWidget::onAddBookmarkGroup()
 
         //status bar
         if (err.isSucceeded()) err=SKGError(0, i18n("Bookmark group created"));
-        getMainPanel()->displayErrorMessage(err);
+        SKGMainPanel::getMainPanel()->displayErrorMessage(err);
 }
 
 void SKGBookmarkPluginDockWidget::onAddBookmark()
@@ -277,7 +277,7 @@ void SKGBookmarkPluginDockWidget::onAddBookmark()
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
         //Get current page
-        SKGTabWidget* currentPage=getMainPanel()->currentTab();
+        SKGTabWidget* currentPage=SKGMainPanel::getMainPanel()->currentTab();
         if (currentPage) {
                 //Get current selection name
                 QString name;
@@ -292,7 +292,7 @@ void SKGBookmarkPluginDockWidget::onAddBookmark()
 
                 QString defaultName=currentPage->objectName();
                 QString defaultIcon;
-                SKGInterfacePlugin* plugin=getMainPanel()->getPluginByName(defaultName);
+                SKGInterfacePlugin* plugin=SKGMainPanel::getMainPanel()->getPluginByName(defaultName);
                 if (plugin) {
                         defaultName=plugin->title();
                         defaultIcon=plugin->icon();
@@ -318,7 +318,7 @@ void SKGBookmarkPluginDockWidget::onAddBookmark()
 
         //status bar
         if (err.isSucceeded()) err=SKGError(0, i18n("Bookmark created"));
-        getMainPanel()->displayErrorMessage(err);
+        SKGMainPanel::getMainPanel()->displayErrorMessage(err);
 }
 
 void SKGBookmarkPluginDockWidget::onRenameBookmark()
@@ -328,7 +328,7 @@ void SKGBookmarkPluginDockWidget::onRenameBookmark()
         SKGObjectBase::SKGListSKGObjectBase selection;
         QItemSelectionModel *selModel=ui.kBookmarksList->selectionModel();
         QSortFilterProxyModel* proxyModel=(QSortFilterProxyModel*) ui.kBookmarksList->model();
-        if (proxyModel) {
+        if (proxyModel && selModel) {
                 SKGObjectModelBase* model=(SKGObjectModelBase*) proxyModel->sourceModel();
                 if (model) {
                         QModelIndexList indexes=selModel->selectedRows();
@@ -360,7 +360,7 @@ void SKGBookmarkPluginDockWidget::onRemoveBookmark()
 
         //status bar
         if (err.isSucceeded()) err=SKGError(0, i18n("Bookmark deleted"));
-        getMainPanel()->displayErrorMessage(err);
+        SKGMainPanel::getMainPanel()->displayErrorMessage(err);
 }
 
 void SKGBookmarkPluginDockWidget::onBookmarkEditorChanged()
@@ -379,7 +379,7 @@ void SKGBookmarkPluginDockWidget::onBookmarkEditorChanged()
         //Enable bookmark buttons
         bool testAdd=getDocument()->getDatabase()!=NULL && nbSelectedObjects<=1 && isFolder;
         if (actAddBookmarkGroup) actAddBookmarkGroup->setEnabled(testAdd);
-        if (actAddBookmark) actAddBookmark->setEnabled(testAdd && getMainPanel()->currentTabIndex()>=0);
+        if (actAddBookmark) actAddBookmark->setEnabled(testAdd && SKGMainPanel::getMainPanel()->currentTabIndex()>=0);
         if (actDelete) actDelete->setEnabled(nbSelectedObjects>0);
         if (actRename) actRename->setEnabled(nbSelectedObjects==1);
 }
