@@ -51,11 +51,10 @@ public:
 
         /**
          * Called to initialise the plugin
-         * @param iParent the SKGMainPanel main panel parent
          * @param iDocument the SKGDocumentBank main document
          * @param iArgument the arguments
          */
-        virtual void setupActions(SKGMainPanel* iParent, SKGDocument* iDocument, const QStringList& iArgument);
+        virtual void setupActions(SKGDocument* iDocument, const QStringList& iArgument);
 
         /**
          * Must be modified to close properly the plugin.
@@ -121,7 +120,7 @@ private slots:
 private:
         Q_DISABLE_COPY(SKGCategoriesPlugin);
 
-        SKGMainPanel *parent;
+
         SKGDocument* currentBankDocument;
         QString docUniqueIdentifier;
         KAction* importStdCatAction;
