@@ -35,8 +35,8 @@
 #include <QGraphicsScene>
 #include <QHeaderView>
 
-SKGCategoriesPluginWidget::SKGCategoriesPluginWidget(SKGMainPanel* iParent, SKGDocumentBank* iDocument)
-                : SKGTabWidget(iParent, iDocument)
+SKGCategoriesPluginWidget::SKGCategoriesPluginWidget(SKGDocumentBank* iDocument)
+                : SKGTabWidget(iDocument)
 {
         SKGTRACEIN(10, "SKGCategoriesPluginWidget::SKGCategoriesPluginWidget");
 
@@ -45,22 +45,22 @@ SKGCategoriesPluginWidget::SKGCategoriesPluginWidget(SKGMainPanel* iParent, SKGD
         ui.kAddCategoryButton->setIcon(KIcon("list-add"));
         ui.kModifyCategoryButton->setIcon(KIcon("dialog-ok-apply"));
 
-        objectModel = new SKGObjectModel((SKGDocumentBank*) getDocument(), "v_category_display",
-                                         "1=0", this, "r_category_id");
+        objectModel = new SKGObjectModel((SKGDocumentBank*) getDocument(), "v_category_display", "1=0", this, "r_category_id", false);
         SKGSortFilterProxyModel* modelproxy = new SKGSortFilterProxyModel(this);
         modelproxy->setSourceModel(objectModel);
         modelproxy->setSortRole(Qt::UserRole);
         modelproxy->setDynamicSortFilter(true);
         ui.kCategoriesView->setModel(modelproxy);
-        ui.kCategoriesView->setWindowTitle(i18n("Categories"));
+        ui.kCategoriesView->setWindowTitle(i18nc("Noun, categories of items","Categories"));
 
         //Add registered global action in contextual menu
-        if (iParent) {
-                ui.kCategoriesView->insertAction(0, iParent->getGlobalAction("edit_delete"));
+
+        if (SKGMainPanel::getMainPanel()) {
+                ui.kCategoriesView->insertAction(0, SKGMainPanel::getMainPanel()->getGlobalAction("edit_delete"));
                 QAction* sep=new QAction(this);
                 sep->setSeparator(true);
                 ui.kCategoriesView->insertAction(0, sep);
-                ui.kCategoriesView->insertAction(0, iParent->getGlobalAction("open_report"));
+                ui.kCategoriesView->insertAction(0, SKGMainPanel::getMainPanel()->getGlobalAction("open_report"));
 
                 ui.kCategoriesView->resizeColumnToContents(0);
                 ui.kCategoriesView->header()->setStretchLastSection(false);
@@ -71,7 +71,7 @@ SKGCategoriesPluginWidget::SKGCategoriesPluginWidget(SKGMainPanel* iParent, SKGD
         connect((const QObject*) getDocument(), SIGNAL(tableModified(QString, int)), this, SLOT(dataModified(QString, int)), Qt::QueuedConnection );
         dataModified("", 0);
 
-        connect(ui.kCategoriesView->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(onSelectionChanged()));
+        connect(ui.kCategoriesView, SIGNAL(selectionChangedDelayed()), this, SLOT(onSelectionChanged()));
 
         connect(objectModel, SIGNAL(beforeReset()), ui.kCategoriesView, SLOT(saveSelection()));
         connect(objectModel, SIGNAL(afterReset()), ui.kCategoriesView, SLOT(resetSelection()));
@@ -86,6 +86,8 @@ SKGCategoriesPluginWidget::~SKGCategoriesPluginWidget()
 void SKGCategoriesPluginWidget::dataModified(const QString& iTableName, int iIdTransaction)
 {
         SKGTRACEIN(10, "SKGCategoriesPluginWidget::dataModified");
+        Q_UNUSED(iIdTransaction);
+
         if (iTableName=="category" || iTableName.isEmpty()) {
                 //Correction bug 2299394 vvv
                 if (ui.kCategoriesView->isAutoResized()) ui.kCategoriesView->resizeColumnsToContents();
@@ -102,9 +104,8 @@ void SKGCategoriesPluginWidget::onSelectionChanged()
         if (objs.count()) {
                 SKGCategoryObject cat=objs.at(0);
                 ui.kNameInput->setText(cat.getName());
-        } else {
-                ui.kNameInput->setText("");
         }
+
         onEditorModified();
         emit selectionChanged();
 }
@@ -142,7 +143,7 @@ void SKGCategoriesPluginWidget::setState(const QString& iState )
                 objectModel->setFilter ( "1=1" );
         }
 
-        //!!! Must be done here after onFilterChanged
+        //!!! Must be done here after setFilter
         ui.kCategoriesView->setState(root.attribute ( "view"));
 
         //Correction bug 2299394 vvv
@@ -150,7 +151,7 @@ void SKGCategoriesPluginWidget::setState(const QString& iState )
         //Correction bug 2299394 ^^^
 }
 
-QString SKGCategoriesPluginWidget::getDefaultStateAttibute()
+QString SKGCategoriesPluginWidget::getDefaultStateAttribute()
 {
         return "SKGCATEGORIES_DEFAULT_PARAMETERS";
 }
@@ -196,7 +197,7 @@ void SKGCategoriesPluginWidget::onAddCategory()
         QApplication::restoreOverrideCursor();
 
         //Display error
-        getMainPanel()->displayErrorMessage(err);
+        SKGMainPanel::getMainPanel()->displayErrorMessage(err);
 }
 
 void SKGCategoriesPluginWidget::onUpdateCategory()
@@ -223,7 +224,7 @@ void SKGCategoriesPluginWidget::onUpdateCategory()
         QApplication::restoreOverrideCursor();
 
         //Display error
-        getMainPanel()->displayErrorMessage(err);
+        SKGMainPanel::getMainPanel()->displayErrorMessage(err);
 }
 
 void SKGCategoriesPluginWidget::onDoubleClick()
@@ -242,11 +243,11 @@ void SKGCategoriesPluginWidget::onDoubleClick()
                 if (name.isEmpty()) {
                         wc+=" IS NULL OR t_REALCATEGORY=''";
                         wc='('+wc+')';
-                        title=i18n("Operations with empty category");
+                        title=i18n("Sub operations with empty category");
                 } else {
                         wc+=" = '"+SKGServices::stringToSqlString(name)+"' OR t_REALCATEGORY like '"+SKGServices::stringToSqlString(name)+OBJECTSEPARATOR+"%'";
                         wc='('+wc+')';
-                        title=i18n("Operations with Category containing '%1'",  name);
+                        title=i18n("Sub operations with category containing '%1'",  name);
                 }
 
                 //Open
@@ -257,11 +258,11 @@ void SKGCategoriesPluginWidget::onDoubleClick()
                         doc.appendChild(root);
                         root.setAttribute("sqlOrder", "SELECT * from v_operation_consolidated WHERE "+wc);
 
-                        getMainPanel()->setNewTabContent(getMainPanel()->getPluginByName("Skrooge debug plugin"), -1, doc.toString());
+                        SKGMainPanel::getMainPanel()->setNewTabContent(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge debug plugin"), -1, doc.toString());
                 } else {
                         //Call operation plugin
                         QDomDocument doc("SKGML");
-                        doc.setContent ( getDocument()->getParameter("SKGOPERATION_DEFAULT_PARAMETERS") );
+                        doc.setContent ( getDocument()->getParameter("SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS") );
                         QDomElement root = doc.documentElement();
                         if (root.isNull()) {
                                 root=doc.createElement("parameters");
@@ -271,12 +272,19 @@ void SKGCategoriesPluginWidget::onDoubleClick()
                         root.setAttribute("operationTable", "v_operation_consolidated");
                         root.setAttribute("operationWhereClause", wc);
                         root.setAttribute("title", title);
-                        root.setAttribute("title_icon", "view-statistics");
+                        root.setAttribute("title_icon", "skrooge_category");
                         root.setAttribute ( "currentPage", "-1" );
 
-                        getMainPanel()->setNewTabContent(getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
+                        SKGMainPanel::getMainPanel()->setNewTabContent(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
                 }
         }
 }
 
+void SKGCategoriesPluginWidget::cleanEditor()
+{
+        if (getNbSelectedObjects()==0) {
+                ui.kNameInput->setText("");
+        }
+}
+
 #include "skgcategoriespluginwidget.moc"
