@@ -40,7 +40,7 @@ public:
         /**
          * Default Constructor
          */
-        SKGCategoriesPluginWidget(SKGMainPanel* iParent, SKGDocumentBank* iDocument);
+        SKGCategoriesPluginWidget(SKGDocumentBank* iDocument);
 
         /**
          * Default Destructor
@@ -79,7 +79,7 @@ public:
          * MUST BE OVERWRITTEN
          * @return attribute name to save the default state.
          */
-        virtual QString getDefaultStateAttibute();
+        virtual QString getDefaultStateAttribute();
 
         /**
          * Get the widget must be printed
@@ -94,6 +94,7 @@ private slots:
         void onEditorModified();
         void onAddCategory();
         void onUpdateCategory();
+        void cleanEditor();
 
 private:
         Q_DISABLE_COPY(SKGCategoriesPluginWidget);
