@@ -35,7 +35,7 @@ public:
         /**
          * Default Constructor
          */
-        SKGDebugPluginWidget(SKGMainPanel* iParent, SKGDocument* iDocument);
+        SKGDebugPluginWidget(SKGDocument* iDocument);
 
         /**
          * Default Destructor
