@@ -42,18 +42,17 @@ SKGDeletePlugin::SKGDeletePlugin(QObject* iParent, const QVariantList& /*iArg*/)
 SKGDeletePlugin::~SKGDeletePlugin()
 {
         SKGTRACEIN(10, "SKGDeletePlugin::~SKGDeletePlugin");
-        parent=NULL;
         currentBankDocument=NULL;
         deleteAction=NULL;
 }
 
-void SKGDeletePlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDocument, const QStringList& iArgument)
+void SKGDeletePlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
 {
         SKGTRACEIN(10, "SKGDeletePlugin::setupActions");
         Q_UNUSED(iArgument);
 
         currentBankDocument=iDocument;
-        parent=iParent;
+
 
         setComponentData( SKGDeletePluginFactory::componentData() );
         setXMLFile("skrooge_delete.rc");
@@ -64,33 +63,34 @@ void SKGDeletePlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDocument
         actionCollection()->addAction( QLatin1String("edit_delete"), deleteAction );
         deleteAction->setShortcut(Qt::Key_Delete);
 
-        if (parent) parent->registedGlobalAction("edit_delete", deleteAction);
+        if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("edit_delete", deleteAction);
 }
 
 void SKGDeletePlugin::refresh()
 {
         SKGTRACEIN(10, "SKGDeletePlugin::refresh");
-        if (deleteAction && parent) deleteAction->setEnabled(parent->getSelectedObjects().count()>0);
+
+        if (deleteAction && SKGMainPanel::getMainPanel()) deleteAction->setEnabled(SKGMainPanel::getMainPanel()->getSelectedObjects().count()>0);
 }
 
 QString SKGDeletePlugin::title() const
 {
-        return i18n("Delete");
+        return i18nc("Verb, delete an item","Delete");
 }
 
 QString SKGDeletePlugin::icon() const
 {
-        return "";
+        return "edit-delete";
 }
 
 QString SKGDeletePlugin::statusTip () const
 {
-        return i18n("Delete");
+        return i18nc("Verb, delete an item","Delete");
 }
 
 QString SKGDeletePlugin::toolTip () const
 {
-        return i18n("Delete");
+        return i18nc("Verb, delete an item","Delete");
 }
 
 int SKGDeletePlugin::getOrder() const
@@ -109,10 +109,10 @@ void SKGDeletePlugin::actionDelete()
         SKGTRACEINRC(10, "SKGDeletePlugin::actionDelete",err);
 
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-        if (parent && currentBankDocument) {
-                SKGObjectBase::SKGListSKGObjectBase selection=parent->getSelectedObjects();
+        if (SKGMainPanel::getMainPanel() && currentBankDocument) {
+                SKGObjectBase::SKGListSKGObjectBase selection=SKGMainPanel::getMainPanel()->getSelectedObjects();
                 int nb=selection.count();
-                SKGBEGINPROGRESSTRANSACTION(*currentBankDocument, i18n("Delete"), err, nb);
+                SKGBEGINPROGRESSTRANSACTION(*currentBankDocument, i18nc("Verb, delete an item","Delete"), err, nb);
                 for (int i=0; err.isSucceeded() && i<nb; ++i) {
                         err=selection[i].remove();
                         if (err.isSucceeded()) err=currentBankDocument->stepForward(i+1);
@@ -125,7 +125,7 @@ void SKGDeletePlugin::actionDelete()
         QApplication::restoreOverrideCursor();
 
         //Display error
-        if (parent) parent->displayErrorMessage(err);
+        if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->displayErrorMessage(err);
 }
 
 #include "skgdeleteplugin.moc"
