@@ -20,7 +20,7 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgfileplugin.h"
-#include "skrooge_file.h"
+#include "skgfile_settings.h"
 
 #include "skgtraces.h"
 #include "skgerror.h"
@@ -51,7 +51,6 @@ SKGFilePlugin::~SKGFilePlugin()
         SKGTRACEIN(10, "SKGFilePlugin::~SKGFilePlugin");
         if (recentFiles) recentFiles->saveEntries(KConfigGroup(KGlobal::config(), "RecentFiles"));
 
-        parent=NULL;
         currentBankDocument=NULL;
         recentFiles=NULL;
         saveAction=NULL;
@@ -59,36 +58,35 @@ SKGFilePlugin::~SKGFilePlugin()
         passwordAction=NULL;
 }
 
-void SKGFilePlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDocument, const QStringList& iArgument)
+void SKGFilePlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
 {
         SKGTRACEIN(10, "SKGFilePlugin::setupActions");
-        Q_UNUSED(iArgument);
 
         currentBankDocument=iDocument;
-        parent=iParent;
+
 
         setComponentData( SKGFilePluginFactory::componentData() );
         setXMLFile("skrooge_file.rc");
 
         //Menu
         KAction* opennew=KStandardAction::openNew(this, SLOT(actionNew()), actionCollection());
-        if (parent) parent->registedGlobalAction("file_new", opennew);
+        if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("file_new", opennew);
 
         KAction* open=KStandardAction::open(this, SLOT(actionOpen()), actionCollection());
-        if (parent) parent->registedGlobalAction("file_open", open);
+        if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("file_open", open);
 
         saveAction=KStandardAction::save(this, SLOT(actionSave()), actionCollection());
-        if (parent) parent->registedGlobalAction("file_save", saveAction);
+        if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("file_save", saveAction);
 
         saveAsAction=KStandardAction::saveAs(this, SLOT(actionSaveAs()), actionCollection());
-        if (parent) parent->registedGlobalAction("file_save_as", saveAsAction);
+        if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("file_save_as", saveAsAction);
 
         passwordAction = new KAction(KIcon("document-encrypt"), i18n("&Change password..."), this);
         connect(passwordAction, SIGNAL(triggered(bool)), this, SLOT(actionChangePassword()));
         actionCollection()->addAction( QLatin1String("file_change_password"), passwordAction );
         passwordAction->setShortcut(Qt::CTRL+Qt::Key_K);
 
-        if (parent) parent->registedGlobalAction("file_change_password", passwordAction);
+        if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("file_change_password", passwordAction);
 
         //Recent file
         recentFiles=KStandardAction::openRecent(this,SLOT(actionOpen(const KUrl)), actionCollection());
@@ -98,25 +96,29 @@ void SKGFilePlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDocument,
         connect(this, SIGNAL(loadFile(const KUrl)), this, SLOT(actionOpen(const KUrl)), Qt::QueuedConnection);
 
         int nbArg=iArgument.count();
-        if (nbArg && QFile(iArgument.at(nbArg-1)).exists()) {
+        int openMode=1; //0=no open, 1=open last opened if settings set, 2=new document
+        if (nbArg) {
+                openMode=2;
                 QString filename=iArgument.at(nbArg-1);
-                if (parent) {
-                        KSplashScreen* splashScreen=parent->splashScreen();
-                        if (splashScreen) splashScreen->showMessage(i18n("Opening file %1...", filename), Qt::AlignLeft, QColor(221, 130, 8));
+                QString extension=QFileInfo(filename).suffix().toUpper();
+                if (QFile(filename).exists() && extension=="SKG") {
+                        processArguments(iArgument);
+                        openMode=0;
                 }
-                emit loadFile(filename);
-        } else {
+        }
+
+        if (openMode) {
                 //Read Setting
                 KSharedConfigPtr config=KSharedConfig::openConfig("skrooge_filerc");
                 KConfigGroup pref=config->group("File");
                 bool openlastfile = pref.readEntry("openlastfile",true);
-                if (openlastfile) {
+                if (openMode==1 && openlastfile) {
                         SKGTRACEIN(10, "SKGFilePlugin::openlastfile");
                         QString lastOpenedFile=pref.readPathEntry("lastfilepath",""); // krazy:exclude=doublequote_chars
                         if (!lastOpenedFile.isEmpty() && QFile(lastOpenedFile).exists()) {
-                                if (parent) {
-                                        KSplashScreen* splashScreen=parent->splashScreen();
-                                        if (splashScreen) splashScreen->showMessage(i18n("Opening file %1...", lastOpenedFile), Qt::AlignLeft, QColor(221, 130, 8));
+                                if (SKGMainPanel::getMainPanel()) {
+                                        KSplashScreen* splashScreen=SKGMainPanel::getMainPanel()->splashScreen();
+                                        if (splashScreen) splashScreen->showMessage(i18n("Opening file %1...", lastOpenedFile), Qt::AlignLeft, QColor(221, 130, 8)); // krazy:exclude=qmethods
                                 }
                                 emit loadFile(lastOpenedFile);
                         }
@@ -124,6 +126,25 @@ void SKGFilePlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDocument,
                         actionNew();
                 }
         }
+
+        //To be sure that the document has the right parameters
+        savePreferences();
+}
+
+void SKGFilePlugin::processArguments(const QStringList& iArgument)
+{
+        int nbArg=iArgument.count();
+        if (nbArg) {
+                QString filename=iArgument.at(nbArg-1);
+                QString extension=QFileInfo(filename).suffix().toUpper();
+                if (QFile(filename).exists() && extension=="SKG") {
+                        if (SKGMainPanel::getMainPanel()) {
+                                KSplashScreen* splashScreen=SKGMainPanel::getMainPanel()->splashScreen();
+                                if (splashScreen) splashScreen->showMessage(i18n("Opening file %1...", filename), Qt::AlignLeft, QColor(221, 130, 8)); // krazy:exclude=qmethods
+                        }
+                        emit loadFile(filename);
+                }
+        }
 }
 
 QWidget* SKGFilePlugin::getPreferenceWidget()
@@ -132,12 +153,42 @@ QWidget* SKGFilePlugin::getPreferenceWidget()
         QWidget* widget=new QWidget();
         ui.setupUi(widget);
 
+        ui.kcfg_prefix->addItem("");
+        ui.kcfg_prefix->addItem(".");
+
+        ui.kcfg_suffix->addItem(".old");
+        ui.kcfg_suffix->addItem(".back");
+        ui.kcfg_suffix->addItem(".<DATE>.back");
+        ui.kcfg_suffix->addItem(".<DATE>.old");
+        ui.kcfg_suffix->addItem("~");
+
         return widget;
 }
 
 KConfigSkeleton* SKGFilePlugin::getPreferenceSkeleton()
 {
-        return skrooge_file::self();
+        return skgfile_settings::self();
+}
+
+SKGError SKGFilePlugin::savePreferences() const
+{
+        SKGError err;
+        if ( currentBankDocument ) {
+                //Read Setting
+                KSharedConfigPtr config=KSharedConfig::openConfig ( "skrooge_filerc" );
+                KConfigGroup pref=config->group ( "File" );
+
+                QString prefix;
+                QString suffix;
+                if (pref.readEntry("backup_enabled", true)) {
+                        prefix = pref.readEntry ( "prefix", "" );
+                        suffix = pref.readEntry ( "suffix", ".old" );
+                }
+
+                //Save setting in document
+                currentBankDocument->setBackupParameters(prefix, suffix);
+        }
+        return err;
 }
 
 void SKGFilePlugin::refresh()
@@ -155,7 +206,7 @@ void SKGFilePlugin::refresh()
 
 QString SKGFilePlugin::title() const
 {
-        return i18n("File");
+        return i18nc("Noun, a file as in a text file","File");
 }
 
 QString SKGFilePlugin::icon() const
@@ -196,10 +247,10 @@ void SKGFilePlugin::actionNew()
 {
         SKGError err;
         SKGTRACEINRC(10, "SKGFilePlugin::actionNew",err);
-        if (parent && currentBankDocument && parent->queryFileClose()) {
+        if (SKGMainPanel::getMainPanel() && currentBankDocument && SKGMainPanel::getMainPanel()->queryFileClose()) {
                 QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
-                parent->closeAllTabs();
+                SKGMainPanel::getMainPanel()->closeAllTabs();
 
                 err=currentBankDocument->initialize();
 
@@ -247,7 +298,7 @@ void SKGFilePlugin::actionNew()
                 else err.addError(ERR_FAIL, i18n("Document creation failed."));
 
                 //Display error
-                if (parent) parent->displayErrorMessage(err);
+                if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->displayErrorMessage(err);
         }
 }
 
@@ -255,7 +306,7 @@ void SKGFilePlugin::actionSave()
 {
         SKGError err;
         SKGTRACEINRC(10, "SKGFilePlugin::actionSave",err);
-        if (currentBankDocument && parent) {
+        if (currentBankDocument && SKGMainPanel::getMainPanel()) {
                 if (currentBankDocument->getCurrentFileName().length()==0) {
                         actionSaveAs();
                 } else {
@@ -264,14 +315,14 @@ void SKGFilePlugin::actionSave()
                         QApplication::restoreOverrideCursor();
 
                         //Refresh
-                        parent->refresh();
+                        SKGMainPanel::getMainPanel()->refresh();
 
                         //status bar
                         if (err.isSucceeded()) err=SKGError(0, i18n("File successfully saved."));
                         else err.addError(ERR_FAIL, i18n("Cannot save file"));
 
                         //Display error
-                        parent->displayErrorMessage(err);
+                        SKGMainPanel::getMainPanel()->displayErrorMessage(err);
                 }
         }
 }
@@ -280,8 +331,8 @@ void SKGFilePlugin::actionSaveAs()
 {
         SKGError err;
         SKGTRACEINRC(10, "SKGFilePlugin::actionSaveAs",err);
-        if (currentBankDocument && parent) {
-                QString fileName=SKGMainPanel::getSaveFileName(KUrl("kfiledialog:///SKG"), i18n("*.skg|Skrooge document") , parent);
+        if (currentBankDocument && SKGMainPanel::getMainPanel()) {
+                QString fileName=SKGMainPanel::getSaveFileName(KUrl("kfiledialog:///SKG"), i18n("*.skg|Skrooge document") , SKGMainPanel::getMainPanel());
                 if (fileName.isEmpty()) return;
 
                 QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
@@ -289,7 +340,7 @@ void SKGFilePlugin::actionSaveAs()
                 QApplication::restoreOverrideCursor();
 
                 //Refresh
-                parent->refresh();
+                SKGMainPanel::getMainPanel()->refresh();
 
                 //status bar
                 if (err.isSucceeded()) {
@@ -307,7 +358,7 @@ void SKGFilePlugin::actionSaveAs()
                 } else err.addError(ERR_FAIL, i18n("Failed to save [%1].", fileName));
 
                 //Display error
-                parent->displayErrorMessage(err);
+                SKGMainPanel::getMainPanel()->displayErrorMessage(err);
         }
 }
 
@@ -315,14 +366,29 @@ void SKGFilePlugin::actionOpen(const KUrl & iUrl)
 {
         SKGError err;
         SKGTRACEINRC(10, "SKGFilePlugin::actionOpen",err);
-        if (parent && currentBankDocument && parent->queryFileClose()) {
+        if (SKGMainPanel::getMainPanel() && currentBankDocument && SKGMainPanel::getMainPanel()->queryFileClose()) {
 
                 QString fileName=iUrl.path();
-                if (!fileName.length()) fileName=KFileDialog::getOpenFileName(KUrl("kfiledialog:///SKG"), "*.skg|"+i18n("Skrooge document") , parent);
+                if (!fileName.length()) fileName=KFileDialog::getOpenFileName(KUrl("kfiledialog:///SKG"), "*.skg|"+i18n("Skrooge document") , SKGMainPanel::getMainPanel());
                 if (fileName.length()) {
+                        //Check if temporary file exists
+                        bool restoreTmpFile=false;
+                        QString tmpFile=SKGDocument::getTemporaryFile(fileName);
+                        if (QFile(tmpFile).exists()) {
+                                int conf=KMessageBox::questionYesNo(SKGMainPanel::getMainPanel(),
+                                                                    i18n("The temporary file of your document already exists. Do you want to restore it ?"),
+                                                                    i18n("Restore temporary file"),
+                                                                    KStandardGuiItem::yes(),
+                                                                    KStandardGuiItem::no());
+                                if (conf==KMessageBox::Yes) {
+                                        restoreTmpFile=true;
+                                }
+                        }
+
+                        //Open
                         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-                        parent->closeAllTabs();
-                        err=currentBankDocument->load(fileName);
+                        SKGMainPanel::getMainPanel()->closeAllTabs();
+                        err=currentBankDocument->load(fileName, "", restoreTmpFile);
                         QApplication::restoreOverrideCursor();
 
                         if (err.isFailed()) {
@@ -333,7 +399,7 @@ void SKGFilePlugin::actionOpen(const KUrl & iUrl)
                                 QString additionnalMessage;
                                 do {
                                         err=SKGError(0, "");
-                                        KDialog* d=new KDialog(parent);
+                                        QPointer<KDialog> d=new KDialog(SKGMainPanel::getMainPanel());
                                         QFrame* f=new QFrame(d);
                                         uipwd.setupUi(f);
                                         d->setMainWidget( f );
@@ -344,11 +410,11 @@ void SKGFilePlugin::actionOpen(const KUrl & iUrl)
                                         uipwd.kTitle->setPixmap(KIcon("document-decrypt").pixmap(48, 48), KTitleWidget::ImageLeft);
                                         uipwd.kPwd1->setFocus();
                                         if (d->exec()==QDialog::Accepted) {
-                                                KSplashScreen* splashScreen=parent->splashScreen();
+                                                KSplashScreen* splashScreen=SKGMainPanel::getMainPanel()->splashScreen();
                                                 if (splashScreen) splashScreen->hide();
 
                                                 QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-                                                err=currentBankDocument->load(fileName, uipwd.kPwd1->text());
+                                                err=currentBankDocument->load(fileName, uipwd.kPwd1->text(), restoreTmpFile);
                                                 if (err.isFailed()) {
                                                         additionnalMessage=i18n("Wrong password.\n");
                                                 }
@@ -356,6 +422,7 @@ void SKGFilePlugin::actionOpen(const KUrl & iUrl)
 
                                                 if (splashScreen) splashScreen->show();
                                         }
+                                        delete d;
                                 } while (err.isFailed());
                         }
                         if (err.isFailed()) err=currentBankDocument->initialize();
@@ -377,7 +444,7 @@ void SKGFilePlugin::actionOpen(const KUrl & iUrl)
                         } else  err.addError(ERR_FAIL, i18n("Failed to open [%1].", fileName));
 
                         //Display error
-                        if (parent) parent->displayErrorMessage(err);
+                        if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->displayErrorMessage(err);
                 }
         }
 }
@@ -387,7 +454,7 @@ void SKGFilePlugin::actionChangePassword()
         SKGError err;
         SKGTRACEINRC(10, "SKGFilePlugin::actionChangePassword",err);
         if (currentBankDocument) {
-                KDialog* d=new KDialog(parent);
+                QPointer<KDialog> d=new KDialog(SKGMainPanel::getMainPanel());
                 QFrame* f=new QFrame(d);
                 uipwd.setupUi(f);
                 d->setMainWidget( f );
@@ -411,8 +478,11 @@ void SKGFilePlugin::actionChangePassword()
                 } else {
                         err=SKGError(0, i18n("Changing password was canceled."));
                 }
+
+                delete d;
+
                 //Display error
-                if (parent) parent->displayErrorMessage(err);
+                if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->displayErrorMessage(err);
         }
 }
 #include "skgfileplugin.moc"
