@@ -57,11 +57,16 @@ public:
 
         /**
          * Called to initialise the plugin
-         * @param iParent the SKGMainPanel main panel parent
          * @param iDocument the SKGDocumentBank main document
          * @param iArgument the arguments
          */
-        virtual void setupActions(SKGMainPanel* iParent, SKGDocument* iDocument, const QStringList& iArgument);
+        virtual void setupActions(SKGDocument* iDocument, const QStringList& iArgument);
+
+        /**
+         * This function is called when the application is launched again with new arguments
+         * @param iArgument the arguments
+         */
+        virtual void processArguments(const QStringList& iArgument);
 
         /**
          * Must be modified to close properly the plugin.
@@ -80,6 +85,14 @@ public:
          */
         virtual KConfigSkeleton* getPreferenceSkeleton();
 
+        /**
+         * This function is called when preferences have been modified. Must be used to save some parameters into the document.
+         * A transaction is already opened
+         * @return an object managing the error.
+         *   @see SKGError
+         */
+        virtual SKGError savePreferences() const;
+
         /**
           * Must be modified to refresh widgets after a modification.
           */
@@ -142,7 +155,7 @@ private:
         KAction* passwordAction;
         KRecentFilesAction *recentFiles;
 
-        SKGMainPanel *parent;
+
         SKGDocument* currentBankDocument;
 
         Ui::skgfileplugin_pref ui;
