@@ -23,6 +23,7 @@
  */
 #include "skginterfaceplugin.h"
 #include "skgimportexportmanager.h"
+#include "ui_skgimportexportpluginwidget_pref.h"
 
 #include <QObject>
 #include <QVariantList>
@@ -53,11 +54,16 @@ public:
 
         /**
          * Called to initialise the plugin
-         * @param iParent the SKGMainPanel main panel parent
          * @param iDocument the SKGDocumentBank main document
          * @param iArgument the arguments
          */
-        virtual void setupActions(SKGMainPanel* iParent, SKGDocument* iDocument, const QStringList& iArgument);
+        virtual void setupActions(SKGDocument* iDocument, const QStringList& iArgument);
+
+        /**
+         * This function is called when the application is launched again with new arguments
+         * @param iArgument the arguments
+         */
+        virtual void processArguments(const QStringList& iArgument);
 
         /**
          * Must be modified to close properly the plugin.
@@ -69,6 +75,18 @@ public:
          */
         virtual void refresh();
 
+        /**
+         * The preference widget of the plugin.
+         * @return The preference widget of the plugin
+         */
+        virtual QWidget* getPreferenceWidget();
+
+        /**
+         * The preference skeleton of the plugin.
+         * @return The preference skeleton of the plugin
+         */
+        virtual KConfigSkeleton* getPreferenceSkeleton();
+
         /**
          * The title of the plugin.
          * @return The title of the plugin
@@ -105,28 +123,40 @@ public:
          */
         virtual QStringList tips() const;
 
+        /**
+         * Must be implemented to know if a plugin must be display in context chooser.
+         * @return true of false (default = false)
+         */
+        virtual bool isInContext() const;
+
 private slots:
-        void import();
+        void import(const QString& iFile="");
         void exportCsv();
         void exportQif();
         void foundTransfer();
         void cleanBankPerfect();
         void cleanBanks();
+        void validateImportedOperations();
+        void openNotValidated();
+        void mergeImportedOperation();
 private:
         Q_DISABLE_COPY(SKGImportExportPlugin);
 
-        KAction *importQifAction;
-        KAction *importOfxAction;
-        KAction *importCsvAction;
+        KAction *importAction;
         KAction *importCsvUnitAction;
         KAction *exportCsvAction;
         KAction *exportQifAction;
         KAction *processingFoundTransfert;
         KAction *processingBankPerfect;
         KAction *processingBank;
+        KAction *validateImportedOperationsAction;
+        KAction *openNotValidatedAction;
+        KAction *mergeImportedOperationAction;
+
 
-        SKGMainPanel *parent;
         SKGDocument* currentBankDocument;
+
+        Ui::skgimportexportplugin_pref ui;
 };
 
 #endif // SKGDEBUGPLUGIN_H
