@@ -37,8 +37,8 @@
 #include <QFile>
 #include <QDir>
 
-SKGMonthlyPluginWidget::SKGMonthlyPluginWidget(SKGMainPanel* iParent, SKGDocument* iDocument)
-                : SKGTabWidget(iParent, iDocument)
+SKGMonthlyPluginWidget::SKGMonthlyPluginWidget(SKGDocument* iDocument)
+                :SKGTabWidget(iDocument)
 {
         SKGTRACEIN(1, "SKGMonthlyPluginWidget::SKGMonthlyPluginWidget");
 
@@ -94,18 +94,21 @@ void SKGMonthlyPluginWidget::onPrint()
         _SKGTRACEIN(10, "SKGMonthlyPluginWidget::onPrint");
 #ifndef QT_NO_PRINTER
         QPrinter printer;
-        QPrintDialog dialog(&printer, this);
-        if (dialog.exec() == QDialog::Accepted) {
+        QPointer<QPrintDialog> dialog=new QPrintDialog(&printer, this);
+        if (dialog->exec() == QDialog::Accepted) {
                 QPainter painter(&printer);
                 ui.kWebView->render(&painter);
                 painter.end();
         }
+
+        delete dialog;
 #endif
 }
 
 void SKGMonthlyPluginWidget::dataModified(const QString& iTableName, int iIdTransaction)
 {
         SKGTRACEIN(1, "SKGMonthlyPluginWidget::dataModified");
+        Q_UNUSED(iIdTransaction);
 
         QSqlDatabase* db = getDocument()->getDatabase();
         setEnabled(db!=NULL);
@@ -178,7 +181,7 @@ void SKGMonthlyPluginWidget::onReportRefresh()
 
         {
                 int step=0;
-                SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18n("Compute monthly report for [%1]", month), err, 4);
+                SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18n("Compute monthly report for [%1]", month), err, 6);
 
                 //Generate HTML report
                 QString html="<?xml version=\"1.0\" encoding=\"utf-8\"?>"
@@ -198,7 +201,7 @@ void SKGMonthlyPluginWidget::onReportRefresh()
                 if (err.isSucceeded()) {
                         SKGStringListList listTmp;
                         err=SKGServices::executeSelectSqliteOrder(getDocument(),
-                                        "SELECT TOTAL(f_CURRENTAMOUNT), d_DATEMONTH  from v_operation_display WHERE (d_DATEMONTH='"+month+"' OR d_DATEMONTH='"+previousmonth+"') AND i_group_id=0 group by d_DATEMONTH, t_TYPEEXPENSE",
+                                        "SELECT TOTAL(f_CURRENTAMOUNT), d_DATEMONTH  from v_operation_display WHERE d_DATEMONTH IN ('"+month+"', '"+previousmonth+"') AND i_group_id=0 group by d_DATEMONTH, t_TYPEEXPENSE",
                                         listTmp);
                         if (err.isSucceeded()) {
                                 html+="<h2>"+i18n("Income & Expenditure")+"</h2><table class=\"table\">";
@@ -223,11 +226,11 @@ void SKGMonthlyPluginWidget::onReportRefresh()
                                 double saving_previous_month=income_previous_month+expense_previous_month;
                                 double saving_month=income_month+expense_month;
 
-                                html+=QString("<tr><td>")+i18n("Income")+"</td>"
+                                html+=QString("<tr><td>")+i18nc("Noun, financial operations with a positive amount","Income")+"</td>"
                                       "<td align=\"right\">"+locale->formatMoney(income_previous_month, primary,2)+"</td>"
                                       "<td align=\"right\">"+locale->formatMoney(income_month, primary,2)+"</td>"
                                       "</tr>";
-                                html+=QString("<tr><td>")+i18n("Expenditure")+"</td>"
+                                html+=QString("<tr><td>")+i18nc("Noun, financial operations with a negative amount","Expenditure")+"</td>"
                                       "<td align=\"right\">"+locale->formatMoney(abs(expense_previous_month), primary,2)+"</td>"
                                       "<td align=\"right\">"+locale->formatMoney(abs(expense_month), primary,2)+"</td>"
                                       "</tr>";
@@ -241,7 +244,7 @@ void SKGMonthlyPluginWidget::onReportRefresh()
                                             SKGServices::doubleToString(abs(expense_month))+','+
                                             SKGServices::doubleToString(abs(income_month))+
                                             "&chds="+range+
-                                            "&chs=300x200&chl="+i18n("Expenditure")+'|'+i18n("Income")+"&chtt="+i18n("Expenditure vs Income")+'|'+month;
+                                            "&chs=300x200&chl="+i18nc("Noun, financial operations with a negative amount","Expenditure")+'|'+i18nc("Noun, financial operations with a negative amount","Income")+"&chtt="+i18n("Expenditure vs Income")+'|'+month;
                                 // SKGTRACE << img << endl;
                                 html+="<img src=\""+img+"\" />";
                         }
@@ -249,18 +252,29 @@ void SKGMonthlyPluginWidget::onReportRefresh()
                 ++step;
                 if (err.isSucceeded()) err=getDocument()->stepForward(step);
 
+                //5 main categories of expenditure
+                if (err.isSucceeded()) {
+                        html+="<h2>"+i18n("5 main categories of expenditure ")+"</h2>";
+                        html+="<table>";
+                        html+="<tr><td align=\"center\">"+get5MainCategories(previousmonth)+"</td>"
+                              "<td align=\"center\">"+get5MainCategories(month)+"</td>"
+                              "</tr></table>";
+                }
+                ++step;
+                if (err.isSucceeded()) err=getDocument()->stepForward(step);
+
                 //Account
                 if (err.isSucceeded()) {
                         SKGObjectBase::SKGListSKGObjectBase accounts;
                         SKGError err=SKGObjectBase::getObjects(getDocument(), "v_account_display", "1=1 ORDER BY t_TYPENLS", accounts);
                         if (err.isSucceeded()) {
                                 html+="<h2>"+i18n("Amounts in accounts")+"</h2><table class=\"table\">";
-                                html+="<tr class=\"tabletitle\"><td align=\"center\">"+i18n("Account")+"</td>"
-                                      "<td align=\"center\">"+locale->formatDate (date1, KLocale::ShortDate)+"</td>"
-                                      "<td align=\"center\">"+locale->formatDate (date2, KLocale::ShortDate)+"</td>"
+                                html+="<tr class=\"tabletitle\"><td align=\"center\">"+SKGServices::stringToHtml(i18nc("Noun, an account as in a bank account","Account"))+"</td>"
+                                      "<td align=\"center\">"+SKGServices::stringToHtml(locale->formatDate (date1, KLocale::ShortDate))+"</td>"
+                                      "<td align=\"center\">"+SKGServices::stringToHtml(locale->formatDate (date2, KLocale::ShortDate))+"</td>"
                                       "<td align=\"center\">%</td>"
-                                      "<td align=\"center\">"+locale->formatDate (date3, KLocale::ShortDate)+"</td>"
-                                      "<td align=\"center\">"+locale->formatDate (date2, KLocale::ShortDate)+"</td>"
+                                      "<td align=\"center\">"+SKGServices::stringToHtml(locale->formatDate (date3, KLocale::ShortDate))+"</td>"
+                                      "<td align=\"center\">"+SKGServices::stringToHtml(locale->formatDate (date2, KLocale::ShortDate))+"</td>"
                                       "<td align=\"center\">%</td>"
                                       "</tr>";
                                 double sumTypeV1=0;
@@ -281,15 +295,15 @@ void SKGMonthlyPluginWidget::onReportRefresh()
                                         bool closed=account.isClosed();
                                         if (type!=currentType) {
                                                 if (!currentType.isEmpty()) {
-                                                        html+="<tr class=\"tabletotal\"><td>"+i18n("Total of %1", currentType)+"</td>"
-                                                              "<td align=\"right\">"+locale->formatMoney(sumTypeV1, primary,2)+"</td>"
-                                                              "<td align=\"right\">"+locale->formatMoney(sumTypeV2, primary,2)+"</td>"
+                                                        html+="<tr class=\"tabletotal\"><td>"+SKGServices::stringToHtml(i18n("Total of %1", currentType))+"</td>"
+                                                              "<td align=\"right\">"+SKGServices::stringToHtml(locale->formatMoney(sumTypeV1, primary,2))+"</td>"
+                                                              "<td align=\"right\">"+SKGServices::stringToHtml(locale->formatMoney(sumTypeV2, primary,2))+"</td>"
                                                               "<td"+(sumTypeV1>sumTypeV2 ? " class=\"negativevalue\"" : "")+
-                                                              " align=\"right\">"+(sumTypeV1==0 ? "" : locale->formatMoney(100.0*(sumTypeV2-sumTypeV1)/sumTypeV1,"%",2))+"</td>"
-                                                              "<td align=\"right\">"+locale->formatMoney(sumTypeV3, primary,2)+"</td>"
-                                                              "<td align=\"right\">"+locale->formatMoney(sumTypeV2, primary,2)+"</td>"
+                                                              " align=\"right\">"+(sumTypeV1==0 ? "" : SKGServices::stringToHtml(locale->formatMoney(100.0*(sumTypeV2-sumTypeV1)/sumTypeV1,"%",2)))+"</td>"
+                                                              "<td align=\"right\">"+SKGServices::stringToHtml(locale->formatMoney(sumTypeV3, primary,2))+"</td>"
+                                                              "<td align=\"right\">"+SKGServices::stringToHtml(locale->formatMoney(sumTypeV2, primary,2))+"</td>"
                                                               "<td"+(sumTypeV3>sumTypeV2 ? " class=\"negativevalue\"" : "")+
-                                                              " align=\"right\">"+(sumTypeV3==0 ? "" : locale->formatMoney(100.0*(sumTypeV2-sumTypeV3)/sumTypeV3,"%",2))+"</td>"
+                                                              " align=\"right\">"+(sumTypeV3==0 ? "" : SKGServices::stringToHtml(locale->formatMoney(100.0*(sumTypeV2-sumTypeV3)/sumTypeV3,"%",2)))+"</td>"
                                                               "</tr>";
                                                         sumTypeV1=0;
                                                         sumTypeV2=0;
@@ -298,15 +312,15 @@ void SKGMonthlyPluginWidget::onReportRefresh()
                                                 currentType=type;
                                         }
                                         if (!closed || abs(v1)>0.01 || abs(v2)>0.01 || abs(v3)>0.01) {
-                                                html+=QString("<tr><td>")+(closed ? "<i>" : "")+account.getName()+(closed ? "</i>" : "")+"</td>"
-                                                      "<td align=\"right\">"+locale->formatMoney(v1, primary,2)+"</td>"
-                                                      "<td align=\"right\">"+locale->formatMoney(v2, primary,2)+"</td>"
+                                                html+=QString("<tr><td>")+(closed ? "<i>" : "")+SKGServices::stringToHtml(account.getName())+(closed ? "</i>" : "")+"</td>"
+                                                      "<td align=\"right\">"+SKGServices::stringToHtml(locale->formatMoney(v1, primary,2))+"</td>"
+                                                      "<td align=\"right\">"+SKGServices::stringToHtml(locale->formatMoney(v2, primary,2))+"</td>"
                                                       "<td"+(v1>v2 ? " class=\"negativevalue\"" : "")+
-                                                      " align=\"right\">"+(v1==0 ? "" :locale->formatMoney(100.0*(v2-v1)/v1,"%",2))+"</td>"
-                                                      "<td align=\"right\">"+locale->formatMoney(v3, primary,2)+"</td>"
-                                                      "<td align=\"right\">"+locale->formatMoney(v2, primary,2)+"</td>"
+                                                      " align=\"right\">"+(v1==0 ? "" :SKGServices::stringToHtml(locale->formatMoney(100.0*(v2-v1)/v1,"%",2)))+"</td>"
+                                                      "<td align=\"right\">"+SKGServices::stringToHtml(locale->formatMoney(v3, primary,2))+"</td>"
+                                                      "<td align=\"right\">"+SKGServices::stringToHtml(locale->formatMoney(v2, primary,2))+"</td>"
                                                       "<td"+(v3>v2 ? " class=\"negativevalue\"" : "")+
-                                                      " align=\"right\">"+(v3==0 ? "" : locale->formatMoney(100.0*(v2-v3)/v3,"%",2))+"</td>"
+                                                      " align=\"right\">"+(v3==0 ? "" : SKGServices::stringToHtml(locale->formatMoney(100.0*(v2-v3)/v3,"%",2)))+"</td>"
                                                       "</tr>";
                                         }
                                         sumTypeV1+=v1;
@@ -320,25 +334,25 @@ void SKGMonthlyPluginWidget::onReportRefresh()
                                 }
                                 getDocument()->endTransaction(err.isSucceeded());
 
-                                html+="<tr class=\"tabletotal\"><td>"+i18n("Total of %1", currentType)+"</td>"
-                                      "<td align=\"right\">"+locale->formatMoney(sumTypeV1, primary,2)+"</td>"
-                                      "<td align=\"right\">"+locale->formatMoney(sumTypeV2, primary,2)+"</td>"
+                                html+="<tr class=\"tabletotal\"><td>"+SKGServices::stringToHtml(i18n("Total of %1", currentType))+"</td>"
+                                      "<td align=\"right\">"+SKGServices::stringToHtml(locale->formatMoney(sumTypeV1, primary,2))+"</td>"
+                                      "<td align=\"right\">"+SKGServices::stringToHtml(locale->formatMoney(sumTypeV2, primary,2))+"</td>"
                                       "<td"+(sumTypeV1>sumTypeV2 ? " class=\"negativevalue\"" : "")+
-                                      " align=\"right\">"+(sumTypeV1==0 ? "" : locale->formatMoney(100.0*(sumTypeV2-sumTypeV1)/sumTypeV1,"%",2))+"</td>"
-                                      "<td align=\"right\">"+locale->formatMoney(sumTypeV3, primary,2)+"</td>"
-                                      "<td align=\"right\">"+locale->formatMoney(sumTypeV2, primary,2)+"</td>"
+                                      " align=\"right\">"+(sumTypeV1==0 ? "" : SKGServices::stringToHtml(locale->formatMoney(100.0*(sumTypeV2-sumTypeV1)/sumTypeV1,"%",2)))+"</td>"
+                                      "<td align=\"right\">"+SKGServices::stringToHtml(locale->formatMoney(sumTypeV3, primary,2))+"</td>"
+                                      "<td align=\"right\">"+SKGServices::stringToHtml(locale->formatMoney(sumTypeV2, primary,2))+"</td>"
                                       "<td"+(sumTypeV3>sumTypeV2 ? " class=\"negativevalue\"" : "")+
-                                      " align=\"right\">"+(sumTypeV3==0 ? "" : locale->formatMoney(100.0*(sumTypeV2-sumTypeV3)/sumTypeV3,"%",2))+"</td>"
+                                      " align=\"right\">"+(sumTypeV3==0 ? "" : SKGServices::stringToHtml(locale->formatMoney(100.0*(sumTypeV2-sumTypeV3)/sumTypeV3,"%",2)))+"</td>"
                                       "</tr>";
-                                html+="<tr class=\"tabletotal\"><td>"+i18n("Total")+"</td>"
-                                      "<td align=\"right\">"+locale->formatMoney(sumV1, primary,2)+"</td>"
-                                      "<td align=\"right\">"+locale->formatMoney(sumV2, primary,2)+"</td>"
+                                html+="<tr class=\"tabletotal\"><td>"+SKGServices::stringToHtml(i18nc("Noun, the numerical total of a sum of values","Total"))+"</td>"
+                                      "<td align=\"right\">"+SKGServices::stringToHtml(locale->formatMoney(sumV1, primary,2))+"</td>"
+                                      "<td align=\"right\">"+SKGServices::stringToHtml(locale->formatMoney(sumV2, primary,2))+"</td>"
                                       "<td"+(sumV1>sumV2 ? " class=\"negativevalue\"" : "")+
-                                      " align=\"right\">"+(sumV1==0 ? "" : locale->formatMoney(100.0*(sumV2-sumV1)/sumV1,"%",2))+"</td>"
-                                      "<td align=\"right\">"+locale->formatMoney(sumV3, primary,2)+"</td>"
-                                      "<td align=\"right\">"+locale->formatMoney(sumV2, primary,2)+"</td>"
+                                      " align=\"right\">"+(sumV1==0 ? "" : SKGServices::stringToHtml(locale->formatMoney(100.0*(sumV2-sumV1)/sumV1,"%",2)))+"</td>"
+                                      "<td align=\"right\">"+SKGServices::stringToHtml(locale->formatMoney(sumV3, primary,2))+"</td>"
+                                      "<td align=\"right\">"+SKGServices::stringToHtml(locale->formatMoney(sumV2, primary,2))+"</td>"
                                       "<td"+(sumV3>sumV2 ? " class=\"negativevalue\"" : "")+
-                                      " align=\"right\">"+(sumV3==0 ? "" : locale->formatMoney(100.0*(sumV2-sumV3)/sumV3,"%",2))+"</td>"
+                                      " align=\"right\">"+(sumV3==0 ? "" : SKGServices::stringToHtml(locale->formatMoney(100.0*(sumV2-sumV3)/sumV3,"%",2)))+"</td>"
                                       "</tr>";
                                 html+="</table>";
                         }
@@ -352,18 +366,18 @@ void SKGMonthlyPluginWidget::onReportRefresh()
                         SKGError err=SKGObjectBase::getObjects(getDocument(), "v_unit_display", "1=1 ORDER BY t_TYPENLS", units);
                         if (err.isSucceeded()) {
                                 html+="<h2>"+i18n("Amounts of units")+"</h2><table class=\"table\">";
-                                html+="<tr class=\"tabletitle\"><td align=\"center\">"+i18n("Unit")+"</td>"
-                                      "<td align=\"center\">"+locale->formatDate (date1, KLocale::ShortDate)+"</td>"
-                                      "<td align=\"center\">"+locale->formatDate (date2, KLocale::ShortDate)+"</td>"
+                                html+="<tr class=\"tabletitle\"><td align=\"center\">"+SKGServices::stringToHtml(i18nc("Noun, the unit of an operation, usually a currency or a share","Unit"))+"</td>"
+                                      "<td align=\"center\">"+SKGServices::stringToHtml(locale->formatDate (date1, KLocale::ShortDate))+"</td>"
+                                      "<td align=\"center\">"+SKGServices::stringToHtml(locale->formatDate (date2, KLocale::ShortDate))+"</td>"
                                       "<td align=\"center\">%</td></tr>";
                                 foreach(const SKGUnitObject& unit, units) {
                                         double v1=unit.getAmount(date1);
                                         double v2=unit.getAmount(date2);
-                                        html+="<tr><td>"+unit.getName()+"</td>"
-                                              "<td align=\"right\">"+locale->formatMoney(v1, primary,2)+"</td>"
-                                              "<td align=\"right\">"+locale->formatMoney(v2, primary,2)+"</td>"
+                                        html+="<tr><td>"+SKGServices::stringToHtml(unit.getName())+"</td>"
+                                              "<td align=\"right\">"+SKGServices::stringToHtml(locale->formatMoney(v1, primary,2))+"</td>"
+                                              "<td align=\"right\">"+SKGServices::stringToHtml(locale->formatMoney(v2, primary,2))+"</td>"
                                               "<td"+(v1>v2 ? " class=\"negativevalue\"" : "")+
-                                              " align=\"right\">"+(v1==0 ? "" : locale->formatMoney(100.0*(v2-v1)/v1,"%",2))+"</td></tr>";
+                                              " align=\"right\">"+(v1==0 ? "" : SKGServices::stringToHtml(locale->formatMoney(100.0*(v2-v1)/v1,"%",2)))+"</td></tr>";
                                 }
                                 html+="</table>";
                         }
@@ -392,7 +406,51 @@ void SKGMonthlyPluginWidget::onReportRefresh()
         else err.addError(ERR_FAIL, i18n("Report computation failed."));
 
         //Display error
-        getMainPanel()->displayErrorMessage(err);
+        SKGMainPanel::getMainPanel()->displayErrorMessage(err);
+}
+
+QString SKGMonthlyPluginWidget::get5MainCategories(const QString& iMonth)
+{
+        QString html;
+        KLocale* locale=KGlobal::locale();
+        QString primary=((SKGDocumentBank*) getDocument())->getPrimaryUnit();
+
+        SKGStringListList listTmp;
+        SKGError err=SKGServices::executeSelectSqliteOrder(getDocument(),"SELECT t_REALCATEGORY, TOTAL(f_REALCURRENTAMOUNT) FROM v_operation_consolidated "
+                        "where i_group_id=0 AND d_DATEMONTH='"+iMonth+"' AND t_TYPEEXPENSE='-' "
+                        "group by t_REALCATEGORY order by TOTAL(f_REALCURRENTAMOUNT) LIMIT 5;",
+                        listTmp);
+        if (err.isSucceeded()) {
+                html+="<table class=\"table\">";
+                html+="<tr class=\"tabletitle\"><td align=\"center\">"+i18nc("Noun, an item's category","Category")+"</td>"
+                      "<td align=\"center\">"+iMonth+"</td>"
+                      "</tr>";
+                int nbval=listTmp.count();
+                QString qoogleChl;
+                QString qoogleChd;
+                double max=0;
+                for (int i=1; i<nbval; ++i) { //Ignore header
+                        QString m=listTmp.at(i).at(1);
+                        double v=abs(SKGServices::stringToDouble(listTmp.at(i).at(1)));
+                        max=qMax(max, v);
+                        html+=QString("<tr><td>")+SKGServices::intToString(i)+" : "+listTmp.at(i).at(0)+"</td>"
+                              "<td align=\"right\">"+locale->formatMoney(v, primary,2)+"</td>"
+                              "</tr>";
+                        if (i>1) {
+                                qoogleChl+='|';
+                                qoogleChd+=',';
+                        }
+                        qoogleChl+=SKGServices::intToString(i);
+                        qoogleChd+=SKGServices::doubleToString(v).replace(',', '.');
+                }
+                html+="</table>";
+
+                QString img="http://chart.apis.google.com/chart?cht=p3&chco=FF0000&chd=t:"+qoogleChd+"&chs=300x100&chl="+qoogleChl+
+                            "&chds=0,"+SKGServices::doubleToString(max);;
+                //SKGTRACE << img << endl;
+                html+="<img src=\""+img+"\" />";
+        }
+        return html;
 }
 #include "skgmonthlypluginwidget.moc"
 
