@@ -35,7 +35,7 @@ public:
         /**
          * Default Constructor
          */
-        SKGMonthlyPluginWidget(SKGMainPanel* iParent, SKGDocument* iDocument);
+        SKGMonthlyPluginWidget(SKGDocument* iDocument);
 
         /**
          * Default Destructor
@@ -70,6 +70,7 @@ private slots:
         void onPrint();
 private:
         Q_DISABLE_COPY(SKGMonthlyPluginWidget);
+        QString get5MainCategories(const QString& iMonth);
 
         Ui::skgmonthlyplugin_base ui;
 };
