@@ -52,11 +52,10 @@ public:
 
         /**
          * Called to initialise the plugin
-         * @param iParent the SKGMainPanel main panel parent
          * @param iDocument the SKGDocumentBank main document
          * @param iArgument the arguments
          */
-        virtual void setupActions(SKGMainPanel* iParent, SKGDocument* iDocument, const QStringList& iArgument);
+        virtual void setupActions(SKGDocument* iDocument, const QStringList& iArgument);
 
         /**
          * Must be modified to close properly the plugin.
@@ -69,10 +68,24 @@ public:
         virtual void refresh();
 
         /**
-         * The dashboard widget of the plugin.
+         * The number of dashboard widgets of the plugin.
+         * @return The number of dashboard widgets of the plugin
+         */
+        virtual int getNbDashboardWidgets();
+
+        /**
+         * Get a dashboard widget title of the plugin.
+         * @param iIndex the index of the widget
+         * @return The title
+         */
+        virtual QString getDashboardWidgetTitle(int iIndex);
+
+        /**
+         * Get a dashboard widget of the plugin.
+         * @param iIndex the index of the widget
          * @return The dashboard widget of the plugin
          */
-        virtual SKGWidget* getDashboardWidget();
+        virtual SKGWidget* getDashboardWidget(int iIndex);
 
         /**
          * The preference widget of the plugin.
@@ -92,14 +105,6 @@ public:
          */
         virtual SKGTabWidget* getWidget();
 
-        /**
-         * This function is called when preferences have been modified. Must be used to save some parameters into the document.
-         * A transaction is already opened
-         * @return an object managing the error.
-         *   @see SKGError
-         */
-        virtual SKGError savePreferences() const;
-
         /**
          * The title of the plugin.
          * @return The title of the plugin
@@ -144,20 +149,20 @@ public:
 
 private slots:
         void actionDuplicate();
+        void actionCreateTemplate();
         void actionSwitchToPointed();
-        void actionSwitchBookmark();
-        void actionOpenBookmarks();
+        void actionSwitchHighLight();
+        void actionOpenHighLights();
 
 private:
         Q_DISABLE_COPY(SKGOperationPlugin);
 
         KAction *duplicateAction;
+        KAction *createTemplateAction;
         KAction *switchToPointedAction;
-        KAction *switchBookmark;
-        KAction *fastEditionAction;
-        KAction *openBookmarks;
+        KAction *switchHighLight;
+        KAction *openHighLights;
 
-        SKGMainPanel *parent;
         SKGDocument* currentBankDocument;
 
         Ui::skgoperationplugin_pref ui;
