@@ -52,11 +52,10 @@ public:
 
         /**
          * Called to initialise the plugin
-         * @param iParent the SKGMainPanel main panel parent
          * @param iDocument the SKGDocumentBank main document
          * @param iArgument the arguments
          */
-        virtual void setupActions(SKGMainPanel* iParent, SKGDocument* iDocument, const QStringList& iArgument);
+        virtual void setupActions(SKGDocument* iDocument, const QStringList& iArgument);
 
         /**
          * Must be modified to close properly the plugin.
@@ -86,14 +85,6 @@ public:
          */
         virtual SKGTabWidget* getWidget();
 
-        /**
-         * This function is called when preferences have been modified. Must be used to save some parameters into the document.
-         * A transaction is already opened
-         * @return an object managing the error.
-         *   @see SKGError
-         */
-        virtual SKGError savePreferences() const;
-
         /**
          * The title of the plugin.
          * @return The title of the plugin
@@ -144,7 +135,7 @@ private slots:
 private:
         Q_DISABLE_COPY(SKGPrintPlugin);
 
-        SKGMainPanel *parent;
+
         SKGDocument* currentBankDocument;
         KAction* printAction;
         KAction* printPreviewAction;
