@@ -29,14 +29,20 @@
 
 #include <QtGui/QGraphicsScene>
 
-SKGReportPluginWidget::SKGReportPluginWidget(SKGMainPanel* iParent, SKGDocumentBank* iDocument)
-                : SKGTabWidget(iParent, iDocument)
+SKGReportPluginWidget::SKGReportPluginWidget(SKGDocumentBank* iDocument)
+                :SKGTabWidget(iDocument)
 {
         SKGTRACEIN(10, "SKGReportPluginWidget::SKGReportPluginWidget");
 
+        timer = new QTimer( this );
+        timer->setSingleShot( true );
+        connect( timer, SIGNAL( timeout() ), this, SLOT( refreshActivated() ) );
+
         ui.setupUi(this);
 
         ui.kTitle->hide();
+        ui.kDateBegin->hide();
+        ui.kDateEnd->hide();
 
         //Build contextual menu
         ui.kTableWithGraph->getTableContextualMenu()->addSeparator();
@@ -49,21 +55,19 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGMainPanel* iParent, SKGDocumentB
 
         //Init comboboxes
         AttsForColumns << "d_DATEMONTH" << "d_DATEYEAR" << "";
-        ui.kColumns->addItem(i18n("Months"));
-        ui.kColumns->addItem(i18n("Years"));
-        ui.kColumns->addItem(i18n("-- Nothing --"));
+        ui.kColumns->addItem(i18nc( "Noun, the months in a year","Months"));
+        ui.kColumns->addItem(i18nc("Noun, the years in a century","Years"));
+        ui.kColumns->addItem(i18nc("Noun, the absence of anything","-- Nothing --"));
 
-        AttsForLines << "t_REALCATEGORY" << "t_payee" << "t_mode" << "t_TYPEEXPENSENLS" << "t_status" << "t_ACCOUNTTYPE" << "t_UNITTYPE";
-        ui.kLines->addItem(i18n("Categories"));
-        ui.kLines->addItem(i18n("Payees"));
-        ui.kLines->addItem(i18n("Modes"));
-        ui.kLines->addItem(i18n("Types"));
-        ui.kLines->addItem(i18n("Status"));
-        ui.kLines->addItem(i18n("Accounts"));
-        ui.kLines->addItem(i18n("Units"));
+        AttsForLines << "t_REALCATEGORY" << "t_payee" << "t_mode" << "t_TYPEEXPENSENLS" << "t_status" << "t_ACCOUNTTYPE" << "t_UNITTYPE" << "t_REALREFUND";
+        if (iDocument) {
+                foreach(const QString& att, AttsForLines) {
+                        ui.kLines->addItem(iDocument->getIcon(att), iDocument->getDisplay(att));
+                }
+        }
 
-        ui.kMode->addItem(i18n("Sum"));
-        ui.kMode->addItem(i18n("History"));
+        ui.kMode->addItem(i18nc("Noun, the numerical sum of a list of values","Sum"));
+        ui.kMode->addItem(i18nc("Noun, historical values of an item","History"));
 
         ui.kPeriod->addItem(i18n("All dates"));
         ui.kPeriod->addItem(i18n("Current month"));
@@ -77,11 +81,12 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGMainPanel* iParent, SKGDocumentB
         ui.kPeriod->addItem(i18n("Last 2 years"));
         ui.kPeriod->addItem(i18n("Last 3 years"));
         ui.kPeriod->addItem(i18n("Last 5 years"));
+        ui.kPeriod->addItem(i18n("Custom..."));
         ui.kPeriod->setCurrentIndex(1);
 
-        ui.kType->addItem(i18n("All without transfer"));
-        ui.kType->addItem(i18n("Income without transfer"));
-        ui.kType->addItem(i18n("Expenditure without transfer"));
+        ui.kType->addItem(i18n("All without transfers"));
+        ui.kType->addItem(i18n("Income without transfers"));
+        ui.kType->addItem(i18n("Expenditure without transfers"));
         ui.kType->addItem(i18n("All with transfers"));
         ui.kType->addItem(i18n("Income with transfers"));
         ui.kType->addItem(i18n("Expenditure with transfers"));
@@ -95,13 +100,12 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGMainPanel* iParent, SKGDocumentB
         connect(ui.kPeriod, SIGNAL(currentIndexChanged(int)), this, SLOT(refresh()), Qt::QueuedConnection);
         connect(ui.kType, SIGNAL(currentIndexChanged(int)), this, SLOT(refresh()), Qt::QueuedConnection);
         connect((const QObject*) getDocument(), SIGNAL(tableModified(QString, int)), this, SLOT(dataModified(QString, int)));
-
-        refresh();
 }
 
 SKGReportPluginWidget::~SKGReportPluginWidget()
 {
         SKGTRACEIN(10, "SKGReportPluginWidget::~SKGReportPluginWidget");
+        timer=NULL;
 }
 
 QString SKGReportPluginWidget::getState()
@@ -121,6 +125,8 @@ QString SKGReportPluginWidget::getState()
         root.setAttribute("lines", ui.kLines->currentIndex());
         root.setAttribute("mode", ui.kMode->currentIndex());
         root.setAttribute("period", ui.kPeriod->currentIndex());
+        root.setAttribute("date_begin", SKGServices::intToString(ui.kDateBegin->date().toJulianDay()));
+        root.setAttribute("date_end", SKGServices::intToString(ui.kDateEnd->date().toJulianDay()));
         root.setAttribute("type", ui.kType->currentIndex());
         root.setAttribute("tableAndGraphState", ui.kTableWithGraph->getState());
         if (operationWhereClause.length()) root.setAttribute("operationWhereClause", operationWhereClause);
@@ -139,6 +145,8 @@ void SKGReportPluginWidget::setState(const QString& iState )
                 QString lines=root.attribute ( "lines");
                 QString mode=root.attribute ( "mode");
                 QString period=root.attribute ( "period");
+                QString date_begin=root.attribute ( "date_begin");
+                QString date_end=root.attribute ( "date_end");
                 QString type=root.attribute ( "type");
                 QString tableAndGraphState=root.attribute ( "tableAndGraphState");
                 QString title=root.attribute ( "title");
@@ -149,9 +157,14 @@ void SKGReportPluginWidget::setState(const QString& iState )
                 if (!mode.isEmpty()) ui.kMode->setCurrentIndex(SKGServices::stringToInt(mode));
                 if (!period.isEmpty()) ui.kPeriod->setCurrentIndex(SKGServices::stringToInt(period));
                 if (!type.isEmpty()) ui.kType->setCurrentIndex(SKGServices::stringToInt(type));
+                if (!date_begin.isEmpty()) ui.kDateBegin->setDate(QDate::fromJulianDay(SKGServices::stringToInt(date_begin)));
+                if (!date_end.isEmpty()) ui.kDateEnd->setDate(QDate::fromJulianDay(SKGServices::stringToInt(date_end)));
+
+                refresh();
+
                 ui.kTableWithGraph->setState(tableAndGraphState);
                 if (!title.isEmpty()) {
-                        ui.kTitle->setComment("<html><body><b>"+title+"</b></body></html>");
+                        ui.kTitle->setComment("<html><body><b>"+SKGServices::stringToHtml(title)+"</b></body></html>");
                         ui.kTitle->show();
                 } else {
                         ui.kTitle->hide();
@@ -162,10 +175,13 @@ void SKGReportPluginWidget::setState(const QString& iState )
                         lastState=doc;
                         dataModified("", 0);
                 }
-        } else ui.kTableWithGraph->setState("");
+        } else {
+                refresh();
+                ui.kTableWithGraph->setState("");
+        }
 }
 
-QString SKGReportPluginWidget::getDefaultStateAttibute()
+QString SKGReportPluginWidget::getDefaultStateAttribute()
 {
         return "SKGREPORT_DEFAULT_PARAMETERS";
 }
@@ -185,7 +201,7 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForSelection(int row, int colu
         bool modeHistory=(ui.kMode->currentIndex()==1);
 
         //Condition on line attribute
-        oTitle+=i18n("Operations with ");
+        oTitle+=i18n("Sub operations with ");
         if (modeHistory || row+1!=ui.kTableWithGraph->table()->rowCount()) {
                 QString att=AttsForLines[ui.kLines->currentIndex()];
                 oWc=att;
@@ -241,11 +257,11 @@ void SKGReportPluginWidget::onDoubleClick(int row, int column)
                 doc.appendChild(root);
                 root.setAttribute("sqlOrder", "SELECT * from v_operation_consolidated WHERE "+wc);
 
-                getMainPanel()->setNewTabContent(getMainPanel()->getPluginByName("Skrooge debug plugin"), -1, doc.toString());
+                SKGMainPanel::getMainPanel()->setNewTabContent(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge debug plugin"), -1, doc.toString());
         } else {
                 //Call operation plugin
                 QDomDocument doc("SKGML");
-                doc.setContent ( getDocument()->getParameter("SKGOPERATION_DEFAULT_PARAMETERS") );
+                doc.setContent ( getDocument()->getParameter("SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS") );
                 QDomElement root = doc.documentElement();
                 if (root.isNull()) {
                         root=doc.createElement("parameters");
@@ -258,7 +274,7 @@ void SKGReportPluginWidget::onDoubleClick(int row, int column)
                 root.setAttribute("title_icon", "view-statistics");
                 root.setAttribute ( "currentPage", "-1" );
 
-                getMainPanel()->setNewTabContent(getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
+                SKGMainPanel::getMainPanel()->setNewTabContent(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
         }
 }
 
@@ -279,7 +295,7 @@ void SKGReportPluginWidget::onOpenReport()
                 root.setAttribute("operationWhereClause", wc);
                 root.setAttribute("title", title);
                 root.setAttribute("title_icon", "view-statistics");
-                getMainPanel()->setNewTabContent(getMainPanel()->getPluginByName("Skrooge report plugin"), -1, doc.toString());
+                SKGMainPanel::getMainPanel()->setNewTabContent(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge report plugin"), -1, doc.toString());
         }
 }
 
@@ -335,6 +351,10 @@ QString SKGReportPluginWidget::getConsolidatedWhereClause()
                 //5 last years
                 wc="d_date>date('now','-5 year') AND d_date<=date('now')";
                 break;
+        case 12:
+                //Custom
+                wc="d_date>='"+SKGServices::dateToSqlString(QDateTime(ui.kDateBegin->date()))+ "' AND d_date<='"+SKGServices::dateToSqlString(QDateTime(ui.kDateEnd->date()))+ '\'';
+                break;
         default:
                 wc="1=1";
                 break;
@@ -373,6 +393,31 @@ void SKGReportPluginWidget::onSelectionChanged()
 }
 
 void SKGReportPluginWidget::refresh()
+{
+        bool custom=(ui.kPeriod->currentIndex()==12);
+        ui.kDateBegin->setVisible(custom);
+        ui.kDateEnd->setVisible(custom);
+
+        QDate d1=ui.kDateBegin->date();
+        QDate d2=ui.kDateEnd->date();
+        if (d1>d2) {
+                ui.kDateBegin->setDate(d2);
+                ui.kDateEnd->setDate(d1);
+        }
+
+        if (custom) {
+                connect(ui.kDateBegin, SIGNAL(dateChanged(QDate)), this, SLOT(refresh()), Qt::QueuedConnection);
+                connect(ui.kDateEnd, SIGNAL(dateChanged(QDate)), this, SLOT(refresh()), Qt::QueuedConnection);
+        } else {
+                disconnect(ui.kDateBegin, SIGNAL(dateChanged(QDate)));
+                disconnect(ui.kDateEnd, SIGNAL(dateChanged(QDate)));
+        }
+
+        if (sender() && timer) timer->start( 300 );
+        else refreshActivated();
+}
+
+void SKGReportPluginWidget::refreshActivated()
 {
         dataModified("", 0);
 }
@@ -390,7 +435,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                 //Check if needed
                 if (iTableName=="operation" || iTableName.isEmpty()) {
                         //Check if update is needed
-                        QString ParametersUsed=getState()+';'+SKGServices::intToString(getDocument()->getTransactionToTreat());;
+                        QString ParametersUsed=getState()+';'+SKGServices::intToString(getDocument()->getTransactionToProcess());;
                         if (ParametersUsed==previousParametersUsed) {
                                 SKGTRACEL(10) << "Same parameters. Refresh ignored" << endl;
                                 return;
@@ -467,7 +512,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                         QApplication::restoreOverrideCursor();
 
                         //Display error
-                        getMainPanel()->displayErrorMessage(err);
+                        SKGMainPanel::getMainPanel()->displayErrorMessage(err);
                 }
         }
 }
