@@ -26,6 +26,7 @@
 
 #include <QStringList>
 #include <QDomDocument>
+#include <QTimer>
 
 class SKGDocumentBank;
 
@@ -40,7 +41,7 @@ public:
         /**
          * Default Constructor
          */
-        SKGReportPluginWidget(SKGMainPanel* iParent, SKGDocumentBank* iDocument);
+        SKGReportPluginWidget(SKGDocumentBank* iDocument);
 
         /**
          * Default Destructor
@@ -67,7 +68,7 @@ public:
          * MUST BE OVERWRITTEN
          * @return attribute name to save the default state.
          */
-        virtual QString getDefaultStateAttibute();
+        virtual QString getDefaultStateAttribute();
 
         /**
          * Get the widget must be printed
@@ -93,6 +94,7 @@ private slots:
         void onDoubleClick(int row, int column);
         void onOpenReport();
         void onSelectionChanged();
+        void refreshActivated();
 
 private:
         Q_DISABLE_COPY(SKGReportPluginWidget);
@@ -106,6 +108,7 @@ private:
         QString operationWhereClause;
         QDomDocument lastState;
         QAction* openReportAction;
+        QTimer* timer;
 };
 
 #endif // SKGREPORTPLUGINWIDGET_H
