@@ -52,11 +52,10 @@ public:
 
         /**
          * Called to initialise the plugin
-         * @param iParent the SKGMainPanel main panel parent
          * @param iDocument the SKGDocumentBank main document
          * @param iArgument the arguments
          */
-        virtual void setupActions(SKGMainPanel* iParent, SKGDocument* iDocument, const QStringList& iArgument);
+        virtual void setupActions(SKGDocument* iDocument, const QStringList& iArgument);
 
         /**
          * Must be modified to close properly the plugin.
@@ -64,10 +63,24 @@ public:
         virtual void close();
 
         /**
-         * The dashboard widget of the plugin.
+         * The number of dashboard widgets of the plugin.
+         * @return The number of dashboard widgets of the plugin
+         */
+        virtual int getNbDashboardWidgets();
+
+        /**
+         * Get a dashboard widget title of the plugin.
+         * @param iIndex the index of the widget
+         * @return The title
+         */
+        virtual QString getDashboardWidgetTitle(int iIndex);
+
+        /**
+         * Get a dashboard widget of the plugin.
+         * @param iIndex the index of the widget
          * @return The dashboard widget of the plugin
          */
-        virtual SKGWidget* getDashboardWidget();
+        virtual SKGWidget* getDashboardWidget(int iIndex);
 
         /**
          * Must be modified to refresh widgets after a modification.
@@ -92,14 +105,6 @@ public:
          */
         virtual SKGTabWidget* getWidget();
 
-        /**
-         * This function is called when preferences have been modified. Must be used to save some parameters into the document.
-         * A transaction is already opened
-         * @return an object managing the error.
-         *   @see SKGError
-         */
-        virtual SKGError savePreferences() const;
-
         /**
          * The title of the plugin.
          * @return The title of the plugin
@@ -154,7 +159,7 @@ private slots:
 private:
         Q_DISABLE_COPY(SKGScheduledPlugin);
 
-        SKGMainPanel *parent;
+
         SKGDocument* currentBankDocument;
         QString docUniqueIdentifier;
 
