@@ -37,7 +37,7 @@ public:
         /**
          * Default Constructor
          */
-        SKGScheduledPluginWidget(SKGMainPanel* iParent, SKGDocumentBank* iDocument);
+        SKGScheduledPluginWidget(SKGDocumentBank* iDocument);
 
         /**
          * Default Destructor
@@ -76,7 +76,7 @@ public:
          * MUST BE OVERWRITTEN
          * @return attribute name to save the default state.
          */
-        virtual QString getDefaultStateAttibute();
+        virtual QString getDefaultStateAttribute();
 
         /**
          * Get the widget must be printed
@@ -90,6 +90,7 @@ private slots:
         void onDoubleClick();
         void onUpdate();
         void onProcess();
+        void onNbOccurrenceChanged();
 
 private:
         Q_DISABLE_COPY(SKGScheduledPluginWidget);
