@@ -21,7 +21,8 @@
  */
 #include "skgunitplugin.h"
 #include "skgunitpluginwidget.h"
-#include "skrooge_unit.h"
+#include "skgunitboardwidget.h"
+#include "skgunit_settings.h"
 #include "skgtraces.h"
 #include "skgmainpanel.h"
 #include "skgtransactionmng.h"
@@ -34,7 +35,7 @@ K_PLUGIN_FACTORY(SKGUnitPluginFactory, registerPlugin<SKGUnitPlugin>();)
 K_EXPORT_PLUGIN(SKGUnitPluginFactory("skrooge_unit", "skrooge_unit"))
 
 SKGUnitPlugin::SKGUnitPlugin(QObject* iParent, const QVariantList& /*iArg*/)
-                :SKGInterfacePlugin(iParent), parent(NULL), currentBankDocument(NULL),
+                :SKGInterfacePlugin(iParent), currentBankDocument(NULL),
                 splitShareAction(NULL)
 {
         SKGTRACEIN(10, "SKGUnitPlugin::SKGUnitPlugin");
@@ -43,18 +44,17 @@ SKGUnitPlugin::SKGUnitPlugin(QObject* iParent, const QVariantList& /*iArg*/)
 SKGUnitPlugin::~SKGUnitPlugin()
 {
         SKGTRACEIN(10, "SKGUnitPlugin::~SKGUnitPlugin");
-        parent=NULL;
         currentBankDocument=NULL;
         splitShareAction=NULL;
 }
 
-void SKGUnitPlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDocument, const QStringList& iArgument)
+void SKGUnitPlugin::setupActions(SKGDocument* iDocument, const QStringList& iArgument)
 {
         SKGTRACEIN(10, "SKGUnitPlugin::setupActions");
         Q_UNUSED(iArgument);
 
         currentBankDocument=iDocument;
-        parent=iParent;
+
 
         setComponentData( SKGUnitPluginFactory::componentData() );
 
@@ -66,7 +66,7 @@ void SKGUnitPlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDocument,
         actionCollection()->addAction( QLatin1String("edit_split_stock"), splitShareAction );
         splitShareAction->setShortcut(Qt::ALT+Qt::Key_Slash);
 
-        if (parent) parent->registedGlobalAction("edit_split_stock", splitShareAction);
+        if (SKGMainPanel::getMainPanel()) SKGMainPanel::getMainPanel()->registedGlobalAction("edit_split_stock", splitShareAction);
 }
 
 void SKGUnitPlugin::close()
@@ -74,13 +74,30 @@ void SKGUnitPlugin::close()
         SKGTRACEIN(10, "SKGUnitPlugin::close");
 }
 
+int SKGUnitPlugin::getNbDashboardWidgets()
+{
+        return 1;
+}
+
+QString SKGUnitPlugin::getDashboardWidgetTitle(int iIndex)
+{
+        if (iIndex==0) return i18n("Shares && Indexes");
+        return "";
+}
+
+SKGWidget* SKGUnitPlugin::getDashboardWidget(int iIndex)
+{
+        if (iIndex==0) return new SKGUnitBoardWidget(currentBankDocument);
+        return NULL;
+}
+
 void SKGUnitPlugin::refresh()
 {
         SKGTRACEIN(10, "SKGUnitPlugin::refresh");
-        if (parent && currentBankDocument) {
+        if (SKGMainPanel::getMainPanel() && currentBankDocument) {
                 bool test=(currentBankDocument->getDatabase()!=NULL);
                 if (splitShareAction) {
-                        SKGObjectBase::SKGListSKGObjectBase selection=parent->getSelectedObjects();
+                        SKGObjectBase::SKGListSKGObjectBase selection=SKGMainPanel::getMainPanel()->getSelectedObjects();
                         if (selection.count()==1 && selection.at(0).getRealTable()=="unit") {
                                 SKGUnitObject unit=selection.at(0);
                                 splitShareAction->setEnabled(unit.getType()==SKGUnitObject::SHARE);
@@ -109,12 +126,12 @@ void SKGUnitPlugin::refresh()
                                         int nb=selection.count();
                                         for (int i=0; err.isSucceeded() && i<nb; ++i) {
                                                 SKGUnitObject unit=selection.at(i);
-                                                err=SKGUnitPluginWidget::downloadUnitValue(unit, parent);
+                                                err=SKGUnitPluginWidget::downloadUnitValue(unit);
                                         }
                                         QApplication::restoreOverrideCursor();
 
                                         //Display error
-                                        parent->displayErrorMessage(err);
+                                        SKGMainPanel::getMainPanel()->displayErrorMessage(err);
                                 }
                         }
                 }
@@ -124,7 +141,7 @@ void SKGUnitPlugin::refresh()
 SKGTabWidget* SKGUnitPlugin::getWidget()
 {
         SKGTRACEIN(10, "SKGUnitPlugin::getWidget");
-        return new SKGUnitPluginWidget(parent, (SKGDocumentBank*) currentBankDocument);
+        return new SKGUnitPluginWidget((SKGDocumentBank*) currentBankDocument);
 }
 
 QWidget* SKGUnitPlugin::getPreferenceWidget()
@@ -138,12 +155,12 @@ QWidget* SKGUnitPlugin::getPreferenceWidget()
 
 KConfigSkeleton* SKGUnitPlugin::getPreferenceSkeleton()
 {
-        return skrooge_unit::self();
+        return skgunit_settings::self();
 }
 
 QString SKGUnitPlugin::title() const
 {
-        return i18n("Units");
+        return i18nc("Noun, units for operations, usually currencies or a shares","Units");
 }
 
 QString SKGUnitPlugin::icon() const
@@ -186,14 +203,14 @@ void SKGUnitPlugin::actionSplitShare()
         SKGTRACEINRC(10, "SKGUnitPlugin::actionSplitShare",err);
 
         //Get Selection
-        if (parent) {
-                SKGObjectBase::SKGListSKGObjectBase selection=parent->getSelectedObjects();
+        if (SKGMainPanel::getMainPanel()) {
+                SKGObjectBase::SKGListSKGObjectBase selection=SKGMainPanel::getMainPanel()->getSelectedObjects();
                 int nb=selection.count();
                 if (nb==1) {
                         bool ok=false;
                         double ratio=KInputDialog::getDouble  (i18n("Split share"),
                                                                i18n("Ratio (2 means 2-for-1, 0.5 means 1-for-2) :"), 2.0,
-                                                               0, DBL_MAX, 8, &ok, parent);
+                                                               0, DBL_MAX, 8, &ok, SKGMainPanel::getMainPanel());
                         if (ok) {
                                 SKGUnitObject unit=selection.at(0);
                                 SKGBEGINTRANSACTION(*currentBankDocument, i18n("Split stock [%1] by [%2]", unit.getName(), ratio), err);
@@ -208,7 +225,7 @@ void SKGUnitPlugin::actionSplitShare()
                 else err.addError(ERR_FAIL, i18n("Splitting stock failed."));
 
                 //Display error
-                parent->displayErrorMessage(err);
+                SKGMainPanel::getMainPanel()->displayErrorMessage(err);
         }
 }
 
