@@ -39,8 +39,8 @@
 #include <QDomDocument>
 #include <QFile>
 
-SKGUnitPluginWidget::SKGUnitPluginWidget(SKGMainPanel* iParent, SKGDocumentBank* iDocument)
-                : SKGTabWidget(iParent, iDocument)
+SKGUnitPluginWidget::SKGUnitPluginWidget(SKGDocumentBank* iDocument)
+                :SKGTabWidget(iDocument)
 {
         SKGTRACEIN(10, "SKGUnitPluginWidget::SKGUnitPluginWidget");
 
@@ -58,17 +58,17 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGMainPanel* iParent, SKGDocumentBank*
         //Fill combo box for type
         ui.kTypeCreatorUnit->addItem(i18n("Primary currency"));
         ui.kTypeCreatorUnit->addItem(i18n("Secondary currency"));
-        ui.kTypeCreatorUnit->addItem(i18n("Currency"));
-        ui.kTypeCreatorUnit->addItem(i18n("Share"));
-        ui.kTypeCreatorUnit->addItem(i18n("Index"));
-        ui.kTypeCreatorUnit->addItem(i18n("Object"));
+        ui.kTypeCreatorUnit->addItem(i18nc("Noun, a country's currency","Currency"));
+        ui.kTypeCreatorUnit->addItem(i18nc("Noun, a financial share, as in a stock market","Share"));
+        ui.kTypeCreatorUnit->addItem(i18nc("Noun, a financial index like the Dow Jones, NASDAQ, CAC40...","Index"));
+        ui.kTypeCreatorUnit->addItem(i18nc("Noun, a physical object like a house or a car","Object"));
 
         //Fill combo box for currency
         ui.kCurrencyList->addItems(SKGUnitObject::getListofKnownCurrencies());
 
         //Bind unit creation view
         {
-                objectModel = new SKGObjectModel((SKGDocumentBank*) getDocument(), "v_unit_display", "", this);
+                objectModel = new SKGObjectModel((SKGDocumentBank*) getDocument(), "v_unit_display", "", this, "", false);
 
                 QSortFilterProxyModel* modelProxy = new QSortFilterProxyModel(this);
                 modelProxy->setSourceModel(objectModel);
@@ -76,41 +76,40 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGMainPanel* iParent, SKGDocumentBank*
                 modelProxy->setDynamicSortFilter(true);
 
                 ui.kUnitTableViewEdition->setModel(modelProxy);
-                ui.kUnitTableViewEdition->setWindowTitle(i18n("Units"));
+                ui.kUnitTableViewEdition->setWindowTitle(i18nc("Noun, units for operations, usually currencies or a shares","Units"));
 
                 //Add registered global action in contextual menu
-                if (iParent) {
-                        ui.kUnitTableViewEdition->insertAction(0, iParent->getGlobalAction("edit_delete"));
+
+                if (SKGMainPanel::getMainPanel()) {
+                        ui.kUnitTableViewEdition->insertAction(0, SKGMainPanel::getMainPanel()->getGlobalAction("edit_delete"));
                         QAction* sep=new QAction(this);
                         sep->setSeparator(true);
                         ui.kUnitTableViewEdition->insertAction(0, sep);
-                        ui.kUnitTableViewEdition->insertAction(0, iParent->getGlobalAction("edit_split_stock"));
+                        ui.kUnitTableViewEdition->insertAction(0, SKGMainPanel::getMainPanel()->getGlobalAction("edit_split_stock"));
                         ui.kUnitTableViewEdition->insertAction(0, sep);
-                        ui.kUnitTableViewEdition->insertAction(0, iParent->getGlobalAction("open_report"));
+                        ui.kUnitTableViewEdition->insertAction(0, SKGMainPanel::getMainPanel()->getGlobalAction("open_report"));
                 }
-                connect(ui.kUnitTableViewEdition->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(onSelectionChanged()));
+                connect(ui.kUnitTableViewEdition, SIGNAL(selectionChangedDelayed()), this, SLOT(onSelectionChanged()));
                 connect(objectModel, SIGNAL(beforeReset()), ui.kUnitTableViewEdition, SLOT(saveSelection()));
                 connect(objectModel, SIGNAL(afterReset()), ui.kUnitTableViewEdition, SLOT(resetSelection()));
         }
 
         //Bind unit creation view
         {
-                SKGObjectModel* objectModel2 = new SKGObjectModel((SKGDocumentBank*) getDocument(), "v_unitvalue_display", "1=0", this);
+                SKGObjectModel* objectModel2 = new SKGObjectModel((SKGDocumentBank*) getDocument(), "v_unitvalue_display", "1=0", this, "", false);
 
                 ui.kUnitValueTableViewEdition->setModel(objectModel2);
                 ui.kUnitValueTableViewEdition->setWindowTitle(i18n("Unit values"));
 
                 //Add registered global action in contextual menu
-                if (iParent) ui.kUnitValueTableViewEdition->insertAction(0, iParent->getGlobalAction("edit_delete"));
 
-                connect(ui.kUnitValueTableViewEdition->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-                        this, SLOT(onSelectionValueChanged()));
+                if (SKGMainPanel::getMainPanel()) ui.kUnitValueTableViewEdition->insertAction(0, SKGMainPanel::getMainPanel()->getGlobalAction("edit_delete"));
+
+                connect(ui.kUnitValueTableViewEdition, SIGNAL(selectionChangedDelayed()), this, SLOT(onSelectionValueChanged()));
         }
 
         //Refresh
         connect((const QObject*) getDocument(), SIGNAL(tableModified(QString, int)), this, SLOT(dataModified(QString, int)), Qt::QueuedConnection );
-        dataModified("", 0);
-
         setCurrentMode(0);
 }
 
@@ -143,19 +142,13 @@ void SKGUnitPluginWidget::onSelectionChanged()
                         QString val=unit.getAttribute("t_type");
                         if (val=="1") val=i18n("Primary currency");
                         else if (val=="2") val=i18n("Secondary currency");
-                        else if (val=="C") val=i18n("Currency");
-                        else if (val=="S") val=i18n("Share");
-                        else if (val=="I") val=i18n("Index");
-                        else val=i18n("Object");
+                        else if (val=="C") val=i18nc("Noun, a country's currency","Currency");
+                        else if (val=="S") val=i18nc("Noun, a financial share, as in a stock market","Share");
+                        else if (val=="I") val=i18nc("Noun, a financial index like the Dow Jones, NASDAQ, CAC40...","Index");
+                        else val=i18nc("Noun, a physical object like a house or a car","Object");
                         ui.kTypeCreatorUnit->setText(val);
                         ui.kInternetCreatorUnit->setText(unit.getAttribute("t_internet_code"));
                         ui.kUnitCreatorUnit->setText(unit.getAttribute("t_UNIT"));
-                } else {
-                        ui.kNameCreatorUnit->setText("");
-                        ui.kSymbolCreatorUnit->setText("");
-                        ui.kCountryCreatorUnit->setText("");
-                        ui.kInternetCreatorUnit->setText("");
-                        ui.kUnitCreatorUnit->setText("");
                 }
 
                 ui.kUnitValueFrame->setEnabled(nbSelect==1);
@@ -239,10 +232,7 @@ void SKGUnitPluginWidget::onSelectionValueChanged()
 
 int SKGUnitPluginWidget::getCurrentMode()
 {
-        if (ui.kStandardFrm->isVisible()) return 0;
-        else if (ui.kManualFrm->isVisible()) return 1;
-        else if (ui.kValuesFrm->isVisible()) return 2;
-        return -1;
+        return mode;
 }
 
 void SKGUnitPluginWidget::onBtnModeClicked()
@@ -262,6 +252,8 @@ void SKGUnitPluginWidget::onBtnModeClicked()
 
 void SKGUnitPluginWidget::setCurrentMode(int iMode)
 {
+        mode=iMode;
+
         ui.kStandardFrm->hide();
         ui.kManualFrm->hide();
         ui.kValuesFrm->hide();
@@ -269,15 +261,15 @@ void SKGUnitPluginWidget::setCurrentMode(int iMode)
         ui.kStandardBtn->setChecked(false);
         ui.kManualBtn->setChecked(false);
         ui.kValuesBtn->setChecked(false);
-        ui.kBtnFrm->setVisible(iMode>=0);
+        ui.kBtnFrm->setVisible(mode>=0);
 
-        if (iMode==0) {
+        if (mode==0) {
                 ui.kStandardFrm->show();
                 ui.kStandardBtn->setChecked(true);
-        } else if (iMode==1) {
+        } else if (mode==1) {
                 ui.kManualFrm->show();
                 ui.kManualBtn->setChecked(true);
-        } else if (iMode==2) {
+        } else if (mode==2) {
                 ui.kValuesFrm->show();
                 ui.kValuesBtn->setChecked(true);
         }
@@ -356,7 +348,7 @@ void SKGUnitPluginWidget::onAddUnit()
         QApplication::restoreOverrideCursor();
 
         //Display error
-        getMainPanel()->displayErrorMessage(err);
+        SKGMainPanel::getMainPanel()->displayErrorMessage(err);
 }
 
 
@@ -402,7 +394,7 @@ void SKGUnitPluginWidget::onModifyUnit()
         QApplication::restoreOverrideCursor();
 
         //Display error
-        getMainPanel()->displayErrorMessage(err);
+        SKGMainPanel::getMainPanel()->displayErrorMessage(err);
 }
 
 void SKGUnitPluginWidget::onDoubleClickUnit()
@@ -425,9 +417,9 @@ void SKGUnitPluginWidget::onDoubleClickUnit()
                         QDomDocument doc("SKGML");
                         QDomElement root = doc.createElement("parameters");
                         doc.appendChild(root);
-                        root.setAttribute("sqlOrder", "SELECT * from v_operation_consolidated WHERE "+wc);
+                        root.setAttribute("sqlOrder", "SELECT * from v_operation_display WHERE "+wc);
 
-                        getMainPanel()->setNewTabContent(getMainPanel()->getPluginByName("Skrooge debug plugin"), -1, doc.toString());
+                        SKGMainPanel::getMainPanel()->setNewTabContent(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge debug plugin"), -1, doc.toString());
                 } else {
                         //Call operation plugin
                         QDomDocument doc("SKGML");
@@ -438,18 +430,18 @@ void SKGUnitPluginWidget::onDoubleClickUnit()
                                 doc.appendChild(root);
                         }
 
-                        root.setAttribute("operationTable", "v_operation_consolidated");
+                        root.setAttribute("operationTable", "v_operation_display");
                         root.setAttribute("operationWhereClause", wc);
                         root.setAttribute("title", title);
-                        root.setAttribute("title_icon", "view-statistics");
+                        root.setAttribute("title_icon", "skrooge_unit");
                         root.setAttribute ( "currentPage", "-1" );
 
-                        getMainPanel()->setNewTabContent(getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
+                        SKGMainPanel::getMainPanel()->setNewTabContent(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
                 }
         }
 }
 
-SKGError SKGUnitPluginWidget::downloadUnitValue(const SKGUnitObject& iUnit, QWidget* iParent, UnitDownloadMode iMode)
+SKGError SKGUnitPluginWidget::downloadUnitValue(const SKGUnitObject& iUnit, UnitDownloadMode iMode)
 {
         SKGError err;
         SKGTRACEINRC(10, "SKGUnitPluginWidget::downloadUnitValue",err);
@@ -512,12 +504,12 @@ SKGError SKGUnitPluginWidget::downloadUnitValue(const SKGUnitObject& iUnit, QWid
                 if (!last) {
                         KUrl url("http://ichart.yahoo.com/table.csv?s="+code+"&ignore=.csv&"+parameters);
                         QString tmpFile;
-                        if ( KIO::NetAccess::download(url, tmpFile, iParent)) {
+                        if ( KIO::NetAccess::download(url, tmpFile, SKGMainPanel::getMainPanel())) {
 
                                 //Open file
                                 QFile file(tmpFile);
                                 if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-                                        doc->sendMessage(tr("Open file [%1] failed").arg(tmpFile));
+                                        doc->sendMessage(i18n("Open file [%1] failed",tmpFile));
                                 } else {
                                         QTextStream stream(&file);
 
@@ -558,7 +550,7 @@ SKGError SKGUnitPluginWidget::downloadUnitValue(const SKGUnitObject& iUnit, QWid
                                                         if (err.isSucceeded()) err=doc->addOrModifyUnitValue(unitname, ds, coef*(invert && val!=0 ? 1/val : val));
                                                 } else {
                                                         err.setReturnCode(ERR_ABORT);
-                                                        err.setMessage(tr("Invalid line [%1] found in downloaded file.").arg(line));
+                                                        err.setMessage(i18n("Invalid line [%1] found in downloaded file.",line));
                                                 }
                                                 nbLoaded++;
                                         }
@@ -577,12 +569,12 @@ SKGError SKGUnitPluginWidget::downloadUnitValue(const SKGUnitObject& iUnit, QWid
                         //http://download.finance.yahoo.com/d/quotes.csv?s=EURUSD=X&f=sl1d1t1c1ohgv&e=.csv
                         KUrl url("http://download.finance.yahoo.com/d/quotes.csv?s="+code+"&f=sl1d1t1c1ohgv&e=.csv");
                         QString tmpFile;
-                        if ( KIO::NetAccess::download(url, tmpFile, iParent)) {
+                        if ( KIO::NetAccess::download(url, tmpFile, SKGMainPanel::getMainPanel())) {
 
                                 //Open file
                                 QFile file(tmpFile);
                                 if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-                                        doc->sendMessage(tr("Open file [%1] failed").arg(tmpFile));
+                                        doc->sendMessage(i18n("Open file [%1] failed",tmpFile));
                                 } else {
                                         QTextStream stream(&file);
 
@@ -612,7 +604,7 @@ SKGError SKGUnitPluginWidget::downloadUnitValue(const SKGUnitObject& iUnit, QWid
                                                 if (err.isSucceeded()) err=doc->addOrModifyUnitValue(unitname, ds , coef*(invert && val!=0 ? 1/val : val));
                                         } else {
                                                 err.setReturnCode(ERR_ABORT);
-                                                err.setMessage(tr("Invalid line [%1] found in downloaded file.").arg(line));
+                                                err.setMessage(i18n("Invalid line [%1] found in downloaded file.",line));
                                         }
 
                                         //close file
@@ -638,29 +630,33 @@ void SKGUnitPluginWidget::onDownloadUnitValue()
                 SKGObjectBase::SKGListSKGObjectBase selection=getSelectedObjects();
                 int nb=selection.count();
                 for (int i=0; err.isSucceeded() && i<nb; ++i) {
-                        err=downloadUnitValue(selection.at(i), getMainPanel());
+                        err=downloadUnitValue(selection.at(i));
                 }
         }
         QApplication::restoreOverrideCursor();
 
         //Display error
-        getMainPanel()->displayErrorMessage(err);
+        SKGMainPanel::getMainPanel()->displayErrorMessage(err);
 }
 
 SKGObjectBase::SKGListSKGObjectBase SKGUnitPluginWidget::getSelectedObjects()
 {
+        SKGObjectBase::SKGListSKGObjectBase output;
         if (ui.kUnitValueTableViewEdition->hasFocus()) {
-                return ui.kUnitValueTableViewEdition->getSelectedObjects();
+                output=ui.kUnitValueTableViewEdition->getSelectedObjects();
         }
-        return ui.kUnitTableViewEdition->getSelectedObjects();
+        if (output.count()==0) output=ui.kUnitTableViewEdition->getSelectedObjects();
+        return output;
 }
 
 int SKGUnitPluginWidget::getNbSelectedObjects()
 {
+        int output=0;
         if (ui.kUnitValueTableViewEdition->hasFocus()) {
-                return ui.kUnitValueTableViewEdition->getNbSelectedObjects();
+                output=ui.kUnitValueTableViewEdition->getNbSelectedObjects();
         }
-        return ui.kUnitTableViewEdition->getNbSelectedObjects();
+        if (output==0) output=ui.kUnitTableViewEdition->getNbSelectedObjects();
+        return output;
 }
 
 
@@ -698,17 +694,9 @@ void SKGUnitPluginWidget::setState(const QString& iState )
 
         ui.kUnitTableViewEdition->setState(root.attribute ( "unitview"));
         ui.kUnitValueTableViewEdition->setState(root.attribute ( "unitvalueview"));
-
-        QSortFilterProxyModel* modelproxy = (QSortFilterProxyModel*) ui.kUnitTableViewEdition->model();
-        SKGObjectModel* modelview=(SKGObjectModel*) modelproxy->sourceModel ();
-        if (modelview) {
-                modelview->setFilter("1=0");
-                modelview->setFilter("");
-                modelview->refresh();
-        }
 }
 
-QString SKGUnitPluginWidget::getDefaultStateAttibute()
+QString SKGUnitPluginWidget::getDefaultStateAttribute()
 {
         return "SKGUNIT_DEFAULT_PARAMETERS";
 }
@@ -716,6 +704,8 @@ QString SKGUnitPluginWidget::getDefaultStateAttibute()
 void SKGUnitPluginWidget::dataModified(const QString& iTableName, int iIdTransaction)
 {
         SKGTRACEIN(10, "SKGUnitPluginWidget::dataModified");
+        Q_UNUSED(iIdTransaction);
+
         if (iTableName=="unit" || iTableName.isEmpty()) {
                 //Refresh widgets
                 setEnabled(getDocument()->getDatabase()!=NULL);
@@ -736,4 +726,16 @@ void SKGUnitPluginWidget::dataModified(const QString& iTableName, int iIdTransac
                 onSelectionChanged();
         }
 }
+
+void SKGUnitPluginWidget::cleanEditor()
+{
+        if (getNbSelectedObjects()==0) {
+                ui.kNameCreatorUnit->setText("");
+                ui.kSymbolCreatorUnit->setText("");
+                ui.kCountryCreatorUnit->setText("");
+                ui.kInternetCreatorUnit->setText("");
+                ui.kUnitCreatorUnit->setText("");
+        }
+}
+
 #include "skgunitpluginwidget.moc"
