@@ -52,7 +52,7 @@ public:
         /**
          * Default Constructor
          */
-        SKGUnitPluginWidget(SKGMainPanel* iParent, SKGDocumentBank* iDocument);
+        SKGUnitPluginWidget(SKGDocumentBank* iDocument);
 
         /**
          * Default Destructor
@@ -91,17 +91,16 @@ public:
          * MUST BE OVERWRITTEN
          * @return attribute name to save the default state.
          */
-        virtual QString getDefaultStateAttibute();
+        virtual QString getDefaultStateAttribute();
 
         /**
          * Download values for a unit
          * @param iUnit unit
-         * @param iParent parent widget
          * @param iMode download mode
          * @return an object managing the error
          *   @see SKGError
          */
-        static SKGError downloadUnitValue(const SKGUnitObject& iUnit, QWidget* iParent, UnitDownloadMode iMode=AUTO);
+        static SKGError downloadUnitValue(const SKGUnitObject& iUnit, UnitDownloadMode iMode=AUTO);
 
 private slots:
         void dataModified(const QString& iTableName, int iIdTransaction);
@@ -113,6 +112,7 @@ private slots:
         void onDownloadUnitValue();
         void onDoubleClickUnit();
         void onBtnModeClicked();
+        void cleanEditor();
 
 private:
         Q_DISABLE_COPY(SKGUnitPluginWidget);
@@ -122,6 +122,7 @@ private:
 
         Ui::skgunitplugin_base ui;;
         SKGObjectModel* objectModel;
+        int mode;
 };
 
 #endif // SKGDEBUGPLUGIN_H
