@@ -26,8 +26,8 @@
 
 #include <QDomDocument>
 
-SKGXXXPluginWidget::SKGXXXPluginWidget(SKGMainPanel* iParent, SKGDocument* iDocument)
-                : SKGTabWidget(iParent, iDocument)
+SKGXXXPluginWidget::SKGXXXPluginWidget(SKGDocument* iDocument)
+                :SKGTabWidget(iDocument)
 {
         SKGTRACEIN(1, "SKGXXXPluginWidget::SKGXXXPluginWidget");
 
@@ -66,7 +66,7 @@ void SKGXXXPluginWidget::setState(const QString& iState )
         //Example: QString account=root.attribute ( "account");
 }
 
-QString SKGXXXPluginWidget::getDefaultStateAttibute()
+QString SKGXXXPluginWidget::getDefaultStateAttribute()
 {
         return "";
 }
