@@ -35,7 +35,7 @@ public:
         /**
          * Default Constructor
          */
-        SKGXXXPluginWidget(SKGMainPanel* iParent, SKGDocument* iDocument);
+        SKGXXXPluginWidget(SKGDocument* iDocument);
 
         /**
          * Default Destructor
@@ -62,7 +62,7 @@ public:
          * MUST BE OVERWRITTEN
          * @return attribute name to save the default state.
          */
-        virtual QString getDefaultStateAttibute();
+        virtual QString getDefaultStateAttribute();
 
         /**
          * Get the widget must be printed
